"use strict";(self.rspackChunktalk=self.rspackChunktalk||[]).push([["defaultVendors-node_modules_nextcloud_vue_dist_assets_NcCheckboxRadioSwitch-BlQSZVW0_css-node-e54a6e"],{63667(t,e,i){let n;i.d(e,{Xn:()=>y,VA:()=>m,KU:()=>b,aN:()=>f,Q$:()=>v,Yr:()=>g,pO:()=>x});var r=i(21777),o=i(63814),s=i(81222);function a(){return(0,s.C)("files_sharing","isPublic",null)??null!==document.querySelector('input#isPublic[type="hidden"][name="isPublic"][value="1"]')}var l=i(44719),u=i(70970);let h=["d:getcontentlength","d:getcontenttype","d:getetag","d:getlastmodified","d:creationdate","d:displayname","d:quota-available-bytes","d:resourcetype","nc:has-preview","nc:is-encrypted","nc:mount-type","oc:comments-unread","oc:favorite","oc:fileid","oc:owner-display-name","oc:owner-id","oc:permissions","oc:size"],c={d:"DAV:",nc:"http://nextcloud.org/ns",oc:"http://owncloud.org/ns",ocs:"http://open-collaboration-services.org/ns"};function p(){return u.s.davProperties??=[...h],u.s.davProperties.map(t=>`<${t} />`).join(" ")}function d(){return u.s.davNamespaces??={...c},Object.keys(u.s.davNamespaces).map(t=>`xmlns:${t}="${u.s.davNamespaces?.[t]}"`).join(" ")}function f(){return`<?xml version="1.0"?>
		<d:propfind ${d()}>
			<d:prop>
				${p()}
			</d:prop>
		</d:propfind>`}function g(t){return`<?xml version="1.0" encoding="UTF-8"?>
<d:searchrequest ${d()}
	xmlns:ns="https://github.com/icewind1991/SearchDAV/ns">
	<d:basicsearch>
		<d:select>
			<d:prop>
				${p()}
			</d:prop>
		</d:select>
		<d:from>
			<d:scope>
				<d:href>/files/${(0,r.HW)()?.uid}/</d:href>
				<d:depth>infinity</d:depth>
			</d:scope>
		</d:from>
		<d:where>
			<d:and>
				<d:or>
					<d:not>
						<d:eq>
							<d:prop>
								<d:getcontenttype/>
							</d:prop>
							<d:literal>httpd/unix-directory</d:literal>
						</d:eq>
					</d:not>
					<d:eq>
						<d:prop>
							<oc:size/>
						</d:prop>
						<d:literal>0</d:literal>
					</d:eq>
				</d:or>
				<d:gt>
					<d:prop>
						<d:getlastmodified/>
					</d:prop>
					<d:literal>${t}</d:literal>
				</d:gt>
			</d:and>
		</d:where>
		<d:orderby>
			<d:order>
				<d:prop>
					<d:getlastmodified/>
				</d:prop>
				<d:descending/>
			</d:order>
		</d:orderby>
		<d:limit>
			<d:nresults>100</d:nresults>
			<ns:firstresult>0</ns:firstresult>
		</d:limit>
	</d:basicsearch>
</d:searchrequest>`}let m=a()?`/files/${(0,s.C)("files_sharing","sharingToken",null)??document.querySelector('input#sharingToken[type="hidden"]')?.value??null}`:`/files/${(0,r.HW)()?.uid}`,y=(n=(0,o.dC)("dav"),a()?n.replace("remote.php","public.php"):n);function b(t=y,e={}){let i=(0,l.UU)(t,{headers:e});function n(t){i.setHeaders({...e,"X-Requested-With":"XMLHttpRequest",requesttoken:t??""})}return(0,r.zo)(n),n((0,r.do)()),(0,l.Gu)().patch("fetch",(t,e)=>{let i=e.headers;return i?.method&&(e.method=i.method,delete i.method),fetch(t,e)}),i}async function v(t={}){let e=t.client??b(),i=t.path??"/",n=t.davRoot??m;return(await e.getDirectoryContents(`${n}${i}`,{signal:t.signal,details:!0,data:`<?xml version="1.0"?>
		<oc:filter-files ${d()}>
			<d:prop>
				${p()}
			</d:prop>
			<oc:filter-rules>
				<oc:favorite>1</oc:favorite>
			</oc:filter-rules>
		</oc:filter-files>`,headers:{method:"REPORT"},includeSelf:!0})).data.filter(t=>t.filename!==i).map(t=>x(t,n))}function x(t,e=m,i=y){let n=(0,r.HW)()?.uid;if(a())n=n??"anonymous";else if(!n)throw Error("No user id found");let o=t.props,s=function(t=""){let e=u.P.NONE;return t&&(t.includes("G")&&(e|=u.P.READ),t.includes("W")&&(e|=u.P.WRITE),t.includes("CK")&&(e|=u.P.CREATE),t.includes("NV")&&(e|=u.P.UPDATE),t.includes("D")&&(e|=u.P.DELETE),t.includes("R")&&(e|=u.P.SHARE)),e}(o?.permissions),l=String(o?.["owner-id"]||n),h=o.fileid||0,c=new Date(Date.parse(t.lastmod)),p=new Date(Date.parse(o.creationdate)),d={id:h,source:`${i}${t.filename}`,mtime:isNaN(c.getTime())||0===c.getTime()?void 0:c,crtime:isNaN(p.getTime())||0===p.getTime()?void 0:p,mime:t.mime||"application/octet-stream",displayname:void 0!==o.displayname?String(o.displayname):void 0,size:o?.size||Number.parseInt(o.getcontentlength||"0"),status:h<0?u.c.FAILED:void 0,permissions:s,owner:l,root:e,attributes:{...t,...o,hasPreview:o?.["has-preview"]}};return delete d.attributes?.props,"file"===t.type?new u.a(d):new u.b(d)}},32505(t,e,i){var n=i(81222);function r(){return(0,n.C)("files_sharing","isPublic",null)??null!==document.querySelector('input#isPublic[type="hidden"][name="isPublic"][value="1"]')}function o(){return(0,n.C)("files_sharing","sharingToken",null)??document.querySelector('input#sharingToken[type="hidden"]')?.value??null}i.d(e,{G:()=>o,f:()=>r})},8273(t,e,i){var n=i(20641),r=i(90033),o=i(52697);let s=["aria-hidden","aria-label"],a=["fill","width","height"],l={d:"M7.41,8.58L12,13.17L16.59,8.58L18,10L12,16L6,10L7.41,8.58Z"},u={key:0},h=(0,o._)({name:"ChevronDownIcon",emits:["click"],props:{title:{type:String},fillColor:{type:String,default:"currentColor"},size:{type:Number,default:24}}},[["render",function(t,e,i,o,h,c){return(0,n.uX)(),(0,n.CE)("span",(0,n.v6)(t.$attrs,{"aria-hidden":i.title?null:"true","aria-label":i.title,class:"material-design-icon chevron-down-icon",role:"img",onClick:e[0]||(e[0]=e=>t.$emit("click",e))}),[((0,n.uX)(),(0,n.CE)("svg",{fill:i.fillColor,class:"material-design-icon__svg",width:i.size,height:i.size,viewBox:"0 0 24 24"},[(0,n.Lk)("path",l,[i.title?((0,n.uX)(),(0,n.CE)("title",u,(0,r.toDisplayString)(i.title),1)):(0,n.Q3)("",!0)])],8,a))],16,s)}]]);i.d(e,{},{C:h})},31564(t,e,i){var n=i(20641),r=i(90033),o=i(52697);let s=["aria-hidden","aria-label"],a=["fill","width","height"],l={d:"M19,6.41L17.59,5L12,10.59L6.41,5L5,6.41L10.59,12L5,17.59L6.41,19L12,13.41L17.59,19L19,17.59L13.41,12L19,6.41Z"},u={key:0},h=(0,o._)({name:"CloseIcon",emits:["click"],props:{title:{type:String},fillColor:{type:String,default:"currentColor"},size:{type:Number,default:24}}},[["render",function(t,e,i,o,h,c){return(0,n.uX)(),(0,n.CE)("span",(0,n.v6)(t.$attrs,{"aria-hidden":i.title?null:"true","aria-label":i.title,class:"material-design-icon close-icon",role:"img",onClick:e[0]||(e[0]=e=>t.$emit("click",e))}),[((0,n.uX)(),(0,n.CE)("svg",{fill:i.fillColor,class:"material-design-icon__svg",width:i.size,height:i.size,viewBox:"0 0 24 24"},[(0,n.Lk)("path",l,[i.title?((0,n.uX)(),(0,n.CE)("title",u,(0,r.toDisplayString)(i.title),1)):(0,n.Q3)("",!0)])],8,a))],16,s)}]]);i.d(e,{},{I:h})},71096(t,e,i){var n=i(98190),r=i(51012),o=i(63825),s=i(65112),a=i(20641),l=i(90033),u=i(52697);let h={name:"NcActionButton",components:{NcIconSvgWrapper:r.N},mixins:[o.A],inject:{isInSemanticMenu:{from:s.a,default:!1}},props:{disabled:{type:Boolean,default:!1},isMenu:{type:Boolean,default:!1},type:{type:String,default:"button",validator:t=>["button","checkbox","radio","reset","submit"].includes(t)},modelValue:{type:[Boolean,String],default:null},value:{type:String,default:null},description:{type:String,default:""}},emits:["update:modelValue"],setup:()=>({mdiCheck:n.d,mdiChevronRight:n.c}),computed:{isFocusable(){return!this.disabled},isChecked(){return"radio"===this.type&&"boolean"!=typeof this.modelValue?this.modelValue===this.value:this.modelValue},nativeType(){return"submit"===this.type||"reset"===this.type?this.type:"button"},buttonAttributes(){let t={};return this.isInSemanticMenu?(t.role="menuitem","radio"===this.type?(t.role="menuitemradio",t["aria-checked"]=this.isChecked?"true":"false"):("checkbox"===this.type||"button"===this.nativeType&&null!==this.modelValue)&&(t.role="menuitemcheckbox",t["aria-checked"]=null===this.modelValue?"mixed":this.modelValue?"true":"false")):null!==this.modelValue&&"button"===this.nativeType&&(t["aria-pressed"]=this.modelValue?"true":"false"),t}},methods:{handleClick(t){this.onClick(t),(null!==this.modelValue||"button"!==this.type)&&("radio"===this.type&&"boolean"!=typeof this.modelValue?this.isChecked||this.$emit("update:modelValue",this.value):this.$emit("update:modelValue",!this.isChecked))}}},c=["role"],p=["aria-label","disabled","title","type"],d={class:"action-button__longtext-wrapper"},f={key:0,class:"action-button__name"},g=["textContent"],m={key:2,class:"action-button__text"},y=["textContent"],b={key:2,class:"action-button__pressed-icon material-design-icon"},v=(0,u._)(h,[["render",function(t,e,i,n,r,o){let s=(0,a.g2)("NcIconSvgWrapper");return(0,a.uX)(),(0,a.CE)("li",{class:(0,l.normalizeClass)(["action",{"action--disabled":i.disabled}]),role:o.isInSemanticMenu&&"presentation"},[(0,a.Lk)("button",(0,a.v6)({"aria-label":t.ariaLabel,class:["action-button button-vue",{"action-button--active":o.isChecked,focusable:o.isFocusable}],disabled:i.disabled,title:t.title,type:o.nativeType},o.buttonAttributes,{onClick:e[0]||(e[0]=(...t)=>o.handleClick&&o.handleClick(...t))}),[(0,a.RG)(t.$slots,"icon",{},()=>[(0,a.Lk)("span",{class:(0,l.normalizeClass)([[t.isIconUrl?"action-button__icon--url":t.icon],"action-button__icon"]),style:(0,l.normalizeStyle)({backgroundImage:t.isIconUrl?`url(${t.icon})`:null}),"aria-hidden":"true"},null,6)],!0),(0,a.Lk)("span",d,[t.name?((0,a.uX)(),(0,a.CE)("strong",f,(0,l.toDisplayString)(t.name),1)):(0,a.Q3)("",!0),t.isLongText?((0,a.uX)(),(0,a.CE)("span",{key:1,class:"action-button__longtext",textContent:(0,l.toDisplayString)(t.text)},null,8,g)):((0,a.uX)(),(0,a.CE)("span",m,(0,l.toDisplayString)(t.text),1)),i.description?((0,a.uX)(),(0,a.CE)("span",{key:3,class:"action-button__description",textContent:(0,l.toDisplayString)(i.description)},null,8,y)):(0,a.Q3)("",!0)]),i.isMenu?((0,a.uX)(),(0,a.Wv)(s,{key:0,class:"action-button__menu-icon",directional:"",path:n.mdiChevronRight},null,8,["path"])):o.isChecked?((0,a.uX)(),(0,a.Wv)(s,{key:1,path:n.mdiCheck,class:"action-button__pressed-icon"},null,8,["path"])):!1===o.isChecked?((0,a.uX)(),(0,a.CE)("span",b)):(0,a.Q3)("",!0),(0,a.Q3)("",!0)],16,p)],10,c)}],["__scopeId","data-v-6c2daf4e"]]);i.d(e,{},{N:v})},39771(t,e,i){var n=i(20641),r=i(90033),o=i(53751),s=i(22436),a=i(26308),l=i(34163),u=i(3639),h=i(64535),c=i(51420),p=i(52697);(0,s.r)(s.l);let d={name:"NcActionInput",components:{NcDateTimePickerNative:u.N,NcPasswordField:h.N,NcTextField:c._,NcColorPicker:(0,n.$V)(()=>Promise.all([i.e("defaultVendors-node_modules_nextcloud_vue_dist_chunks_NcColorPicker-CGE4Kei4_mjs"),i.e("node_modules_nextcloud_vue_dist_assets_NcColorPicker-DVYGs8R3_css-node_modules_nextcloud_vue_-975502")]).then(i.bind(i,71415))),NcDateTimePicker:(0,n.$V)(()=>i.e("defaultVendors-node_modules_nextcloud_vue_dist_components_NcDateTimePicker_index_mjs").then(i.bind(i,76828))),NcSelect:(0,n.$V)(()=>Promise.resolve().then(i.bind(i,3710)))},mixins:[a.A],inheritAttrs:!1,props:{id:{type:String,default:()=>"action-"+(0,l.c)(),validator:t=>""!==t.trim()},inputId:{type:String,default:()=>"action-input-"+(0,l.c)(),validator:t=>""!==t.trim()},icon:{type:String,default:""},type:{type:String,default:"text",validator:t=>["date","datetime-local","month","multiselect","number","password","search","tel","text","time","url","week","color","email"].includes(t)},idNativeDateTimePicker:{type:String,default:"date-time-picker_id"},isNativePicker:{type:Boolean,default:!1},label:{type:String,default:null},labelOutside:{type:Boolean,default:!0},modelValue:{type:[String,Date,Number,Array],default:""},disabled:{type:Boolean,default:!1},ariaLabel:{type:String,default:""},showTrailingButton:{type:Boolean,default:!0},trailingButtonLabel:{type:String,default:(0,s.a)("Submit")},class:{type:[String,Array,Object],default:""}},emits:["submit","update:modelValue"],computed:{isIconUrl(){try{return new URL(this.icon)}catch{return!1}},isMultiselectType(){return"multiselect"===this.type},nativeDatePickerType(){switch(this.type){case"date":case"month":case"time":case"week":case"datetime-local":return this.type}return!1},datePickerType(){if(!this.isNativePicker)switch(this.type){case"date":case"month":case"time":return this.type;case"datetime-local":return"datetime"}return!1},isFocusable(){return!this.disabled}},methods:{onLeave(){this.$refs.datetimepicker&&this.$refs.datetimepicker.$refs.datepicker&&this.$refs.datetimepicker.$refs.datepicker.closePopup()},onSubmit(t){if(t.preventDefault(),t.stopPropagation(),this.disabled)return!1;this.$emit("submit",t)},onUpdateModelValue(t){this.$emit("update:modelValue",t)}}},f={class:"action-input__icon-wrapper"},g=["disabled"],m={class:"action-input__container"},y=["for"],b={class:"action-input__input-container"},v={key:4,class:"action-input__container"},x=["for"],w={class:"action-input__input-container"},N=(0,p._)(d,[["render",function(t,e,i,s,a,l){let u=(0,n.g2)("NcDateTimePicker"),h=(0,n.g2)("NcDateTimePickerNative"),c=(0,n.g2)("NcSelect"),p=(0,n.g2)("NcPasswordField"),d=(0,n.g2)("NcColorPicker"),N=(0,n.g2)("NcTextField");return(0,n.uX)(),(0,n.CE)("li",{class:(0,r.normalizeClass)(["action",[{"action--disabled":i.disabled},t.$props.class]])},[(0,n.Lk)("span",{class:(0,r.normalizeClass)(["action-input",{"action-input-picker--disabled":i.disabled,"action-input--visible-label":i.labelOutside&&i.label}]),onMouseleave:e[3]||(e[3]=(...t)=>l.onLeave&&l.onLeave(...t))},[(0,n.Lk)("span",f,[(0,n.RG)(t.$slots,"icon",{},()=>[(0,n.Lk)("span",{"aria-hidden":"true",class:(0,r.normalizeClass)(["action-input__icon",[l.isIconUrl?"action-input__icon--url":i.icon]]),style:(0,r.normalizeStyle)({backgroundImage:l.isIconUrl?`url(${i.icon})`:null})},null,6)],!0)]),(0,n.Lk)("form",{ref:"form",class:"action-input__form",disabled:i.disabled,onSubmit:e[2]||(e[2]=(0,o.withModifiers)((...t)=>l.onSubmit&&l.onSubmit(...t),["prevent"]))},[(0,n.Lk)("div",m,[i.label&&i.labelOutside&&!i.isNativePicker?((0,n.uX)(),(0,n.CE)("label",{key:0,class:(0,r.normalizeClass)(["action-input__text-label",{"action-input__text-label--hidden":!i.labelOutside}]),for:i.inputId},(0,r.toDisplayString)(i.label),11,y)):(0,n.Q3)("",!0),(0,n.Lk)("div",b,[l.datePickerType?((0,n.uX)(),(0,n.Wv)(u,(0,n.v6)({key:0,ref:"datetimepicker",modelValue:i.modelValue,style:{"z-index":"99999999999"},placeholder:t.text,disabled:i.disabled,type:l.datePickerType,inputClass:["mx-input",{focusable:l.isFocusable}],class:"action-input__datetimepicker",appendToBody:""},t.$attrs,{"onUpdate:modelValue":l.onUpdateModelValue}),null,16,["modelValue","placeholder","disabled","type","inputClass","onUpdate:modelValue"])):i.isNativePicker?((0,n.uX)(),(0,n.Wv)(h,(0,n.v6)({key:1,id:i.idNativeDateTimePicker,modelValue:i.modelValue,label:i.label,type:l.nativeDatePickerType,inputClass:{focusable:l.isFocusable},class:"action-input__datetimepicker"},t.$attrs,{"onUpdate:modelValue":l.onUpdateModelValue}),null,16,["id","modelValue","label","type","inputClass","onUpdate:modelValue"])):l.isMultiselectType?((0,n.uX)(),(0,n.Wv)(c,(0,n.v6)({key:2,modelValue:i.modelValue,placeholder:t.text,disabled:i.disabled,appendToBody:!1,inputClass:{focusable:l.isFocusable},class:"action-input__multi"},t.$attrs,{"onUpdate:modelValue":l.onUpdateModelValue}),null,16,["modelValue","placeholder","disabled","inputClass","onUpdate:modelValue"])):"password"===i.type?((0,n.uX)(),(0,n.Wv)(p,(0,n.v6)({key:3,id:i.inputId,modelValue:i.modelValue,label:i.label,labelOutside:!i.label||i.labelOutside,placeholder:t.text,disabled:i.disabled,inputClass:{focusable:l.isFocusable},showTrailingButton:i.showTrailingButton&&!i.disabled},t.$attrs,{"onUpdate:modelValue":l.onUpdateModelValue}),null,16,["id","modelValue","label","labelOutside","placeholder","disabled","inputClass","showTrailingButton","onUpdate:modelValue"])):"color"===i.type?((0,n.uX)(),(0,n.CE)("div",v,[i.label&&"color"===i.type?((0,n.uX)(),(0,n.CE)("label",{key:0,class:(0,r.normalizeClass)(["action-input__text-label",{"action-input__text-label--hidden":!i.labelOutside}]),for:i.inputId},(0,r.toDisplayString)(i.label),11,x)):(0,n.Q3)("",!0),(0,n.Lk)("div",w,[(0,n.bF)(d,(0,n.v6)({id:"inputId",modelValue:i.modelValue,class:"colorpicker__trigger"},t.$attrs,{"onUpdate:modelValue":l.onUpdateModelValue,onSubmit:e[0]||(e[0]=e=>t.$refs.form.requestSubmit())}),{default:(0,n.k6)(()=>[(0,n.Lk)("button",{class:(0,r.normalizeClass)(["colorpicker__preview",{focusable:l.isFocusable}]),style:(0,r.normalizeStyle)({"background-color":i.modelValue})},null,6)]),_:1},16,["modelValue","onUpdate:modelValue"])])])):((0,n.uX)(),(0,n.Wv)(N,(0,n.v6)({key:5,id:i.inputId,modelValue:i.modelValue,label:i.label,labelOutside:!i.label||i.labelOutside,placeholder:t.text,disabled:i.disabled,inputClass:{focusable:l.isFocusable},type:i.type,trailingButtonIcon:"arrowRight",trailingButtonLabel:i.trailingButtonLabel,showTrailingButton:i.showTrailingButton&&!i.disabled},t.$attrs,{onTrailingButtonClick:e[1]||(e[1]=e=>t.$refs.form.requestSubmit()),"onUpdate:modelValue":l.onUpdateModelValue}),null,16,["id","modelValue","label","labelOutside","placeholder","disabled","inputClass","type","trailingButtonLabel","showTrailingButton","onUpdate:modelValue"]))])])],40,g)],34)],2)}],["__scopeId","data-v-43230e98"]]);i.d(e,{},{N:N})},56891(t,e,i){var n=i(63825),r=i(65112),o=i(20641),s=i(90033),a=i(52697);let l={name:"NcActionLink",mixins:[n.A],inject:{isInSemanticMenu:{from:r.a,default:!1}},props:{href:{type:String,required:!0,validator:t=>{try{return new URL(t)}catch{return t.startsWith("#")||t.startsWith("/")}}},download:{type:String,default:null},target:{type:String,default:"_self",validator:t=>t&&(!t.startsWith("_")||["_blank","_self","_parent","_top"].indexOf(t)>-1)},title:{type:String,default:null}}},u=["role"],h=["download","href","aria-label","target","title","role"],c={key:0,class:"action-link__longtext-wrapper"},p={class:"action-link__name"},d=["textContent"],f=["textContent"],g={key:2,class:"action-link__text"},m=(0,a._)(l,[["render",function(t,e,i,n,r,a){return(0,o.uX)(),(0,o.CE)("li",{class:"action",role:a.isInSemanticMenu&&"presentation"},[(0,o.Lk)("a",{download:i.download,href:i.href,"aria-label":t.ariaLabel,target:i.target,title:i.title,class:"action-link focusable",rel:"nofollow noreferrer noopener",role:a.isInSemanticMenu&&"menuitem",onClick:e[0]||(e[0]=(...e)=>t.onClick&&t.onClick(...e))},[(0,o.RG)(t.$slots,"icon",{},()=>[(0,o.Lk)("span",{"aria-hidden":"true",class:(0,s.normalizeClass)(["action-link__icon",[t.isIconUrl?"action-link__icon--url":t.icon]]),style:(0,s.normalizeStyle)({backgroundImage:t.isIconUrl?`url(${t.icon})`:null})},null,6)],!0),t.name?((0,o.uX)(),(0,o.CE)("span",c,[(0,o.Lk)("strong",p,(0,s.toDisplayString)(t.name),1),e[1]||(e[1]=(0,o.Lk)("br",null,null,-1)),(0,o.Lk)("span",{class:"action-link__longtext",textContent:(0,s.toDisplayString)(t.text)},null,8,d)])):t.isLongText?((0,o.uX)(),(0,o.CE)("span",{key:1,class:"action-link__longtext",textContent:(0,s.toDisplayString)(t.text)},null,8,f)):((0,o.uX)(),(0,o.CE)("span",g,(0,s.toDisplayString)(t.text),1)),(0,o.Q3)("",!0)],8,h)],8,u)}],["__scopeId","data-v-32f01b7a"]]);i.d(e,{},{N:m})},17834(t,e,i){var n=i(63825),r=i(65112),o=i(20641),s=i(90033),a=i(52697);let l={name:"NcActionRouter",mixins:[n.A],inject:{isInSemanticMenu:{from:r.a,default:!1}},props:{to:{type:[String,Object],required:!0}}},u=["role"],h={key:0,class:"action-router__longtext-wrapper"},c={class:"action-router__name"},p=["textContent"],d=["textContent"],f={key:2,class:"action-router__text"},g=(0,a._)(l,[["render",function(t,e,i,n,r,a){let l=(0,o.g2)("RouterLink");return(0,o.uX)(),(0,o.CE)("li",{class:"action",role:a.isInSemanticMenu&&"presentation"},[(0,o.bF)(l,{"aria-label":t.ariaLabel,class:"action-router focusable",rel:"nofollow noreferrer noopener",role:a.isInSemanticMenu&&"menuitem",title:t.title,to:i.to,onClick:t.onClick},{default:(0,o.k6)(()=>[(0,o.RG)(t.$slots,"icon",{},()=>[(0,o.Lk)("span",{"aria-hidden":"true",class:(0,s.normalizeClass)(["action-router__icon",[t.isIconUrl?"action-router__icon--url":t.icon]]),style:(0,s.normalizeStyle)({backgroundImage:t.isIconUrl?`url(${t.icon})`:null})},null,6)],!0),t.name?((0,o.uX)(),(0,o.CE)("span",h,[(0,o.Lk)("strong",c,(0,s.toDisplayString)(t.name),1),e[0]||(e[0]=(0,o.Lk)("br",null,null,-1)),(0,o.Lk)("span",{class:"action-router__longtext",textContent:(0,s.toDisplayString)(t.text)},null,8,p)])):t.isLongText?((0,o.uX)(),(0,o.CE)("span",{key:1,class:"action-router__longtext",textContent:(0,s.toDisplayString)(t.text)},null,8,d)):((0,o.uX)(),(0,o.CE)("span",f,(0,s.toDisplayString)(t.text),1)),(0,o.Q3)("",!0)]),_:3},8,["aria-label","role","title","to","onClick"])],8,u)}],["__scopeId","data-v-87267750"]]);i.d(e,{},{N:g})},3639(t,e,i){var n=i(20641),r=i(90033),o=i(22436),s=i(34163),a=i(52697);(0,o.r)(o.x);let l=["for"],u=["id","type","value","min","max"],h=(0,n.pM)({...{inheritAttrs:!1},__name:"NcDateTimePickerNative",props:(0,n.zz)({class:{default:void 0},id:{default:()=>(0,s.c)()},inputClass:{default:""},type:{default:"date"},label:{default:()=>(0,o.a)("Please choose a date")},min:{default:null},max:{default:null},hideLabel:{type:Boolean}},{modelValue:{default:null},modelModifiers:{}}),emits:["update:modelValue"],setup(t){let e=(0,n.fn)(t,"modelValue"),i=(0,n.EW)(()=>e.value?h(e.value):""),o=(0,n.EW)(()=>t.max?h(t.max):void 0),s=(0,n.EW)(()=>t.min?h(t.min):void 0);function a(t){let e=t.getFullYear().toString().padStart(4,"0"),i=(t.getMonth()+1).toString().padStart(2,"0"),n=t.getDate().toString().padStart(2,"0");return{yyyy:e,MM:i,dd:n,hh:t.getHours().toString().padStart(2,"0"),mm:t.getMinutes().toString().padStart(2,"0")}}function h(e){let{yyyy:i,MM:n,dd:r,hh:o,mm:s}=a(e);if("datetime-local"===t.type)return`${i}-${n}-${r}T${o}:${s}`;if("date"===t.type)return`${i}-${n}-${r}`;if("month"===t.type)return`${i}-${n}`;if("time"===t.type)return`${o}:${s}`;if("week"===t.type){let t=new Date(Number.parseInt(i),0,1),n=Math.ceil(Math.floor((e.getTime()-t.getTime())/864e5)/7);return`${i}-W${n}`}return""}function c(i){let n=i.target;if(!n||isNaN(n.valueAsNumber))e.value=null;else if("time"===t.type){let t=n.value,{yyyy:i,MM:r,dd:o}=a(e.value||new Date);e.value=new Date(`${i}-${r}-${o}T${t}`)}else if("month"===t.type){let t=(new Date(n.value).getMonth()+1).toString().padStart(2,"0"),{yyyy:i,dd:r,hh:o,mm:s}=a(e.value||new Date);e.value=new Date(`${i}-${t}-${r}T${o}:${s}`)}else{let t=1e3*new Date(n.valueAsNumber).getTimezoneOffset()*60;e.value=new Date(n.valueAsNumber+t)}}return(e,a)=>((0,n.uX)(),(0,n.CE)("div",{class:(0,r.normalizeClass)(["native-datetime-picker",e.$props.class])},[(0,n.Lk)("label",{class:(0,r.normalizeClass)(["native-datetime-picker__label",{"hidden-visually":t.hideLabel}]),for:t.id},(0,r.toDisplayString)(t.label),11,l),(0,n.Lk)("input",(0,n.v6)({id:t.id,class:["native-datetime-picker__input",t.inputClass],type:t.type,value:i.value,min:s.value,max:o.value},e.$attrs,{onInput:c}),null,16,u)],2))}}),c=(0,a._)(h,[["__scopeId","data-v-b97e1f7a"]]);i.d(e,{},{N:c})},42531(t,e,i){var n=i(20641);function r(t,e){let i=[],n=0,r=t.toLowerCase().indexOf(e.toLowerCase(),n),o=0;for(;r>-1&&o++<t.length;)n=r+e.length,i.push({start:r,end:n}),r=t.toLowerCase().indexOf(e.toLowerCase(),n);return i}let o=(0,n.pM)({name:"NcHighlight",props:{text:{type:String,default:""},search:{type:String,default:""},highlight:{type:Array,default:()=>[]}},computed:{ranges(){let t=[];return this.search||0!==this.highlight.length?((t=this.highlight.length>0?this.highlight:r(this.text,this.search)).forEach((e,i)=>{e.end<e.start&&(t[i]={start:e.end,end:e.start})}),(t=t.reduce((t,e)=>(e.start<this.text.length&&e.end>0&&t.push({start:e.start<0?0:e.start,end:e.end>this.text.length?this.text.length:e.end}),t),[])).sort((t,e)=>t.start-e.start),t=t.reduce((t,e)=>{if(t.length){let i=t.length-1;t[i].end>=e.start?t[i]={start:t[i].start,end:Math.max(t[i].end,e.end)}:t.push(e)}else t.push(e);return t},[])):t},chunks(){if(0===this.ranges.length)return[{start:0,end:this.text.length,highlight:!1,text:this.text}];let t=[],e=0,i=0;for(;e<this.text.length;){let n=this.ranges[i];if(n.start===e){t.push({...n,highlight:!0,text:this.text.slice(n.start,n.end)}),i++,e=n.end,i>=this.ranges.length&&e<this.text.length&&(t.push({start:e,end:this.text.length,highlight:!1,text:this.text.slice(e)}),e=this.text.length);continue}t.push({start:e,end:n.start,highlight:!1,text:this.text.slice(e,n.start)}),e=n.start}return t}},render(){return this.ranges.length?(0,n.h)("span",{},this.chunks.map(t=>t.highlight?(0,n.h)("strong",{},t.text):t.text)):(0,n.h)("span",{},this.text)}});i.d(e,{f:()=>r},{_:o})},26089(t,e,i){var n=i(20641),r=i(90033),o=i(50953),s=i(53751),a=i(98190),l=i(42221),u=i(51012),h=i(34163),c=i(26096),p=i(52697);let d={class:"input-field__main-wrapper"},f=["id","aria-describedby","disabled","placeholder","type","value"],g=["for"],m={class:"input-field__icon input-field__icon--leading"},y={key:2,class:"input-field__icon input-field__icon--trailing"},b=["id"],v=(0,n.pM)({...{inheritAttrs:!1},__name:"NcInputField",props:(0,n.zz)({class:{default:""},inputClass:{default:""},id:{default:()=>(0,h.c)()},label:{default:void 0},labelOutside:{type:Boolean},type:{default:"text"},placeholder:{default:void 0},showTrailingButton:{type:Boolean},trailingButtonLabel:{default:void 0},success:{type:Boolean},error:{type:Boolean},helperText:{default:""},disabled:{type:Boolean},pill:{type:Boolean}},{modelValue:{required:!0},modelModifiers:{}}),emits:(0,n.zz)(["trailingButtonClick"],["update:modelValue"]),setup(t,{expose:e,emit:i}){let h=(0,n.fn)(t,"modelValue");e({focus:function(t){v.value.focus(t)},select:function(){v.value.select()}});let p=(0,n.OA)(),v=(0,n.rk)("input"),x=(0,n.EW)(()=>t.showTrailingButton||t.success),w=(0,n.EW)(()=>t.placeholder?t.placeholder:t.label?c.a?t.label:"":void 0),N=(0,n.EW)(()=>{let e=t.label||t.labelOutside;return e||(0,n.R8)("You need to add a label to the NcInputField component. Either use the prop label or use an external one, as per the example in the documentation."),e}),_=(0,n.EW)(()=>{let e=[];return t.helperText&&e.push(`${t.id}-helper-text`),p["aria-describedby"]&&e.push(String(p["aria-describedby"])),e.join(" ")||void 0});function S(e){let i=e.target;h.value="number"===t.type&&"number"==typeof h.value?parseFloat(i.value):i.value}return(e,p)=>((0,n.uX)(),(0,n.CE)("div",{class:(0,r.normalizeClass)(["input-field",[{"input-field--disabled":t.disabled,"input-field--error":t.error,"input-field--label-outside":t.labelOutside||!N.value,"input-field--leading-icon":!!e.$slots.icon,"input-field--trailing-icon":x.value,"input-field--pill":t.pill,"input-field--success":t.success,"input-field--legacy":(0,o.R1)(c.a)},e.$props.class]])},[(0,n.Lk)("div",d,[(0,n.Lk)("input",(0,n.v6)(e.$attrs,{id:t.id,ref:"input","aria-describedby":_.value,"aria-live":"polite",class:["input-field__input",t.inputClass],disabled:t.disabled,placeholder:w.value,type:t.type,value:h.value.toString(),onInput:S}),null,16,f),!t.labelOutside&&N.value?((0,n.uX)(),(0,n.CE)("label",{key:0,class:"input-field__label",for:t.id},(0,r.toDisplayString)(t.label),9,g)):(0,n.Q3)("",!0),(0,n.bo)((0,n.Lk)("div",m,[(0,n.RG)(e.$slots,"icon",{},void 0,!0)],512),[[s.vShow,!!e.$slots.icon]]),t.showTrailingButton?((0,n.uX)(),(0,n.Wv)(l.N,{key:1,class:"input-field__trailing-button","aria-label":t.trailingButtonLabel,disabled:t.disabled,variant:"tertiary-no-background",onClick:p[0]||(p[0]=t=>i("trailingButtonClick",t))},{icon:(0,n.k6)(()=>[(0,n.RG)(e.$slots,"trailing-button-icon",{},void 0,!0)]),_:3},8,["aria-label","disabled"])):t.success||t.error?((0,n.uX)(),(0,n.CE)("div",y,[t.success?((0,n.uX)(),(0,n.Wv)(u.N,{key:0,path:(0,o.R1)(a.d)},null,8,["path"])):((0,n.uX)(),(0,n.Wv)(u.N,{key:1,path:(0,o.R1)(a.j)},null,8,["path"]))])):(0,n.Q3)("",!0)]),t.helperText?((0,n.uX)(),(0,n.CE)("p",{key:0,id:`${t.id}-helper-text`,class:"input-field__helper-text-message"},[t.success?((0,n.uX)(),(0,n.Wv)(u.N,{key:0,class:"input-field__helper-text-message__icon",path:(0,o.R1)(a.d),inline:""},null,8,["path"])):t.error?((0,n.uX)(),(0,n.Wv)(u.N,{key:1,class:"input-field__helper-text-message__icon",path:(0,o.R1)(a.j),inline:""},null,8,["path"])):(0,n.Q3)("",!0),(0,n.eW)(" "+(0,r.toDisplayString)(t.helperText),1)],8,b)):(0,n.Q3)("",!0)],2))}}),x=(0,p._)(v,[["__scopeId","data-v-8e16cbb5"]]);i.d(e,{},{N:x})},64535(t,e,i){var n=i(20641),r=i(50953),o=i(98190),s=i(29504),a=i(87485),l=i(63814),u=i(46855),h=i(51012),c=i(26089),p=i(22436),d=i(3168),f=i(52697);(0,p.r)(p.n);let g=(0,n.pM)({__name:"NcPasswordField",props:(0,n.zz)({class:{},inputClass:{default:""},id:{},label:{},labelOutside:{type:Boolean},placeholder:{},showTrailingButton:{type:Boolean,default:!0},success:{type:Boolean},error:{type:Boolean},helperText:{},disabled:{type:Boolean},pill:{type:Boolean},checkPasswordStrength:{type:Boolean},minlength:{default:void 0},asText:{type:Boolean}},{modelValue:{default:""},modelModifiers:{},visible:{type:Boolean,default:!1},visibleModifiers:{}}),emits:(0,n.zz)(["valid","invalid"],["update:modelValue","update:visible"]),setup(t,{expose:e,emit:i}){let f=(0,n.fn)(t,"modelValue"),g=(0,n.fn)(t,"visible");e({focus:function(t){y.value.focus(t)},select:function(){y.value.select()}});let{password_policy:m}=(0,a.F)(),y=(0,n.rk)("inputField"),b=(0,r.KR)(""),v=(0,r.KR)(),x=(0,n.EW)(()=>{let e={...t};return delete e.checkPasswordStrength,delete e.minlength,delete e.asText,delete e.error,delete e.helperText,delete e.inputClass,delete e.success,e}),w=(0,n.EW)(()=>t.minlength??(t.checkPasswordStrength?m?.minLength:void 0)??void 0);async function N(){if(t.checkPasswordStrength&&f.value)try{let{data:t}=await s.Ay.post((0,l.KT)("apps/password_policy/api/v1/validate"),{password:f.value});if(v.value=t.ocs.data.passed,t.ocs.data.passed){b.value=(0,p.a)("Password is secure"),i("valid");return}b.value=t.ocs.data.reason,i("invalid")}catch(t){d.l.error("Password policy returned an error",{error:t})}}function _(){g.value=!g.value}return(0,n.wB)(f,()=>{v.value=void 0,b.value=""}),(0,n.wB)(f,(0,u.A)(N,500)),(e,i)=>((0,n.uX)(),(0,n.Wv)(c.N,(0,n.v6)(x.value,{ref:"inputField",modelValue:f.value,"onUpdate:modelValue":i[0]||(i[0]=t=>f.value=t),error:t.error||!1===v.value,helperText:t.helperText||b.value,inputClass:[t.inputClass,{"password-field__input--secure-text":!g.value&&t.asText}],minlength:w.value,success:t.success||!0===v.value,trailingButtonLabel:g.value?(0,r.R1)(p.a)("Hide password"):(0,r.R1)(p.a)("Show password"),type:g.value||t.asText?"text":"password",onTrailingButtonClick:_}),(0,n.eX)({"trailing-button-icon":(0,n.k6)(()=>[(0,n.bF)(h.N,{path:g.value?(0,r.R1)(o.q):(0,r.R1)(o.r)},null,8,["path"])]),_:2},[e.$slots.icon?{name:"icon",fn:(0,n.k6)(()=>[(0,n.RG)(e.$slots,"icon",{},void 0,!0)]),key:"0"}:void 0]),1040,["modelValue","error","helperText","inputClass","minlength","success","trailingButtonLabel","type"]))}}),m=(0,f._)(g,[["__scopeId","data-v-cb828737"]]);i.d(e,{},{N:m})},15205(t,e,i){let n;i.d(e,{N:()=>tP});var r=i(97193),o=i(95361);function s(){return"u">typeof window}function a(t){return h(t)?(t.nodeName||"").toLowerCase():"#document"}function l(t){var e;return(null==t||null==(e=t.ownerDocument)?void 0:e.defaultView)||window}function u(t){var e;return null==(e=(h(t)?t.ownerDocument:t.document)||window.document)?void 0:e.documentElement}function h(t){return!!s()&&(t instanceof Node||t instanceof l(t).Node)}function c(t){return!!s()&&(t instanceof Element||t instanceof l(t).Element)}function p(t){return!!s()&&(t instanceof HTMLElement||t instanceof l(t).HTMLElement)}function d(t){return!(!s()||"u"<typeof ShadowRoot)&&(t instanceof ShadowRoot||t instanceof l(t).ShadowRoot)}function f(t){let{overflow:e,overflowX:i,overflowY:n,display:r}=N(t);return/auto|scroll|overlay|hidden|clip/.test(e+n+i)&&"inline"!==r&&"contents"!==r}function g(t){try{if(t.matches(":popover-open"))return!0}catch(t){}try{return t.matches(":modal")}catch(t){return!1}}let m=/transform|translate|scale|rotate|perspective|filter/,y=/paint|layout|strict|content/,b=t=>!!t&&"none"!==t;function v(t){let e=c(t)?N(t):t;return b(e.transform)||b(e.translate)||b(e.scale)||b(e.rotate)||b(e.perspective)||!x()&&(b(e.backdropFilter)||b(e.filter))||m.test(e.willChange||"")||y.test(e.contain||"")}function x(){return null==n&&(n="u">typeof CSS&&CSS.supports&&CSS.supports("-webkit-backdrop-filter","none")),n}function w(t){return/^(html|body|#document)$/.test(a(t))}function N(t){return l(t).getComputedStyle(t)}function _(t){return c(t)?{scrollLeft:t.scrollLeft,scrollTop:t.scrollTop}:{scrollLeft:t.scrollX,scrollTop:t.scrollY}}function S(t){if("html"===a(t))return t;let e=t.assignedSlot||t.parentNode||d(t)&&t.host||u(t);return d(e)?e.host:e}function E(t,e,i){var n;void 0===e&&(e=[]),void 0===i&&(i=!0);let r=function t(e){let i=S(e);return w(i)?e.ownerDocument?e.ownerDocument.body:e.body:p(i)&&f(i)?i:t(i)}(t),o=r===(null==(n=t.ownerDocument)?void 0:n.body),s=l(r);if(!o)return e.concat(r,E(r,[],i));{let t=C(s);return e.concat(s,s.visualViewport||[],f(r)?r:[],t&&i?E(t):[])}}function C(t){return t.parent&&Object.getPrototypeOf(t.parent)?t.frameElement:null}function P(t){let e=N(t),i=parseFloat(e.width)||0,n=parseFloat(e.height)||0,o=p(t),s=o?t.offsetWidth:i,a=o?t.offsetHeight:n,l=(0,r.LI)(i)!==s||(0,r.LI)(n)!==a;return l&&(i=s,n=a),{width:i,height:n,$:l}}function O(t){return c(t)?t:t.contextElement}function A(t){let e=O(t);if(!p(e))return(0,r.Jx)(1);let i=e.getBoundingClientRect(),{width:n,height:o,$:s}=P(e),a=(s?(0,r.LI)(i.width):i.width)/n,l=(s?(0,r.LI)(i.height):i.height)/o;return a&&Number.isFinite(a)||(a=1),l&&Number.isFinite(l)||(l=1),{x:a,y:l}}let T=(0,r.Jx)(0);function $(t){let e=l(t);return x()&&e.visualViewport?{x:e.visualViewport.offsetLeft,y:e.visualViewport.offsetTop}:T}function k(t,e,i,n){var o;void 0===e&&(e=!1),void 0===i&&(i=!1);let s=t.getBoundingClientRect(),a=O(t),u=(0,r.Jx)(1);e&&(n?c(n)&&(u=A(n)):u=A(t));let h=(void 0===(o=i)&&(o=!1),n&&(!o||n===l(a))&&o)?$(a):(0,r.Jx)(0),p=(s.left+h.x)/u.x,d=(s.top+h.y)/u.y,f=s.width/u.x,g=s.height/u.y;if(a){let t=l(a),e=n&&c(n)?l(n):n,i=t,r=C(i);for(;r&&n&&e!==i;){let t=A(r),e=r.getBoundingClientRect(),n=N(r),o=e.left+(r.clientLeft+parseFloat(n.paddingLeft))*t.x,s=e.top+(r.clientTop+parseFloat(n.paddingTop))*t.y;p*=t.x,d*=t.y,f*=t.x,g*=t.y,p+=o,d+=s,r=C(i=l(r))}}return(0,r.B1)({width:f,height:g,x:p,y:d})}function L(t,e){let i=_(t).scrollLeft;return e?e.left+i:k(u(t)).left+i}function j(t,e){let i=t.getBoundingClientRect();return{x:i.left+e.scrollLeft-L(t,i),y:i.top+e.scrollTop}}function I(t,e,i){var n;let o;if("viewport"===e)o=function(t,e){let i=l(t),n=u(t),r=i.visualViewport,o=n.clientWidth,s=n.clientHeight,a=0,h=0;if(r){o=r.width,s=r.height;let t=x();(!t||t&&"fixed"===e)&&(a=r.offsetLeft,h=r.offsetTop)}let c=L(n);if(c<=0){let t=n.ownerDocument,e=t.body,i=getComputedStyle(e),r="CSS1Compat"===t.compatMode&&parseFloat(i.marginLeft)+parseFloat(i.marginRight)||0,s=Math.abs(n.clientWidth-e.clientWidth-r);s<=25&&(o-=s)}else c<=25&&(o+=c);return{width:o,height:s,x:a,y:h}}(t,i);else if("document"===e){let e,i,s,a,l,h,c;n=u(t),e=u(n),i=_(n),s=n.ownerDocument.body,a=(0,r.T9)(e.scrollWidth,e.clientWidth,s.scrollWidth,s.clientWidth),l=(0,r.T9)(e.scrollHeight,e.clientHeight,s.scrollHeight,s.clientHeight),h=-i.scrollLeft+L(n),c=-i.scrollTop,"rtl"===N(s).direction&&(h+=(0,r.T9)(e.clientWidth,s.clientWidth)-a),o={width:a,height:l,x:h,y:c}}else if(c(e)){let t,n,s,a,l,u;n=(t=k(e,!0,"fixed"===i)).top+e.clientTop,s=t.left+e.clientLeft,a=p(e)?A(e):(0,r.Jx)(1),l=e.clientWidth*a.x,u=e.clientHeight*a.y,o={width:l,height:u,x:s*a.x,y:n*a.y}}else{let i=$(t);o={x:e.x-i.x,y:e.y-i.y,width:e.width,height:e.height}}return(0,r.B1)(o)}function R(t){return"static"===N(t).position}function D(t,e){if(!p(t)||"fixed"===N(t).position)return null;if(e)return e(t);let i=t.offsetParent;return u(t)===i&&(i=i.ownerDocument.body),i}function V(t,e){var i;let n=l(t);if(g(t))return n;if(!p(t)){let e=S(t);for(;e&&!w(e);){if(c(e)&&!R(e))return e;e=S(e)}return n}let r=D(t,e);for(;r&&(i=r,/^(table|td|th)$/.test(a(i)))&&R(r);)r=D(r,e);return r&&w(r)&&R(r)&&!v(r)?n:r||function(t){let e=S(t);for(;p(e)&&!w(e);){if(v(e))return e;if(g(e))break;e=S(e)}return null}(t)||n}let M=async function(t){let e=this.getOffsetParent||V,i=this.getDimensions,n=await i(t.floating);return{reference:function(t,e,i){let n=p(e),o=u(e),s="fixed"===i,l=k(t,!0,s,e),h={scrollLeft:0,scrollTop:0},c=(0,r.Jx)(0);if(n||!n&&!s)if(("body"!==a(e)||f(o))&&(h=_(e)),n){let t=k(e,!0,s,e);c.x=t.x+e.clientLeft,c.y=t.y+e.clientTop}else o&&(c.x=L(o));s&&!n&&o&&(c.x=L(o));let d=!o||n||s?(0,r.Jx)(0):j(o,h);return{x:l.left+h.scrollLeft-c.x-d.x,y:l.top+h.scrollTop-c.y-d.y,width:l.width,height:l.height}}(t.reference,await e(t.floating),t.strategy),floating:{x:0,y:0,width:n.width,height:n.height}}},B={convertOffsetParentRelativeRectToViewportRelativeRect:function(t){let{elements:e,rect:i,offsetParent:n,strategy:o}=t,s="fixed"===o,l=u(n),h=!!e&&g(e.floating);if(n===l||h&&s)return i;let c={scrollLeft:0,scrollTop:0},d=(0,r.Jx)(1),m=(0,r.Jx)(0),y=p(n);if((y||!y&&!s)&&(("body"!==a(n)||f(l))&&(c=_(n)),y)){let t=k(n);d=A(n),m.x=t.x+n.clientLeft,m.y=t.y+n.clientTop}let b=!l||y||s?(0,r.Jx)(0):j(l,c);return{width:i.width*d.x,height:i.height*d.y,x:i.x*d.x-c.scrollLeft*d.x+m.x+b.x,y:i.y*d.y-c.scrollTop*d.y+m.y+b.y}},getDocumentElement:u,getClippingRect:function(t){let{element:e,boundary:i,rootBoundary:n,strategy:o}=t,s=[..."clippingAncestors"===i?g(e)?[]:function(t,e){let i=e.get(t);if(i)return i;let n=E(t,[],!1).filter(t=>c(t)&&"body"!==a(t)),r=null,o="fixed"===N(t).position,s=o?S(t):t;for(;c(s)&&!w(s);){let e=N(s),i=v(s);i||"fixed"!==e.position||(r=null),(o?i||r:!(!i&&"static"===e.position&&r&&("absolute"===r.position||"fixed"===r.position)||f(s)&&!i&&function t(e,i){let n=S(e);return!(n===i||!c(n)||w(n))&&("fixed"===N(n).position||t(n,i))}(t,s)))?r=e:n=n.filter(t=>t!==s),s=S(s)}return e.set(t,n),n}(e,this._c):[].concat(i),n],l=I(e,s[0],o),u=l.top,h=l.right,p=l.bottom,d=l.left;for(let t=1;t<s.length;t++){let i=I(e,s[t],o);u=(0,r.T9)(i.top,u),h=(0,r.jk)(i.right,h),p=(0,r.jk)(i.bottom,p),d=(0,r.T9)(i.left,d)}return{width:h-d,height:p-u,x:d,y:u}},getOffsetParent:V,getElementRects:M,getClientRects:function(t){return Array.from(t.getClientRects())},getDimensions:function(t){let{width:e,height:i}=P(t);return{width:e,height:i}},getScale:A,isElement:c,isRTL:function(t){return"rtl"===N(t).direction}};function F(t,e){return t.x===e.x&&t.y===e.y&&t.width===e.width&&t.height===e.height}let U=o.cY,W=o.BN,z=o.UU,X=o.ER;var G=i(20641),q=i(90033),H=i(53751);let K=0,Q=(t,e)=>{let i=t.__vccOpts||t;for(let[t,n]of e)i[t]=n;return i},Y={xmlns:"http://www.w3.org/2000/svg",width:"10",height:"10"},J=Q({},[["render",function(t,e){return(0,G.uX)(),(0,G.CE)("svg",Y,[...e[0]||(e[0]=[(0,G.Lk)("path",{d:"M6.895455 5l2.842897-2.842898c.348864-.348863.348864-.914488 0-1.263636L9.106534.261648c-.348864-.348864-.914489-.348864-1.263636 0L5 3.104545 2.157102.261648c-.348863-.348864-.914488-.348864-1.263636 0L.261648.893466c-.348864.348864-.348864.914489 0 1.263636L3.104545 5 .261648 7.842898c-.348864.348863-.348864.914488 0 1.263636l.631818.631818c.348864.348864.914773.348864 1.263636 0L5 6.895455l2.842898 2.842897c.348863.348864.914772.348864 1.263636 0l.631818-.631818c.348864-.348864.348864-.914489 0-1.263636L6.895455 5z"},null,-1)])])}]]),Z={xmlns:"http://www.w3.org/2000/svg",width:"14",height:"10"},tt={Deselect:J,OpenIndicator:Q({},[["render",function(t,e){return(0,G.uX)(),(0,G.CE)("svg",Z,[...e[0]||(e[0]=[(0,G.Lk)("path",{d:"M9.211364 7.59931l4.48338-4.867229c.407008-.441854.407008-1.158247 0-1.60046l-.73712-.80023c-.407008-.441854-1.066904-.441854-1.474243 0L7 5.198617 2.51662.33139c-.407008-.441853-1.066904-.441853-1.474243 0l-.737121.80023c-.407008.441854-.407008 1.158248 0 1.600461l4.48338 4.867228L7 10l2.211364-2.40069z"},null,-1)])])}]])},te={components:{...tt},directives:{appendToBody:{mounted(t,{instance:e}){if(e.appendToBody){document.body.appendChild(t);let{height:i,top:n,left:r,width:o}=e.$refs.toggle.getBoundingClientRect(),s=window.scrollX||window.pageXOffset,a=window.scrollY||window.pageYOffset;t.unbindPosition=e.calculatePosition(t,e,{width:o+"px",left:s+r+"px",top:a+n+i+"px"})}},unmounted(t,{instance:e}){e.appendToBody&&(t.unbindPosition&&"function"==typeof t.unbindPosition&&t.unbindPosition(),t.parentNode&&t.parentNode.removeChild(t))}}},mixins:[{props:{autoscroll:{type:Boolean,default:!0}},watch:{typeAheadPointer(){this.autoscroll&&this.maybeAdjustScroll()},open(t){this.autoscroll&&t&&this.$nextTick(()=>this.maybeAdjustScroll())}},methods:{maybeAdjustScroll(){let t=this.$refs.dropdownMenu?.children[this.typeAheadPointer]||!1;if(t){let e=this.getDropdownViewport(),{top:i,bottom:n,height:r}=t.getBoundingClientRect();if(i<e.top)return this.$refs.dropdownMenu.scrollTop=t.offsetTop;if(n>e.bottom)return this.$refs.dropdownMenu.scrollTop=t.offsetTop-(e.height-r)}},getDropdownViewport(){return this.$refs.dropdownMenu?this.$refs.dropdownMenu.getBoundingClientRect():{height:0,top:0,bottom:0}}}},{data:()=>({typeAheadPointer:-1}),watch:{filteredOptions(){if(this.resetFocusOnOptionsChange){for(let t=0;t<this.filteredOptions.length;t++)if(this.selectable(this.filteredOptions[t])){this.typeAheadPointer=t;break}}},open(t){t&&this.typeAheadToLastSelected()},selectedValue(){this.open&&this.typeAheadToLastSelected()}},methods:{typeAheadUp(){for(let t=this.typeAheadPointer-1;t>=0;t--)if(this.selectable(this.filteredOptions[t])){this.typeAheadPointer=t;break}},typeAheadDown(){for(let t=this.typeAheadPointer+1;t<this.filteredOptions.length;t++)if(this.selectable(this.filteredOptions[t])){this.typeAheadPointer=t;break}},typeAheadSelect(){let t=this.filteredOptions[this.typeAheadPointer];t&&this.selectable(t)&&this.select(t)},typeAheadToLastSelected(){let t=0!==this.selectedValue.length?this.filteredOptions.indexOf(this.selectedValue[this.selectedValue.length-1]):-1;-1!==t&&(this.typeAheadPointer=t)}}},{props:{loading:{type:Boolean,default:!1}},data:()=>({mutableLoading:!1}),watch:{search(){this.$emit("search",this.search,this.toggleLoading)},loading(t){this.mutableLoading=t}},methods:{toggleLoading(t=null){return null==t?this.mutableLoading=!this.mutableLoading:this.mutableLoading=t}}}],props:{modelValue:{},components:{type:Object,default:()=>({})},options:{type:Array,default:()=>[]},limit:{type:Number,default:null},disabled:{type:Boolean,default:!1},clearable:{type:Boolean,default:!0},deselectFromDropdown:{type:Boolean,default:!1},searchable:{type:Boolean,default:!0},multiple:{type:Boolean,default:!1},placeholder:{type:String,default:""},transition:{type:String,default:"vs__fade"},clearSearchOnSelect:{type:Boolean,default:!0},closeOnSelect:{type:Boolean,default:!0},label:{type:String,default:"label"},ariaLabelCombobox:{type:String,default:"Search for options"},ariaLabelListbox:{type:String,default:"Options"},ariaLabelClearSelected:{type:String,default:"Clear selected"},ariaLabelDeselectOption:{type:Function,default:t=>`Deselect ${t}`},autocomplete:{type:String,default:"off"},reduce:{type:Function,default:t=>t},selectable:{type:Function,default:()=>!0},getOptionLabel:{type:Function,default(t){return"object"==typeof t?Object.hasOwn(t,this.label)?t[this.label]:(0,G.R8)(`[vue-select warn]: Label key "option.${this.label}" does not exist in options object ${JSON.stringify(t)}.
https://vue-select.org/api/props.html#getoptionlabel`):t}},getOptionKey:{type:Function,default(t){if("object"!=typeof t)return t;try{let e;return Object.hasOwn(t,"id")?t.id:(e={},Object.keys(t).sort().forEach(i=>{e[i]=t[i]}),JSON.stringify(e))}catch(e){return(0,G.R8)("[vue-select warn]: Could not stringify this option to generate unique key. Please provide'getOptionKey' prop to return a unique key for each option.\nhttps://vue-select.org/api/props.html#getoptionkey",t,e)}}},onTab:{type:Function,default(){this.selectOnTab&&!this.isComposing&&this.typeAheadSelect()}},taggable:{type:Boolean,default:!1},tabindex:{type:Number,default:null},pushTags:{type:Boolean,default:!1},filterable:{type:Boolean,default:!0},filterBy:{type:Function,default:(t,e,i)=>(e||"").toLocaleLowerCase().indexOf(i.toLocaleLowerCase())>-1},filter:{type:Function,default(t,e){return t.filter(t=>{let i=this.getOptionLabel(t);return"number"==typeof i&&(i=i.toString()),this.filterBy(t,i,e)})}},createOption:{type:Function,default(t){return"object"==typeof this.optionList[0]?{[this.label]:t}:t}},resetFocusOnOptionsChange:{type:Boolean,default:!0},resetOnOptionsChange:{default:!1,validator:t=>["function","boolean"].includes(typeof t)},clearSearchOnBlur:{type:Function,default:({clearSearchOnSelect:t,multiple:e})=>t&&!e},noDrop:{type:Boolean,default:!1},inputId:{type:String},dir:{type:String,default:"auto"},selectOnTab:{type:Boolean,default:!1},selectOnKeyCodes:{type:Array,default:()=>[13]},searchInputQuerySelector:{type:String,default:"[type=search]"},mapKeydown:{type:Function,default:t=>t},appendToBody:{type:Boolean,default:!1},calculatePosition:{type:Function,default(t,e,{width:i,top:n,left:r}){t.style.top=n,t.style.left=r,t.style.width=i}},dropdownShouldOpen:{type:Function,default:({noDrop:t,open:e,mutableLoading:i})=>!t&&e&&!i},keyboardFocusBorder:{type:Boolean,default:!1},uid:{type:[String,Number],default:()=>++K}},emits:["open","close","update:modelValue","search","search:compositionstart","search:compositionend","search:keydown","search:blur","search:focus","search:input","option:created","option:selecting","option:selected","option:deselecting","option:deselected"],data:()=>({search:"",open:!1,isComposing:!1,isKeyboardNavigation:!1,pushedTags:[],_value:[],deselectButtons:[]}),computed:{isReducingValues(){return this.$props.reduce!==this.$options.props.reduce.default},isTrackingValues(){return void 0===this.modelValue||this.isReducingValues},selectedValue(){let t=this.modelValue;return(this.isTrackingValues&&(t=this.$data._value),null!=t&&""!==t)?[].concat(t):[]},optionList(){return this.options.concat(this.pushTags?this.pushedTags:[])},searchEl(){return this.$slots.search?this.$refs.selectedOptions.querySelector(this.searchInputQuerySelector):this.$refs.search},scope(){let t={search:this.search,loading:this.loading,searching:this.searching,filteredOptions:this.filteredOptions};return{search:{attributes:{id:this.inputId,disabled:this.disabled,placeholder:this.searchPlaceholder,tabindex:this.tabindex,readonly:!this.searchable,role:"combobox","aria-autocomplete":"list","aria-label":this.ariaLabelCombobox,"aria-controls":`vs-${this.uid}__listbox`,"aria-owns":`vs-${this.uid}__listbox`,"aria-expanded":this.dropdownOpen.toString(),ref:"search",type:"search",autocomplete:this.autocomplete,value:this.search,...this.dropdownOpen&&this.filteredOptions[this.typeAheadPointer]?{"aria-activedescendant":`vs-${this.uid}__option-${this.typeAheadPointer}`}:{}},events:{compositionstart:()=>this.isComposing=!0,compositionend:()=>this.isComposing=!1,keydown:this.onSearchKeyDown,keypress:this.onSearchKeyPress,blur:this.onSearchBlur,focus:this.onSearchFocus,input:t=>this.search=t.target.value}},spinner:{loading:this.mutableLoading},noOptions:{search:this.search,loading:this.mutableLoading,searching:this.searching},openIndicator:{attributes:{ref:"openIndicator",role:"presentation",class:"vs__open-indicator"}},listHeader:t,listFooter:t,header:{...t,deselect:this.deselect},footer:{...t,deselect:this.deselect}}},childComponents(){return{...tt,...this.components}},stateClasses(){return{"vs--open":this.dropdownOpen,"vs--single":!this.multiple,"vs--multiple":this.multiple,"vs--searching":this.searching&&!this.noDrop,"vs--searchable":this.searchable&&!this.noDrop,"vs--unsearchable":!this.searchable,"vs--loading":this.mutableLoading,"vs--disabled":this.disabled}},searching(){return!!this.search},dropdownOpen(){return this.dropdownShouldOpen(this)},searchPlaceholder(){return this.isValueEmpty&&this.placeholder?this.placeholder:void 0},filteredOptions(){let t=t=>null!==this.limit?t.slice(0,this.limit):t,e=[].concat(this.optionList);if(!this.filterable&&!this.taggable)return t(e);let i=this.search.length?this.filter(e,this.search,this):e;if(this.taggable&&this.search.length)try{let t=this.createOption(this.search);this.optionExists(t)||i.unshift(t)}catch{}return t(i)},isValueEmpty(){return 0===this.selectedValue.length},showClearButton(){return!this.multiple&&this.clearable&&!this.open&&!this.isValueEmpty}},watch:{options(t,e){let i=()=>"function"==typeof this.resetOnOptionsChange?this.resetOnOptionsChange(t,e,this.selectedValue):this.resetOnOptionsChange;!this.taggable&&i()&&this.clearSelection(),this.modelValue&&this.isTrackingValues&&this.setInternalValueFromOptions(this.modelValue)},modelValue:{immediate:!0,handler(t){this.isTrackingValues&&this.setInternalValueFromOptions(t)}},multiple(){this.clearSelection()},open(t){this.$emit(t?"open":"close")},search(t){t.length&&(this.open=!0)}},created(){this.mutableLoading=this.loading},methods:{setInternalValueFromOptions(t){Array.isArray(t)?this.$data._value=t.map(t=>this.findOptionFromReducedValue(t)):this.$data._value=this.findOptionFromReducedValue(t)},select(t){this.$emit("option:selecting",t),this.isOptionSelected(t)?this.deselectFromDropdown&&(this.clearable||this.multiple&&this.selectedValue.length>1)&&this.deselect(t):(this.taggable&&!this.optionExists(t)&&(this.$emit("option:created",t),this.pushTag(t)),this.multiple&&(t=this.selectedValue.concat(t)),this.updateValue(t),this.$emit("option:selected",t)),this.onAfterSelect(t)},deselect(t){this.$emit("option:deselecting",t),this.updateValue(this.selectedValue.filter(e=>!this.optionComparator(e,t))),this.$emit("option:deselected",t)},keyboardDeselect(t,e){this.deselect(t);let i=this.deselectButtons?.[e+1],n=this.deselectButtons?.[e-1],r=i??n;r?r.focus():this.searchEl.focus()},clearSelection(){this.updateValue(this.multiple?[]:null),this.searchEl.focus()},onAfterSelect(){this.closeOnSelect&&(this.open=!this.open),this.clearSearchOnSelect&&(this.search=""),this.noDrop&&this.multiple&&this.$nextTick(()=>this.$refs.search.focus())},updateValue(t){void 0===this.modelValue&&(this.$data._value=t),null!==t&&(t=Array.isArray(t)?t.map(t=>this.reduce(t)):this.reduce(t)),this.$emit("update:modelValue",t)},toggleDropdown(t){let e=t.target!==this.searchEl;e&&t.preventDefault();let i=[...this.deselectButtons||[],...this.$refs.clearButton?[this.$refs.clearButton]:[]];void 0===this.searchEl||i.filter(Boolean).some(e=>e.contains(t.target)||e===t.target)?t.preventDefault():this.open&&e?(this.open=!1,this.searchEl.blur()):this.disabled||(this.open=!0,this.searchEl.focus())},isOptionSelected(t){return this.selectedValue.some(e=>this.optionComparator(e,t))},isOptionDeselectable(t){return this.isOptionSelected(t)&&this.deselectFromDropdown},hasKeyboardFocusBorder(t){return!!this.keyboardFocusBorder&&!!this.isKeyboardNavigation&&t===this.typeAheadPointer},optionComparator(t,e){return this.getOptionKey(t)===this.getOptionKey(e)},findOptionFromReducedValue(t){let e=e=>JSON.stringify(this.reduce(e))===JSON.stringify(t),i=[...this.options,...this.pushedTags].filter(e);return 1===i.length?i[0]:i.find(t=>this.optionComparator(t,this.$data._value))||t},closeSearchOptions(){this.open=!1,this.$emit("search:blur")},maybeDeleteValue(){if(!this.searchEl.value.length&&this.selectedValue&&this.selectedValue.length&&this.clearable){let t=null;this.multiple&&(t=[...this.selectedValue.slice(0,this.selectedValue.length-1)]),this.updateValue(t)}},optionExists(t){return this.optionList.some(e=>this.optionComparator(e,t))},optionAriaSelected(t){return this.selectable(t)?String(this.isOptionSelected(t)):null},normalizeOptionForSlot(t){return"object"==typeof t?t:{[this.label]:t}},pushTag(t){this.pushedTags.push(t)},onEscape(){this.search.length?this.search="":this.open=!1},onSearchBlur(){if(this.mousedown&&!this.searching)this.mousedown=!1;else{let{clearSearchOnSelect:t,multiple:e}=this;this.clearSearchOnBlur({clearSearchOnSelect:t,multiple:e})&&(this.search=""),this.closeSearchOptions();return}0===this.search.length&&0===this.options.length&&this.closeSearchOptions()},onSearchFocus(){this.$emit("search:focus")},onMousedown(){this.mousedown=!0},onMouseUp(){this.mousedown=!1},onMouseMove(t,e){this.isKeyboardNavigation=!1,this.selectable(t)&&(this.typeAheadPointer=e)},onSearchKeyDown(t){let e=t=>{if(t.preventDefault(),!this.open){this.open=!0;return}return!this.isComposing&&this.typeAheadSelect()},i={8:()=>this.maybeDeleteValue(),9:()=>this.onTab(),27:()=>this.onEscape(),38:t=>{if(t.preventDefault(),this.isKeyboardNavigation=!0,!this.open){this.open=!0;return}return this.typeAheadUp()},40:t=>{if(t.preventDefault(),this.isKeyboardNavigation=!0,!this.open){this.open=!0;return}return this.typeAheadDown()}};this.selectOnKeyCodes.forEach(t=>i[t]=e);let n=this.mapKeydown(i,this);if("function"==typeof n[t.keyCode])return n[t.keyCode](t)},onSearchKeyPress(t){this.open||32!==t.keyCode||(t.preventDefault(),this.open=!0)}}},ti=["id","dir"],tn={ref:"toggle",class:"vs__dropdown-toggle"},tr=["disabled","title","aria-label","onMousedown","onKeydown"],to={ref:"actions",class:"vs__actions"},ts=["disabled","title","aria-label"],ta={class:"vs__spinner"},tl=["id","aria-label","aria-multiselectable"],tu=["id","aria-selected","onMousemove","onClick"],th={key:0,class:"vs__no-options"},tc=["id","aria-label"],tp=Q(te,[["render",function(t,e,i,n,r,o){let s=(0,G.gN)("append-to-body");return(0,G.uX)(),(0,G.CE)("div",{id:`v-select-${i.uid}`,dir:i.dir,class:(0,q.normalizeClass)(["v-select",o.stateClasses])},[(0,G.RG)(t.$slots,"header",(0,q.normalizeProps)((0,G.Ng)(o.scope.header))),(0,G.Lk)("div",tn,[(0,G.Lk)("div",{ref:"selectedOptions",class:"vs__selected-options",onMousedown:e[0]||(e[0]=(...t)=>o.toggleDropdown&&o.toggleDropdown(...t))},[((0,G.uX)(!0),(0,G.CE)(G.FK,null,(0,G.pI)(o.selectedValue,(e,n)=>(0,G.RG)(t.$slots,"selected-option-container",{option:o.normalizeOptionForSlot(e),deselect:o.deselect,multiple:i.multiple,disabled:i.disabled},()=>[((0,G.uX)(),(0,G.CE)("span",{key:i.getOptionKey(e),class:"vs__selected"},[(0,G.RG)(t.$slots,"selected-option",(0,G.v6)({ref_for:!0},o.normalizeOptionForSlot(e)),()=>[(0,G.eW)((0,q.toDisplayString)(i.getOptionLabel(e)),1)]),i.multiple?((0,G.uX)(),(0,G.CE)("button",{key:0,ref_for:!0,ref:t=>r.deselectButtons[n]=t,disabled:i.disabled,type:"button",class:"vs__deselect",title:i.ariaLabelDeselectOption(i.getOptionLabel(e)),"aria-label":i.ariaLabelDeselectOption(i.getOptionLabel(e)),onMousedown:(0,H.withModifiers)(t=>o.deselect(e),["stop"]),onKeydown:(0,H.withKeys)(t=>o.keyboardDeselect(e,n),["enter"])},[((0,G.uX)(),(0,G.Wv)((0,G.$y)(o.childComponents.Deselect)))],40,tr)):(0,G.Q3)("",!0)]))])),256)),(0,G.RG)(t.$slots,"search",(0,q.normalizeProps)((0,G.Ng)(o.scope.search)),()=>[(0,G.Lk)("input",(0,G.v6)({class:"vs__search"},o.scope.search.attributes,(0,G.Tb)(o.scope.search.events,!0)),null,16)])],544),(0,G.Lk)("div",to,[(0,G.bo)((0,G.Lk)("button",{ref:"clearButton",disabled:i.disabled,type:"button",class:"vs__clear",title:i.ariaLabelClearSelected,"aria-label":i.ariaLabelClearSelected,onClick:e[1]||(e[1]=(...t)=>o.clearSelection&&o.clearSelection(...t))},[((0,G.uX)(),(0,G.Wv)((0,G.$y)(o.childComponents.Deselect)))],8,ts),[[H.vShow,o.showClearButton]]),i.noDrop?(0,G.Q3)("",!0):((0,G.uX)(),(0,G.CE)("button",{key:0,ref:"openIndicatorButton",class:"vs__open-indicator-button",type:"button",tabindex:"-1","aria-hidden":"true",onMousedown:e[2]||(e[2]=(...t)=>o.toggleDropdown&&o.toggleDropdown(...t))},[(0,G.RG)(t.$slots,"open-indicator",(0,q.normalizeProps)((0,G.Ng)(o.scope.openIndicator)),()=>[((0,G.uX)(),(0,G.Wv)((0,G.$y)(o.childComponents.OpenIndicator),(0,q.normalizeProps)((0,G.Ng)(o.scope.openIndicator.attributes)),null,16))])],544)),(0,G.RG)(t.$slots,"spinner",(0,q.normalizeProps)((0,G.Ng)(o.scope.spinner)),()=>[(0,G.bo)((0,G.Lk)("div",ta," Loading... ",512),[[H.vShow,t.mutableLoading]])])],512)],512),(0,G.bF)(H.Transition,{name:i.transition},{default:(0,G.k6)(()=>[o.dropdownOpen?(0,G.bo)(((0,G.uX)(),(0,G.CE)("ul",{id:`vs-${i.uid}__listbox`,ref:"dropdownMenu",key:`vs-${i.uid}__listbox`,class:"vs__dropdown-menu",role:"listbox","aria-label":i.ariaLabelListbox,"aria-multiselectable":i.multiple?"true":null,tabindex:"-1",onMousedown:e[3]||(e[3]=(0,H.withModifiers)((...t)=>o.onMousedown&&o.onMousedown(...t),["prevent"])),onMouseup:e[4]||(e[4]=(...t)=>o.onMouseUp&&o.onMouseUp(...t))},[(0,G.RG)(t.$slots,"list-header",(0,q.normalizeProps)((0,G.Ng)(o.scope.listHeader))),((0,G.uX)(!0),(0,G.CE)(G.FK,null,(0,G.pI)(o.filteredOptions,(e,n)=>((0,G.uX)(),(0,G.CE)("li",{id:`vs-${i.uid}__option-${n}`,key:i.getOptionKey(e),role:"option",class:(0,q.normalizeClass)(["vs__dropdown-option",{"vs__dropdown-option--deselect":o.isOptionDeselectable(e)&&n===t.typeAheadPointer,"vs__dropdown-option--selected":o.isOptionSelected(e),"vs__dropdown-option--highlight":n===t.typeAheadPointer,"vs__dropdown-option--kb-focus":o.hasKeyboardFocusBorder(n),"vs__dropdown-option--disabled":!i.selectable(e)}]),"aria-selected":o.optionAriaSelected(e),onMousemove:t=>o.onMouseMove(e,n),onClick:(0,H.withModifiers)(t=>i.selectable(e)?o.select(e):null,["prevent","stop"])},[(0,G.RG)(t.$slots,"option",(0,G.v6)({ref_for:!0},o.normalizeOptionForSlot(e)),()=>[(0,G.eW)((0,q.toDisplayString)(i.getOptionLabel(e)),1)])],42,tu))),128)),0===o.filteredOptions.length?((0,G.uX)(),(0,G.CE)("li",th,[(0,G.RG)(t.$slots,"no-options",(0,q.normalizeProps)((0,G.Ng)(o.scope.noOptions)),()=>[e[5]||(e[5]=(0,G.eW)(" Sorry, no matching options. ",-1))])])):(0,G.Q3)("",!0),(0,G.RG)(t.$slots,"list-footer",(0,q.normalizeProps)((0,G.Ng)(o.scope.listFooter)))],40,tl)),[[s]]):((0,G.uX)(),(0,G.CE)("ul",{key:1,id:`vs-${i.uid}__listbox`,role:"listbox","aria-label":i.ariaLabelListbox,style:{display:"none",visibility:"hidden"}},null,8,tc))]),_:3},8,["name"]),(0,G.RG)(t.$slots,"footer",(0,q.normalizeProps)((0,G.Ng)(o.scope.footer)))],10,ti)}]]);var td=i(8273),tf=i(31564),tg=i(42531),tm=i(52697);let ty={name:"NcEllipsisedOption",components:{NcHighlight:tg._},props:{name:{type:String,default:""},search:{type:String,default:""}},computed:{needsTruncate(){return this.name&&this.name.length>=10},split(){return this.name.length-Math.min(Math.floor(this.name.length/2),10)},part1(){return this.needsTruncate?this.name.slice(0,this.split):this.name},part2(){return this.needsTruncate?this.name.slice(this.split):""},highlight1(){return this.search?(0,tg.f)(this.name,this.search):[]},highlight2(){return this.highlight1.map(t=>({start:t.start-this.split,end:t.end-this.split}))}}},tb=["title"],tv=(0,tm._)(ty,[["render",function(t,e,i,n,r,o){let s=(0,G.g2)("NcHighlight");return(0,G.uX)(),(0,G.CE)("span",{dir:"auto",class:"name-parts",title:i.name},[(0,G.bF)(s,{class:"name-parts__first",text:o.part1,search:i.search,highlight:o.highlight1},null,8,["text","search","highlight"]),o.part2?((0,G.uX)(),(0,G.Wv)(s,{key:0,class:"name-parts__last",text:o.part2,search:i.search,highlight:o.highlight2},null,8,["text","search","highlight"])):(0,G.Q3)("",!0)],8,tb)}],["__scopeId","data-v-a612f185"]]);var tx=i(78799),tw=i(22436),tN=i(34163),t_=i(26096);(0,tw.r)(tw.g);let tS={name:"NcSelect",components:{ChevronDown:td.C,NcEllipsisedOption:tv,NcLoadingIcon:tx.N,VueSelect:tp},props:{...tp.props,...tp.mixins.reduce((t,e)=>({...t,...e.props}),{}),ariaLabelClearSelected:{type:String,default:(0,tw.a)("Clear selected")},ariaLabelCombobox:{type:String,default:null},ariaLabelListbox:{type:String,default:(0,tw.a)("Options")},ariaLabelDeselectOption:{type:Function,default:t=>(0,tw.a)("Deselect {option}",{option:t})},appendToBody:{type:Boolean,default:!0},calculatePosition:{type:Function,default:null},keepOpen:{type:Boolean,default:!1},components:{type:Object,default:()=>({Deselect:{render:()=>(0,G.h)(tf.I,{size:20,fillColor:"var(--vs-controls-color)",style:[{cursor:"pointer"}]})}})},limit:{type:Number,default:null},disabled:{type:Boolean,default:!1},dropdownShouldOpen:{type:Function,default:({noDrop:t,open:e})=>!t&&e},filterBy:{type:Function,default:null},inputClass:{type:[String,Object],default:null},inputId:{type:String,default:()=>(0,tN.c)()},inputLabel:{type:String,default:null},labelOutside:{type:Boolean,default:!1},keyboardFocusBorder:{type:Boolean,default:!0},label:{type:String,default:null},loading:{type:Boolean,default:!1},multiple:{type:Boolean,default:!1},noWrap:{type:Boolean,default:!1},options:{type:Array,default:()=>[]},placeholder:{type:String,default:""},mapKeydown:{type:Function,default:(t,e)=>({...t,27:i=>{e.open&&i.stopPropagation(),t[27](i)}})},uid:{type:String,default:()=>(0,tN.c)()},placement:{type:String,default:"bottom"},resetFocusOnOptionsChange:{type:Boolean,default:!0},modelValue:{type:[String,Number,Object,Array],default:null},required:{type:Boolean,default:!1}," ":{}},emits:[" ","update:modelValue"],setup:()=>({avatarSize:Number.parseInt(window.getComputedStyle(document.body).getPropertyValue("--default-clickable-area"))-2*Number.parseInt(window.getComputedStyle(document.body).getPropertyValue("--default-grid-baseline")),isLegacy:t_.a}),data:()=>({search:""}),computed:{inputRequired(){return this.required?null===this.modelValue||Array.isArray(this.modelValue)&&0===this.modelValue.length:null},localCalculatePosition(){return null!==this.calculatePosition?this.calculatePosition:(t,e,{width:i})=>{t.style.width=i;let n={name:"addClass",fn:()=>(t.classList.add("vs__dropdown-menu--floating"),{})},s={name:"togglePlacementClass",fn:({placement:i})=>(e.$el.classList.toggle("select--drop-up","top"===i),t.classList.toggle("vs__dropdown-menu--floating-placement-top","top"===i),{})},a=()=>{var i,r;let a,l,u;(i=e.$refs.toggle,r={placement:this.placement,middleware:[U(-1),n,s,z(),W({limiter:X()})]},a=new Map,u={...(l={platform:B,...r}).platform,_c:a},(0,o.rD)(i,t,{...l,platform:u})).then(({x:i,y:n})=>{Object.assign(t.style,{left:`${i}px`,top:`${n}px`,width:`${e.$refs.toggle.getBoundingClientRect().width}px`})})};return function(t,e,i,n){let o;void 0===n&&(n={});let{ancestorScroll:s=!0,ancestorResize:a=!0,elementResize:l="function"==typeof ResizeObserver,layoutShift:h="function"==typeof IntersectionObserver,animationFrame:c=!1}=n,p=O(t),d=s||a?[...p?E(p):[],...e?E(e):[]]:[];d.forEach(t=>{s&&t.addEventListener("scroll",i,{passive:!0}),a&&t.addEventListener("resize",i)});let f=p&&h?function(t,e){let i,n=null,o=u(t);function s(){var t;clearTimeout(i),null==(t=n)||t.disconnect(),n=null}return!function a(l,u){void 0===l&&(l=!1),void 0===u&&(u=1),s();let h=t.getBoundingClientRect(),{left:c,top:p,width:d,height:f}=h;if(l||e(),!d||!f)return;let g={rootMargin:-(0,r.RI)(p)+"px "+-(0,r.RI)(o.clientWidth-(c+d))+"px "+-(0,r.RI)(o.clientHeight-(p+f))+"px "+-(0,r.RI)(c)+"px",threshold:(0,r.T9)(0,(0,r.jk)(1,u))||1},m=!0;function y(e){let n=e[0].intersectionRatio;if(n!==u){if(!m)return a();n?a(!1,n):i=setTimeout(()=>{a(!1,1e-7)},1e3)}1!==n||F(h,t.getBoundingClientRect())||a(),m=!1}try{n=new IntersectionObserver(y,{...g,root:o.ownerDocument})}catch(t){n=new IntersectionObserver(y,g)}n.observe(t)}(!0),s}(p,i):null,g=-1,m=null;l&&(m=new ResizeObserver(t=>{let[n]=t;n&&n.target===p&&m&&e&&(m.unobserve(e),cancelAnimationFrame(g),g=requestAnimationFrame(()=>{var t;null==(t=m)||t.observe(e)})),i()}),p&&!c&&m.observe(p),e&&m.observe(e));let y=c?k(t):null;return c&&function e(){let n=k(t);y&&!F(y,n)&&i(),y=n,o=requestAnimationFrame(e)}(),i(),()=>{var t;d.forEach(t=>{s&&t.removeEventListener("scroll",i),a&&t.removeEventListener("resize",i)}),null==f||f(),null==(t=m)||t.disconnect(),m=null,c&&cancelAnimationFrame(o)}}(e.$refs.toggle,t,a)}},localFilterBy(){return this.filterBy??tp.props.filterBy.default},localLabel(){return this.label??tp.props.label.default},propsToForward(){let t=[...Object.keys(tp.props),...tp.mixins.flatMap(t=>Object.keys(t.props??{}))];return{...Object.fromEntries(Object.entries(this.$props).filter(([e,i])=>t.includes(e))),calculatePosition:this.localCalculatePosition,closeOnSelect:!this.keepOpen,filterBy:this.localFilterBy,label:this.localLabel}}},mounted(){this.labelOutside||this.inputLabel||this.ariaLabelCombobox||(0,G.R8)("[NcSelect] An `inputLabel` or `ariaLabelCombobox` should be set. If an external label is used, `labelOutside` should be set to `true`."),this.inputLabel&&this.ariaLabelCombobox&&(0,G.R8)("[NcSelect] Only one of `inputLabel` or `ariaLabelCombobox` should to be set.")},methods:{t:tw.a}},tE=["for"],tC=["required"],tP=(0,tm._)(tS,[["render",function(t,e,i,n,r,o){let s=(0,G.g2)("ChevronDown"),a=(0,G.g2)("NcEllipsisedOption"),l=(0,G.g2)("NcLoadingIcon"),u=(0,G.g2)("VueSelect");return(0,G.uX)(),(0,G.Wv)(u,(0,G.v6)({class:["select",{"select--legacy":n.isLegacy,"select--no-wrap":i.noWrap}]},o.propsToForward,{onSearch:e[0]||(e[0]=t=>r.search=t),"onUpdate:modelValue":e[1]||(e[1]=e=>t.$emit("update:modelValue",e))}),(0,G.eX)({search:(0,G.k6)(({attributes:t,events:e})=>[(0,G.Lk)("input",(0,G.v6)({class:["vs__search",[i.inputClass]]},t,{required:o.inputRequired,dir:"auto"},(0,G.Tb)(e,!0)),null,16,tC)]),"open-indicator":(0,G.k6)(({attributes:t})=>[(0,G.bF)(s,(0,G.v6)(t,{fillColor:"var(--vs-controls-color)",style:{cursor:i.disabled?null:"pointer"},size:26}),null,16,["style"])]),option:(0,G.k6)(e=>[(0,G.RG)(t.$slots,"option",(0,q.normalizeProps)((0,G.Ng)(e)),()=>[(0,G.bF)(a,{name:String(e[o.localLabel]),search:r.search},null,8,["name","search"])])]),"selected-option":(0,G.k6)(e=>[(0,G.RG)(t.$slots,"selected-option",(0,q.normalizeProps)((0,G.Ng)(e)),()=>[(0,G.bF)(a,{name:String(e[o.localLabel]),search:r.search},null,8,["name","search"])])]),spinner:(0,G.k6)(t=>[t.loading?((0,G.uX)(),(0,G.Wv)(l,{key:0})):(0,G.Q3)("",!0)]),"no-options":(0,G.k6)(()=>[(0,G.eW)((0,q.toDisplayString)(o.t("No results")),1)]),_:2},[!i.labelOutside&&i.inputLabel?{name:"header",fn:(0,G.k6)(()=>[(0,G.Lk)("label",{for:i.inputId,class:"select__label"},(0,q.toDisplayString)(i.inputLabel),9,tE)]),key:"0"}:void 0,(0,G.pI)(t.$slots,(e,i)=>({name:i,fn:(0,G.k6)(e=>[(0,G.RG)(t.$slots,i,(0,q.normalizeProps)((0,G.Ng)(e)))])}))]),1040,["class"])}]])},51420(t,e,i){var n=i(20641),r=i(50953),o=i(98190),s=i(22436),a=i(51012),l=i(26089);(0,s.r)(s.c,s.b);let u=(0,n.pM)({__name:"NcTextField",props:(0,n.zz)({class:{},inputClass:{},id:{},label:{},labelOutside:{type:Boolean},type:{},placeholder:{},showTrailingButton:{type:Boolean},trailingButtonLabel:{default:void 0},success:{type:Boolean},error:{type:Boolean},helperText:{},disabled:{type:Boolean},pill:{type:Boolean},trailingButtonIcon:{default:"close"}},{modelValue:{default:""},modelModifiers:{}}),emits:["update:modelValue"],setup(t,{expose:e}){let i=(0,n.fn)(t,"modelValue");e({focus:function(t){u.value.focus(t)},select:function(){u.value.select()}});let u=(0,n.rk)("inputField"),h={arrowEnd:(0,s.a)("Save changes"),close:(0,s.a)("Clear text"),undo:(0,s.a)("Undo changes")},c=new Set(Object.keys(l.N.props)),p=(0,n.EW)(()=>{let e=Object.fromEntries(Object.entries(t).filter(([t])=>c.has(t)));return e.trailingButtonLabel??=h[t.trailingButtonIcon],e});return(e,s)=>((0,n.uX)(),(0,n.Wv)((0,r.R1)(l.N),(0,n.v6)(p.value,{ref:"inputField",modelValue:i.value,"onUpdate:modelValue":s[0]||(s[0]=t=>i.value=t)}),(0,n.eX)({_:2},[e.$slots.icon?{name:"icon",fn:(0,n.k6)(()=>[(0,n.RG)(e.$slots,"icon")]),key:"0"}:void 0,"search"!==t.type?{name:"trailing-button-icon",fn:(0,n.k6)(()=>["arrowEnd"===t.trailingButtonIcon?((0,n.uX)(),(0,n.Wv)((0,r.R1)(a.N),{key:0,directional:"",path:(0,r.R1)(o.m)},null,8,["path"])):((0,n.uX)(),(0,n.Wv)((0,r.R1)(a.N),{key:1,path:"undo"===t.trailingButtonIcon?(0,r.R1)(o.a):(0,r.R1)(o.b)},null,8,["path"]))]),key:"1"}:void 0]),1040,["modelValue"]))}});i.d(e,{},{_:u})},26308(t,e,i){i.d(e,{},{A:{beforeUpdate(){this.text=this.getText()},data(){return{text:this.getText()}},computed:{isLongText(){return this.text&&this.text.trim().length>20}},methods:{getText(){return this.$slots.default?.()[0].children?.trim?.()||""}}}})},63825(t,e,i){var n=i(20641),r=i(65112);let o={mixins:[i(26308).A],props:{icon:{type:String,default:""},name:{type:String,default:""},title:{type:String,default:""},closeAfterClick:{type:Boolean,default:!1},ariaLabel:{type:String,default:null}},inject:{closeMenu:{from:r.N}},emits:["click"],created(){"ariaHidden"in this.$attrs&&(0,n.R8)("[NcAction*]: Do not set the ariaHidden attribute as the root element will inherit the incorrect aria-hidden.")},computed:{isIconUrl(){try{return new URL(this.icon,this.icon.startsWith("/")?window.location.origin:void 0),!0}catch{return!1}}},methods:{onClick(t){this.$emit("click",t),this.closeAfterClick&&this.closeMenu(!1)}}};i.d(e,{},{A:o})},15797(t,e,i){var n=i(65048);i.d(e,{A:()=>n.N})},3710(t,e,i){i.r(e);var n=i(15205);i.d(e,{default:()=>n.N})},79455(t,e,i){var n=i(51420);i.d(e,{A:()=>n._})},46855(t,e,i){function n(t,e=100,i={}){let r,o,s,a;if("function"!=typeof t)throw TypeError(`Expected the first parameter to be a function, got \`${typeof t}\`.`);if(e<0)throw RangeError("`wait` must not be negative.");if("boolean"==typeof i)throw TypeError("The `options` parameter must be an object, not a boolean. Use `{immediate: true}` instead.");let{immediate:l}=i;function u(){let e=r,i=o;return r=void 0,o=void 0,t.apply(e,i)}function h(){let t=Date.now()-a;t<e&&t>=0?s=setTimeout(h,e-t):(s=void 0,l||u())}let c=function(...t){if(r&&this!==r&&Object.getPrototypeOf(this)===Object.getPrototypeOf(r))throw Error("Debounced method called with different contexts of the same prototype.");r=this,o=t,a=Date.now();let i=l&&!s;if(s||(s=setTimeout(h,e)),i)return u()};return Object.defineProperty(c,"isPending",{get:()=>void 0!==s}),c.clear=()=>{s&&(clearTimeout(s),s=void 0,r=void 0,o=void 0)},c.flush=()=>{s&&c.trigger()},c.trigger=()=>{u(),c.clear()},c}i.d(e,{A:()=>n})},44719(t,e,i){let n;var r,o,s,a,l,u,h,c,p,d,f,g,m,y,b,v,x=i(65606),w={2(t){function e(t,e,r){t instanceof RegExp&&(t=i(t,r)),e instanceof RegExp&&(e=i(e,r));var o=n(t,e,r);return o&&{start:o[0],end:o[1],pre:r.slice(0,o[0]),body:r.slice(o[0]+t.length,o[1]),post:r.slice(o[1]+e.length)}}function i(t,e){var i=e.match(t);return i?i[0]:null}function n(t,e,i){var n,r,o,s,a,l=i.indexOf(t),u=i.indexOf(e,l+1),h=l;if(l>=0&&u>0){for(n=[],o=i.length;h>=0&&!a;)h==l?(n.push(h),l=i.indexOf(t,h+1)):1==n.length?a=[n.pop(),u]:((r=n.pop())<o&&(o=r,s=u),u=i.indexOf(e,h+1)),h=l<u&&l>=0?l:u;n.length&&(a=[o,s])}return a}t.exports=e,e.range=n},101(t,e,i){var n,r,o,s,a,l,u;((t=i.nmd(t))&&t.exports,r="object"==typeof global&&global).global!==r&&r.window,((o=function(t){this.message=t}).prototype=Error()).name="InvalidCharacterError",s=function(t){throw new o(t)},a="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",l=/[\t\n\f\r ]/g,u={encode:function(t){t=String(t),/[^\0-\xFF]/.test(t)&&s("The string to be encoded contains characters outside of the Latin1 range.");for(var e,i,n,r,o=t.length%3,l="",u=-1,h=t.length-o;++u<h;)e=t.charCodeAt(u)<<16,i=t.charCodeAt(++u)<<8,n=t.charCodeAt(++u),l+=a.charAt((r=e+i+n)>>18&63)+a.charAt(r>>12&63)+a.charAt(r>>6&63)+a.charAt(63&r);return 2==o?(e=t.charCodeAt(u)<<8,i=t.charCodeAt(++u),l+=a.charAt((r=e+i)>>10)+a.charAt(r>>4&63)+a.charAt(r<<2&63)+"="):1==o&&(r=t.charCodeAt(u),l+=a.charAt(r>>2)+a.charAt(r<<4&63)+"=="),l},decode:function(t){var e=(t=String(t).replace(l,"")).length;e%4==0&&(e=(t=t.replace(/==?$/,"")).length),(e%4==1||/[^+a-zA-Z0-9/]/.test(t))&&s("Invalid character: the string to be decoded is not correctly encoded.");for(var i,n,r=0,o="",u=-1;++u<e;)n=a.indexOf(t.charAt(u)),i=r%4?64*i+n:n,r++%4&&(o+=String.fromCharCode(255&i>>(-2*r&6)));return o},version:"1.0.0"},void 0===(n=(function(){return u}).call(e,i,e,t))||(t.exports=n)},172(t,e){e.d=function(t){if(!t)return 0;for(var e=(t=t.toString()).length,i=t.length;i--;){var n=t.charCodeAt(i);56320<=n&&n<=57343&&i--,127<n&&n<=2047?e++:2047<n&&n<=65535&&(e+=2)}return e}},526(t){var e={utf8:{stringToBytes:function(t){return e.bin.stringToBytes(unescape(encodeURIComponent(t)))},bytesToString:function(t){return decodeURIComponent(escape(e.bin.bytesToString(t)))}},bin:{stringToBytes:function(t){for(var e=[],i=0;i<t.length;i++)e.push(255&t.charCodeAt(i));return e},bytesToString:function(t){for(var e=[],i=0;i<t.length;i++)e.push(String.fromCharCode(t[i]));return e.join("")}}};t.exports=e},298(t){var e,i;e="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",t.exports=i={rotl:function(t,e){return t<<e|t>>>32-e},rotr:function(t,e){return t<<32-e|t>>>e},endian:function(t){if(t.constructor==Number)return 0xff00ff&i.rotl(t,8)|0xff00ff00&i.rotl(t,24);for(var e=0;e<t.length;e++)t[e]=i.endian(t[e]);return t},randomBytes:function(t){for(var e=[];t>0;t--)e.push(Math.floor(256*Math.random()));return e},bytesToWords:function(t){for(var e=[],i=0,n=0;i<t.length;i++,n+=8)e[n>>>5]|=t[i]<<24-n%32;return e},wordsToBytes:function(t){for(var e=[],i=0;i<32*t.length;i+=8)e.push(t[i>>>5]>>>24-i%32&255);return e},bytesToHex:function(t){for(var e=[],i=0;i<t.length;i++)e.push((t[i]>>>4).toString(16)),e.push((15&t[i]).toString(16));return e.join("")},hexToBytes:function(t){for(var e=[],i=0;i<t.length;i+=2)e.push(parseInt(t.substr(i,2),16));return e},bytesToBase64:function(t){for(var i=[],n=0;n<t.length;n+=3)for(var r=t[n]<<16|t[n+1]<<8|t[n+2],o=0;o<4;o++)8*n+6*o<=8*t.length?i.push(e.charAt(r>>>6*(3-o)&63)):i.push("=");return i.join("")},base64ToBytes:function(t){t=t.replace(/[^A-Z0-9+\/]/gi,"");for(var i=[],n=0,r=0;n<t.length;r=++n%4)0!=r&&i.push((e.indexOf(t.charAt(n-1))&Math.pow(2,-2*r+8)-1)<<2*r|e.indexOf(t.charAt(n))>>>6-2*r);return i}}},135(t){function e(t){return!!t.constructor&&"function"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}t.exports=function(t){return null!=t&&(e(t)||"function"==typeof t.readFloatLE&&"function"==typeof t.slice&&e(t.slice(0,0))||!!t._isBuffer)}},542(t,e,i){var n,r,o,s,a;n=i(298),r=i(526).utf8,o=i(135),s=i(526).bin,(a=function(t,e){t.constructor==String?t=e&&"binary"===e.encoding?s.stringToBytes(t):r.stringToBytes(t):o(t)?t=Array.prototype.slice.call(t,0):Array.isArray(t)||t.constructor===Uint8Array||(t=t.toString());for(var i=n.bytesToWords(t),l=8*t.length,u=0x67452301,h=-0x10325477,c=-0x67452302,p=0x10325476,d=0;d<i.length;d++)i[d]=0xff00ff&(i[d]<<8|i[d]>>>24)|0xff00ff00&(i[d]<<24|i[d]>>>8);i[l>>>5]|=128<<l%32,i[14+(l+64>>>9<<4)]=l;var f=a._ff,g=a._gg,m=a._hh,y=a._ii;for(d=0;d<i.length;d+=16){var b=u,v=h,x=c,w=p;u=f(u,h,c,p,i[d+0],7,-0x28955b88),p=f(p,u,h,c,i[d+1],12,-0x173848aa),c=f(c,p,u,h,i[d+2],17,0x242070db),h=f(h,c,p,u,i[d+3],22,-0x3e423112),u=f(u,h,c,p,i[d+4],7,-0xa83f051),p=f(p,u,h,c,i[d+5],12,0x4787c62a),c=f(c,p,u,h,i[d+6],17,-0x57cfb9ed),h=f(h,c,p,u,i[d+7],22,-0x2b96aff),u=f(u,h,c,p,i[d+8],7,0x698098d8),p=f(p,u,h,c,i[d+9],12,-0x74bb0851),c=f(c,p,u,h,i[d+10],17,-42063),h=f(h,c,p,u,i[d+11],22,-0x76a32842),u=f(u,h,c,p,i[d+12],7,0x6b901122),p=f(p,u,h,c,i[d+13],12,-0x2678e6d),c=f(c,p,u,h,i[d+14],17,-0x5986bc72),u=g(u,h=f(h,c,p,u,i[d+15],22,0x49b40821),c,p,i[d+1],5,-0x9e1da9e),p=g(p,u,h,c,i[d+6],9,-0x3fbf4cc0),c=g(c,p,u,h,i[d+11],14,0x265e5a51),h=g(h,c,p,u,i[d+0],20,-0x16493856),u=g(u,h,c,p,i[d+5],5,-0x29d0efa3),p=g(p,u,h,c,i[d+10],9,0x2441453),c=g(c,p,u,h,i[d+15],14,-0x275e197f),h=g(h,c,p,u,i[d+4],20,-0x182c0438),u=g(u,h,c,p,i[d+9],5,0x21e1cde6),p=g(p,u,h,c,i[d+14],9,-0x3cc8f82a),c=g(c,p,u,h,i[d+3],14,-0xb2af279),h=g(h,c,p,u,i[d+8],20,0x455a14ed),u=g(u,h,c,p,i[d+13],5,-0x561c16fb),p=g(p,u,h,c,i[d+2],9,-0x3105c08),c=g(c,p,u,h,i[d+7],14,0x676f02d9),u=m(u,h=g(h,c,p,u,i[d+12],20,-0x72d5b376),c,p,i[d+5],4,-378558),p=m(p,u,h,c,i[d+8],11,-0x788e097f),c=m(c,p,u,h,i[d+11],16,0x6d9d6122),h=m(h,c,p,u,i[d+14],23,-0x21ac7f4),u=m(u,h,c,p,i[d+1],4,-0x5b4115bc),p=m(p,u,h,c,i[d+4],11,0x4bdecfa9),c=m(c,p,u,h,i[d+7],16,-0x944b4a0),h=m(h,c,p,u,i[d+10],23,-0x41404390),u=m(u,h,c,p,i[d+13],4,0x289b7ec6),p=m(p,u,h,c,i[d+0],11,-0x155ed806),c=m(c,p,u,h,i[d+3],16,-0x2b10cf7b),h=m(h,c,p,u,i[d+6],23,0x4881d05),u=m(u,h,c,p,i[d+9],4,-0x262b2fc7),p=m(p,u,h,c,i[d+12],11,-0x1924661b),c=m(c,p,u,h,i[d+15],16,0x1fa27cf8),u=y(u,h=m(h,c,p,u,i[d+2],23,-0x3b53a99b),c,p,i[d+0],6,-0xbd6ddbc),p=y(p,u,h,c,i[d+7],10,0x432aff97),c=y(c,p,u,h,i[d+14],15,-0x546bdc59),h=y(h,c,p,u,i[d+5],21,-0x36c5fc7),u=y(u,h,c,p,i[d+12],6,0x655b59c3),p=y(p,u,h,c,i[d+3],10,-0x70f3336e),c=y(c,p,u,h,i[d+10],15,-1051523),h=y(h,c,p,u,i[d+1],21,-0x7a7ba22f),u=y(u,h,c,p,i[d+8],6,0x6fa87e4f),p=y(p,u,h,c,i[d+15],10,-0x1d31920),c=y(c,p,u,h,i[d+6],15,-0x5cfebcec),h=y(h,c,p,u,i[d+13],21,0x4e0811a1),u=y(u,h,c,p,i[d+4],6,-0x8ac817e),p=y(p,u,h,c,i[d+11],10,-0x42c50dcb),c=y(c,p,u,h,i[d+2],15,0x2ad7d2bb),h=y(h,c,p,u,i[d+9],21,-0x14792c6f),u=u+b>>>0,h=h+v>>>0,c=c+x>>>0,p=p+w>>>0}return n.endian([u,h,c,p])})._ff=function(t,e,i,n,r,o,s){var a=t+(e&i|~e&n)+(r>>>0)+s;return(a<<o|a>>>32-o)+e},a._gg=function(t,e,i,n,r,o,s){var a=t+(e&n|i&~n)+(r>>>0)+s;return(a<<o|a>>>32-o)+e},a._hh=function(t,e,i,n,r,o,s){var a=t+(e^i^n)+(r>>>0)+s;return(a<<o|a>>>32-o)+e},a._ii=function(t,e,i,n,r,o,s){var a=t+(i^(e|~n))+(r>>>0)+s;return(a<<o|a>>>32-o)+e},a._blocksize=16,a._digestsize=16,t.exports=function(t,e){if(null==t)throw Error("Illegal argument "+t);var i=n.wordsToBytes(a(t,e));return e&&e.asBytes?i:e&&e.asString?s.bytesToString(i):n.bytesToHex(i)}},285(t,e,i){var n=i(2);t.exports=function(t,e){if(!t)return[];var i=null==(e=e||{}).max?1/0:e.max;return"{}"===t.substr(0,2)&&(t="\\{\\}"+t.substr(2)),(function t(e,i,r){var o=[],a=n("{","}",e);if(!a)return[e];var l=a.pre,h=a.post.length?t(a.post,i,!1):[""];if(/\$$/.test(a.pre))for(var g=0;g<h.length&&g<i;g++){var m=l+"{"+a.body+"}"+h[g];o.push(m)}else{var y,b,v=/^-?\d+\.\.-?\d+(?:\.\.-?\d+)?$/.test(a.body),x=/^[a-zA-Z]\.\.[a-zA-Z](?:\.\.-?\d+)?$/.test(a.body),w=v||x,N=a.body.indexOf(",")>=0;if(!w&&!N)return a.post.match(/,(?!,).*\}/)?t(e=a.pre+"{"+a.body+s+a.post,i,!0):[e];if(w)y=a.body.split(/\.\./);else if(1===(y=function t(e){if(!e)return[""];var i=[],r=n("{","}",e);if(!r)return e.split(",");var o=r.pre,s=r.body,a=r.post,l=o.split(",");l[l.length-1]+="{"+s+"}";var u=t(a);return a.length&&(l[l.length-1]+=u.shift(),l.push.apply(l,u)),i.push.apply(i,l),i}(a.body)).length&&1===(y=t(y[0],i,!1).map(c)).length)return h.map(function(t){return a.pre+y[0]+t});if(w){var _,S=u(y[0]),E=u(y[1]),C=Math.max(y[0].length,y[1].length),P=3==y.length?Math.max(Math.abs(u(y[2])),1):1,O=d;E<S&&(P*=-1,O=f);var A=y.some(p);b=[];for(var T=S;O(T,E);T+=P){if(x)"\\"===(_=String.fromCharCode(T))&&(_="");else if(_=String(T),A){var $=C-_.length;if($>0){var k=Array($+1).join("0");_=T<0?"-"+k+_.slice(1):k+_}}b.push(_)}}else{b=[];for(var L=0;L<y.length;L++)b.push.apply(b,t(y[L],i,!1))}for(L=0;L<b.length;L++)for(g=0;g<h.length&&o.length<i;g++)m=l+b[L]+h[g],(!r||w||m)&&o.push(m)}return o})(t.split("\\\\").join(r).split("\\{").join(o).split("\\}").join(s).split("\\,").join(a).split("\\.").join(l),i,!0).map(h)};var r="\0SLASH"+Math.random()+"\0",o="\0OPEN"+Math.random()+"\0",s="\0CLOSE"+Math.random()+"\0",a="\0COMMA"+Math.random()+"\0",l="\0PERIOD"+Math.random()+"\0";function u(t){return parseInt(t,10)==t?parseInt(t,10):t.charCodeAt(0)}function h(t){return t.split(r).join("\\").split(o).join("{").split(s).join("}").split(a).join(",").split(l).join(".")}function c(t){return"{"+t+"}"}function p(t){return/^-?0\d/.test(t)}function d(t,e){return t<=e}function f(t,e){return t>=e}},829(t){function e(t){return(e="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t})(t)}function i(t){var e="function"==typeof Map?new Map:void 0;return(i=function(t){if(null===t||-1===Function.toString.call(t).indexOf("[native code]"))return t;if("function"!=typeof t)throw TypeError("Super expression must either be null or a function");if(void 0!==e){if(e.has(t))return e.get(t);e.set(t,i)}function i(){return n(t,arguments,o(this).constructor)}return i.prototype=Object.create(t.prototype,{constructor:{value:i,enumerable:!1,writable:!0,configurable:!0}}),r(i,t)})(t)}function n(t,e,i){return(n=!function(){if("u"<typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],function(){})),!0}catch(t){return!1}}()?function(t,e,i){var n=[null];n.push.apply(n,e);var o=new(Function.bind.apply(t,n));return i&&r(o,i.prototype),o}:Reflect.construct).apply(null,arguments)}function r(t,e){return(r=Object.setPrototypeOf||function(t,e){return t.__proto__=e,t})(t,e)}function o(t){return(o=Object.setPrototypeOf?Object.getPrototypeOf:function(t){return t.__proto__||Object.getPrototypeOf(t)})(t)}var s=function(t){function i(t){var n,r;return function(t,e){if(!(t instanceof e))throw TypeError("Cannot call a class as a function")}(this,i),(n=(r=o(i).call(this,t))&&("object"===e(r)||"function"==typeof r)?r:function(t){if(void 0===t)throw ReferenceError("this hasn't been initialised - super() hasn't been called");return t}(this)).name="ObjectPrototypeMutationError",n}return function(t,e){if("function"!=typeof e&&null!==e)throw TypeError("Super expression must either be null or a function");t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),e&&r(t,e)}(i,t),i}(i(Error));function a(t,i){for(var n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:function(){},r=i.split("."),o=r.length,s=function(e){var i=r[e];if(!t)return{v:void 0};if("+"===i){if(Array.isArray(t))return{v:t.map(function(i,o){var s=r.slice(e+1);return s.length>0?a(i,s.join("."),n):n(t,o,r,e)})};var o=r.slice(0,e).join(".");throw Error("Object at wildcard (".concat(o,") is not an array"))}t=n(t,i,r,e)},l=0;l<o;l++){var u=s(l);if("object"===e(u))return u.v}return t}function l(t,e){return t.length===e+1}t.exports={set:function(t,i,n){if("object"!=e(t)||null===t||void 0===i)return t;if("number"==typeof i)return t[i]=n,t[i];try{return a(t,i,function(t,e,i,r){if(t===Reflect.getPrototypeOf({}))throw new s("Attempting to mutate Object.prototype");if(!t[e]){var o=Number.isInteger(Number(i[r+1])),a="+"===i[r+1];t[e]=o||a?[]:{}}return l(i,r)&&(t[e]=n),t[e]})}catch(e){if(e instanceof s)throw e;return t}},get:function(t,i){if("object"!=e(t)||null===t||void 0===i)return t;if("number"==typeof i)return t[i];try{return a(t,i,function(t,e){return t[e]})}catch(e){return t}},has:function(t,i){var n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};if("object"!=e(t)||null===t||void 0===i)return!1;if("number"==typeof i)return i in t;try{var r=!1;return a(t,i,function(t,e,i,o){if(!l(i,o))return t&&t[e];r=n.own?t.hasOwnProperty(e):e in t}),r}catch(t){return!1}},hasOwn:function(t,e,i){return this.has(t,e,i||{own:!0})},isIn:function(t,i,n){var r=arguments.length>3&&void 0!==arguments[3]?arguments[3]:{};if("object"!=e(t)||null===t||void 0===i)return!1;try{var o=!1,s=!1;return a(t,i,function(t,i,r,a){return o=o||t===n||!!t&&t[i]===n,s=l(r,a)&&"object"===e(t)&&i in t,t&&t[i]}),r.validPath?o&&s:o}catch(t){return!1}},ObjectPrototypeMutationError:s}},47(t,e,i){var n=i(410),r=function(t){return"string"==typeof t};function o(t,e){for(var i=[],n=0;n<t.length;n++){var r=t[n];r&&"."!==r&&(".."===r?i.length&&".."!==i[i.length-1]?i.pop():e&&i.push(".."):i.push(r))}return i}var s=/^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/,a={};function l(t){return s.exec(t).slice(1)}a.resolve=function(){for(var t="",e=!1,i=arguments.length-1;i>=-1&&!e;i--){var n=i>=0?arguments[i]:x.cwd();if(!r(n))throw TypeError("Arguments to path.resolve must be strings");n&&(t=n+"/"+t,e="/"===n.charAt(0))}return(e?"/":"")+(t=o(t.split("/"),!e).join("/"))||"."},a.normalize=function(t){var e=a.isAbsolute(t),i="/"===t.substr(-1);return(t=o(t.split("/"),!e).join("/"))||e||(t="."),t&&i&&(t+="/"),(e?"/":"")+t},a.isAbsolute=function(t){return"/"===t.charAt(0)},a.join=function(){for(var t="",e=0;e<arguments.length;e++){var i=arguments[e];if(!r(i))throw TypeError("Arguments to path.join must be strings");i&&(t+=t?"/"+i:i)}return a.normalize(t)},a.relative=function(t,e){function i(t){for(var e=0;e<t.length&&""===t[e];e++);for(var i=t.length-1;i>=0&&""===t[i];i--);return e>i?[]:t.slice(e,i+1)}t=a.resolve(t).substr(1),e=a.resolve(e).substr(1);for(var n=i(t.split("/")),r=i(e.split("/")),o=Math.min(n.length,r.length),s=o,l=0;l<o;l++)if(n[l]!==r[l]){s=l;break}var u=[];for(l=s;l<n.length;l++)u.push("..");return(u=u.concat(r.slice(s))).join("/")},a._makeLong=function(t){return t},a.dirname=function(t){var e=l(t),i=e[0],n=e[1];return i||n?(n&&(n=n.substr(0,n.length-1)),i+n):"."},a.basename=function(t,e){var i=l(t)[2];return e&&i.substr(-1*e.length)===e&&(i=i.substr(0,i.length-e.length)),i},a.extname=function(t){return l(t)[3]},a.format=function(t){if(!n.isObject(t))throw TypeError("Parameter 'pathObject' must be an object, not "+typeof t);if(!r(t.root||""))throw TypeError("'pathObject.root' must be a string or undefined, not "+typeof t.root);return(t.dir?t.dir+a.sep:"")+(t.base||"")},a.parse=function(t){if(!r(t))throw TypeError("Parameter 'pathString' must be a string, not "+typeof t);var e=l(t);if(!e||4!==e.length)throw TypeError("Invalid path '"+t+"'");return e[1]=e[1]||"",e[2]=e[2]||"",e[3]=e[3]||"",{root:e[0],dir:e[0]+e[1].slice(0,e[1].length-1),base:e[2],ext:e[3],name:e[2].slice(0,e[2].length-e[3].length)}},a.sep="/",a.delimiter=":",t.exports=a},647(t,e){var i=Object.prototype.hasOwnProperty;function n(t){try{return decodeURIComponent(t.replace(/\+/g," "))}catch(t){return null}}function r(t){try{return encodeURIComponent(t)}catch(t){return null}}e.stringify=function(t,e){var n,o,s=[];for(o in"string"!=typeof(e=e||"")&&(e="?"),t)if(i.call(t,o)){if((n=t[o])||null!=n&&!isNaN(n)||(n=""),o=r(o),n=r(n),null===o||null===n)continue;s.push(o+"="+n)}return s.length?e+s.join("&"):""},e.parse=function(t){for(var e,i=/([^=?#&]+)=?([^&]*)/g,r={};e=i.exec(t);){var o=n(e[1]),s=n(e[2]);null===o||null===s||o in r||(r[o]=s)}return r}},670(t){t.exports=function(t,e){if(e=e.split(":")[0],!(t*=1))return!1;switch(e){case"http":case"ws":return 80!==t;case"https":case"wss":return 443!==t;case"ftp":return 21!==t;case"gopher":return 70!==t;case"file":return!1}return 0!==t}},737(t,e,i){var n=i(670),r=i(647),o=/^[\x00-\x20\u00a0\u1680\u2000-\u200a\u2028\u2029\u202f\u205f\u3000\ufeff]+/,s=/[\n\r\t]/g,a=/^[A-Za-z][A-Za-z0-9+-.]*:\/\//,l=/:\d+$/,u=/^([a-z][a-z0-9.+-]*:)?(\/\/)?([\\/]+)?([\S\s]*)/i,h=/^[a-zA-Z]:/;function c(t){return(t||"").toString().replace(o,"")}var p=[["#","hash"],["?","query"],function(t,e){return g(e.protocol)?t.replace(/\\/g,"/"):t},["/","pathname"],["@","auth",1],[NaN,"host",void 0,1,1],[/:(\d*)$/,"port",void 0,1],[NaN,"hostname",void 0,1,1]],d={hash:1,query:1};function f(t){var e,i=("u">typeof window?window:"u">typeof global?global:"u">typeof self?self:{}).location||{},n={},r=typeof(t=t||i);if("blob:"===t.protocol)n=new y(unescape(t.pathname),{});else if("string"===r)for(e in n=new y(t,{}),d)delete n[e];else if("object"===r){for(e in t)e in d||(n[e]=t[e]);void 0===n.slashes&&(n.slashes=a.test(t.href))}return n}function g(t){return"file:"===t||"ftp:"===t||"http:"===t||"https:"===t||"ws:"===t||"wss:"===t}function m(t,e){t=(t=c(t)).replace(s,""),e=e||{};var i,n=u.exec(t),r=n[1]?n[1].toLowerCase():"",o=!!n[2],a=!!n[3],l=0;return o?a?(i=n[2]+n[3]+n[4],l=n[2].length+n[3].length):(i=n[2]+n[4],l=n[2].length):a?(i=n[3]+n[4],l=n[3].length):i=n[4],"file:"===r?l>=2&&(i=i.slice(2)):g(r)?i=n[4]:r?o&&(i=i.slice(2)):l>=2&&g(e.protocol)&&(i=n[4]),{protocol:r,slashes:o||g(r),slashesCount:l,rest:i}}function y(t,e,i){if(t=(t=c(t)).replace(s,""),!(this instanceof y))return new y(t,e,i);var o,a,l,u,d,b,v=p.slice(),x=typeof e,w=0;for("object"!==x&&"string"!==x&&(i=e,e=null),i&&"function"!=typeof i&&(i=r.parse),o=!(a=m(t||"",e=f(e))).protocol&&!a.slashes,this.slashes=a.slashes||o&&e.slashes,this.protocol=a.protocol||e.protocol||"",t=a.rest,("file:"===a.protocol&&(2!==a.slashesCount||h.test(t))||!a.slashes&&(a.protocol||a.slashesCount<2||!g(this.protocol)))&&(v[3]=[/(.*)/,"pathname"]);w<v.length;w++)"function"!=typeof(u=v[w])?(l=u[0],b=u[1],l!=l?this[b]=t:"string"==typeof l?~(d="@"===l?t.lastIndexOf(l):t.indexOf(l))&&("number"==typeof u[2]?(this[b]=t.slice(0,d),t=t.slice(d+u[2])):(this[b]=t.slice(d),t=t.slice(0,d))):(d=l.exec(t))&&(this[b]=d[1],t=t.slice(0,d.index)),this[b]=this[b]||o&&u[3]&&e[b]||"",u[4]&&(this[b]=this[b].toLowerCase())):t=u(t,this);i&&(this.query=i(this.query)),o&&e.slashes&&"/"!==this.pathname.charAt(0)&&(""!==this.pathname||""!==e.pathname)&&(this.pathname=function(t,e){if(""===t)return e;for(var i=(e||"/").split("/").slice(0,-1).concat(t.split("/")),n=i.length,r=i[n-1],o=!1,s=0;n--;)"."===i[n]?i.splice(n,1):".."===i[n]?(i.splice(n,1),s++):s&&(0===n&&(o=!0),i.splice(n,1),s--);return o&&i.unshift(""),"."!==r&&".."!==r||i.push(""),i.join("/")}(this.pathname,e.pathname)),"/"!==this.pathname.charAt(0)&&g(this.protocol)&&(this.pathname="/"+this.pathname),n(this.port,this.protocol)||(this.host=this.hostname,this.port=""),this.username=this.password="",this.auth&&(~(d=this.auth.indexOf(":"))?(this.username=this.auth.slice(0,d),this.username=encodeURIComponent(decodeURIComponent(this.username)),this.password=this.auth.slice(d+1),this.password=encodeURIComponent(decodeURIComponent(this.password))):this.username=encodeURIComponent(decodeURIComponent(this.auth)),this.auth=this.password?this.username+":"+this.password:this.username),this.origin="file:"!==this.protocol&&g(this.protocol)&&this.host?this.protocol+"//"+this.host:"null",this.href=this.toString()}y.prototype={set:function(t,e,i){switch(t){case"query":"string"==typeof e&&e.length&&(e=(i||r.parse)(e)),this[t]=e;break;case"port":this[t]=e,n(e,this.protocol)?e&&(this.host=this.hostname+":"+e):(this.host=this.hostname,this[t]="");break;case"hostname":this[t]=e,this.port&&(e+=":"+this.port),this.host=e;break;case"host":this[t]=e,l.test(e)?(e=e.split(":"),this.port=e.pop(),this.hostname=e.join(":")):(this.hostname=e,this.port="");break;case"protocol":this.protocol=e.toLowerCase(),this.slashes=!i;break;case"pathname":case"hash":if(e){var o="pathname"===t?"/":"#";this[t]=e.charAt(0)!==o?o+e:e}else this[t]=e;break;case"username":case"password":this[t]=encodeURIComponent(e);break;case"auth":var s=e.indexOf(":");~s?(this.username=e.slice(0,s),this.username=encodeURIComponent(decodeURIComponent(this.username)),this.password=e.slice(s+1),this.password=encodeURIComponent(decodeURIComponent(this.password))):this.username=encodeURIComponent(decodeURIComponent(e))}for(var a=0;a<p.length;a++){var u=p[a];u[4]&&(this[u[1]]=this[u[1]].toLowerCase())}return this.auth=this.password?this.username+":"+this.password:this.username,this.origin="file:"!==this.protocol&&g(this.protocol)&&this.host?this.protocol+"//"+this.host:"null",this.href=this.toString(),this},toString:function(t){t&&"function"==typeof t||(t=r.stringify);var e,i=this.host,n=this.protocol;n&&":"!==n.charAt(n.length-1)&&(n+=":");var o=n+(this.protocol&&this.slashes||g(this.protocol)?"//":"");return this.username?(o+=this.username,this.password&&(o+=":"+this.password),o+="@"):this.password?(o+=":"+this.password,o+="@"):"file:"!==this.protocol&&g(this.protocol)&&!i&&"/"!==this.pathname&&(o+="@"),(":"===i[i.length-1]||l.test(this.hostname)&&!this.port)&&(i+=":"),o+=i+this.pathname,(e="object"==typeof this.query?t(this.query):this.query)&&(o+="?"!==e.charAt(0)?"?"+e:e),this.hash&&(o+=this.hash),o}},y.extractProtocol=m,y.location=f,y.trimLeft=c,y.qs=r,t.exports=y},410(){},388(){},805(){},345(){},800(){}},N={};function _(t){var e=N[t];if(void 0!==e)return e.exports;var i=N[t]={id:t,loaded:!1,exports:{}};return w[t].call(i.exports,i,i.exports,_),i.loaded=!0,i.exports}_.n=t=>{var e=t&&t.__esModule?()=>t.default:()=>t;return _.d(e,{a:e}),e},_.d=(t,e)=>{for(var i in e)_.o(e,i)&&!_.o(t,i)&&Object.defineProperty(t,i,{enumerable:!0,get:e[i]})},_.o=(t,e)=>Object.prototype.hasOwnProperty.call(t,e),_.nmd=t=>(t.paths=[],t.children||(t.children=[]),t);var S=_(737),E=_.n(S);function C(t){if(!P(t))throw Error("Parameter was not an error")}function P(t){return!!t&&"object"==typeof t&&"[object Error]"===Object.prototype.toString.call(t)||t instanceof Error}class O extends Error{constructor(t,e){const i=[...arguments],{options:n,shortMessage:r}=function(t){let e,i="";if(0===t.length)e={};else if(P(t[0]))e={cause:t[0]},i=t.slice(1).join(" ")||"";else if(t[0]&&"object"==typeof t[0])e=Object.assign({},t[0]),i=t.slice(1).join(" ")||"";else{if("string"!=typeof t[0])throw Error("Invalid arguments passed to Layerr");e={},i=i=t.join(" ")||""}return{options:e,shortMessage:i}}(i);let o=r;n.cause&&(o=`${o}: ${n.cause.message}`),super(o),this.message=o,n.name&&"string"==typeof n.name?this.name=n.name:this.name="Layerr",n.cause&&Object.defineProperty(this,"_cause",{value:n.cause}),Object.defineProperty(this,"_info",{value:{}}),n.info&&"object"==typeof n.info&&Object.assign(this._info,n.info),Error.captureStackTrace&&Error.captureStackTrace(this,n.constructorOpt||this.constructor)}static cause(t){return C(t),t._cause&&P(t._cause)?t._cause:null}static fullStack(t){C(t);let e=O.cause(t);return e?`${t.stack}
caused by: ${O.fullStack(e)}`:t.stack??""}static info(t){C(t);let e={},i=O.cause(t);return i&&Object.assign(e,O.info(i)),t._info&&Object.assign(e,t._info),e}toString(){let t=this.name||this.constructor.name||this.constructor.prototype.name;return this.message&&(t=`${t}: ${this.message}`),t}}var A=_(47),T=_.n(A);let $="__PATH_SEPARATOR_POSIX__",k="__PATH_SEPARATOR_WINDOWS__";function L(t){try{let e=t.replace(/\//g,$).replace(/\\\\/g,k);return encodeURIComponent(e).split(k).join("\\\\").split($).join("/")}catch(t){throw new O(t,"Failed encoding path")}}function j(t){return t.startsWith("/")?t:"/"+t}function I(t){let e=t;return"/"!==e[0]&&(e="/"+e),/^.+\/$/.test(e)&&(e=e.substr(0,e.length-1)),e}function R(){for(var t=arguments.length,e=Array(t),i=0;i<t;i++)e[i]=arguments[i];return function(){return function(t){var e=[];if(0===t.length)return"";if("string"!=typeof t[0])throw TypeError("Url must be a string. Received "+t[0]);if(t[0].match(/^[^/:]+:\/*$/)&&t.length>1){var i=t.shift();t[0]=i+t[0]}t[0].match(/^file:\/\/\//)?t[0]=t[0].replace(/^([^/:]+):\/*/,"$1:///"):t[0]=t[0].replace(/^([^/:]+):\/*/,"$1://");for(var n=0;n<t.length;n++){var r=t[n];if("string"!=typeof r)throw TypeError("Url must be a string. Received "+r);""!==r&&(n>0&&(r=r.replace(/^[\/]+/,"")),r=n<t.length-1?r.replace(/[\/]+$/,""):r.replace(/[\/]+$/,"/"),e.push(r))}var o=e.join("/"),s=(o=o.replace(/\/(\?|&|#[^!])/g,"$1")).split("?");return s.shift()+(s.length>0?"?":"")+s.join("&")}("object"==typeof arguments[0]?arguments[0]:[].slice.call(arguments))}(e.reduce((t,e,i)=>((0===i||"/"!==e||"/"===e&&"/"!==t[t.length-1])&&t.push(e),t),[]))}var D=_(542),V=_.n(D);function M(t,e){var i,n,r,o,s,a;let l,u=t.url.replace("//",""),h=-1==u.indexOf("/")?"/":u.slice(u.indexOf("/")),c=t.method?t.method.toUpperCase():"GET",p=!!/(^|,)\s*auth\s*($|,)/.test(e.qop)&&"auth",d=`00000000${e.nc}`.slice(-8),f=(i=e.algorithm,n=e.username,r=e.realm,o=e.password,s=e.nonce,a=e.cnonce,l=e.ha1||V()(`${n}:${r}:${o}`),i&&"md5-sess"===i.toLowerCase()?V()(`${l}:${s}:${a}`):l),g=V()(`${c}:${h}`),m=p?V()(`${f}:${e.nonce}:${d}:${e.cnonce}:${p}:${g}`):V()(`${f}:${e.nonce}:${g}`),y={username:e.username,realm:e.realm,nonce:e.nonce,uri:h,qop:p,response:m,nc:d,cnonce:e.cnonce,algorithm:e.algorithm,opaque:e.opaque},b=[];for(let t in y)y[t]&&("qop"===t||"nc"===t||"algorithm"===t?b.push(`${t}=${y[t]}`):b.push(`${t}="${y[t]}"`));return`Digest ${b.join(", ")}`}function B(t){return"digest"===(t.headers&&t.headers.get("www-authenticate")||"").split(/\s/)[0].toLowerCase()}var F=_(101),U=_.n(F);function W(t){return U().decode(t)}function z(t,e){var i;return`Basic ${i=`${t}:${e}`,U().encode(i)}`}let X="u">typeof WorkerGlobalScope&&self instanceof WorkerGlobalScope?self:"u">typeof window?window:globalThis,G=X.fetch.bind(X);X.Headers,X.Request,X.Response;let q=((r={}).Auto="auto",r.Digest="digest",r.None="none",r.Password="password",r.Token="token",r),H=((o={}).DataTypeNoLength="data-type-no-length",o.InvalidAuthType="invalid-auth-type",o.InvalidOutputFormat="invalid-output-format",o.LinkUnsupportedAuthType="link-unsupported-auth",o.InvalidUpdateRange="invalid-update-range",o.NotSupported="not-supported",o);function K(t,e,i,n,r){switch(t.authType){case q.Auto:e&&i&&(t.headers.Authorization=z(e,i));break;case q.Digest:t.digest={username:e,password:i,ha1:r,nc:0,algorithm:"md5",hasDigestAuth:!1};break;case q.None:break;case q.Password:t.headers.Authorization=z(e,i);break;case q.Token:t.headers.Authorization=`${n.token_type} ${n.access_token}`;break;default:throw new O({info:{code:H.InvalidAuthType}},`Invalid auth type: ${t.authType}`)}}_(345),_(800);let Q="@@HOTPATCHER",Y=()=>{};function J(t){return{original:t,methods:[t],final:!1}}class Z{constructor(){this._configuration={registry:{},getEmptyAction:"null"},this.__type__=Q}get configuration(){return this._configuration}get getEmptyAction(){return this.configuration.getEmptyAction}set getEmptyAction(t){this.configuration.getEmptyAction=t}control(t){let e=arguments.length>1&&void 0!==arguments[1]&&arguments[1];if(!t||t.__type__!==Q)throw Error("Failed taking control of target HotPatcher instance: Invalid type or object");return Object.keys(t.configuration.registry).forEach(i=>{this.configuration.registry.hasOwnProperty(i)?e&&(this.configuration.registry[i]=Object.assign({},t.configuration.registry[i])):this.configuration.registry[i]=Object.assign({},t.configuration.registry[i])}),t._configuration=this.configuration,this}execute(t){let e=this.get(t)||Y;for(var i=arguments.length,n=Array(i>1?i-1:0),r=1;r<i;r++)n[r-1]=arguments[r];return e(...n)}get(t){let e=this.configuration.registry[t];if(!e)switch(this.getEmptyAction){case"null":return null;case"throw":throw Error(`Failed handling method request: No method provided for override: ${t}`);default:throw Error(`Failed handling request which resulted in an empty method: Invalid empty-action specified: ${this.getEmptyAction}`)}return function(){for(var t=arguments.length,e=Array(t),i=0;i<t;i++)e[i]=arguments[i];if(0===e.length)throw Error("Failed creating sequence: No functions provided");return function(){for(var t=arguments.length,i=Array(t),n=0;n<t;n++)i[n]=arguments[n];let r=i;for(;e.length>0;)r=[e.shift().apply(this,r)];return r[0]}}(...e.methods)}isPatched(t){return!!this.configuration.registry[t]}patch(t,e){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},{chain:n=!1}=i;if(this.configuration.registry[t]&&this.configuration.registry[t].final)throw Error(`Failed patching '${t}': Method marked as being final`);if("function"!=typeof e)throw Error(`Failed patching '${t}': Provided method is not a function`);if(n)this.configuration.registry[t]?this.configuration.registry[t].methods.push(e):this.configuration.registry[t]=J(e);else if(this.isPatched(t)){let{original:i}=this.configuration.registry[t];this.configuration.registry[t]=Object.assign(J(e),{original:i})}else this.configuration.registry[t]=J(e);return this}patchInline(t,e){this.isPatched(t)||this.patch(t,e);for(var i=arguments.length,n=Array(i>2?i-2:0),r=2;r<i;r++)n[r-2]=arguments[r];return this.execute(t,...n)}plugin(t){for(var e=arguments.length,i=Array(e>1?e-1:0),n=1;n<e;n++)i[n-1]=arguments[n];return i.forEach(e=>{this.patch(t,e,{chain:!0})}),this}restore(t){if(!this.isPatched(t))throw Error(`Failed restoring method: No method present for key: ${t}`);if("function"!=typeof this.configuration.registry[t].original)throw Error(`Failed restoring method: Original method not found or of invalid type for key: ${t}`);return this.configuration.registry[t].methods=[this.configuration.registry[t].original],this}setFinal(t){if(!this.configuration.registry.hasOwnProperty(t))throw Error(`Failed marking '${t}' as final: No method found for key`);return this.configuration.registry[t].final=!0,this}}let tt=null;function te(){return tt||(tt=new Z),tt}function ti(t){return!function(t){if("object"!=typeof t||null===t||"[object Object]"!=Object.prototype.toString.call(t))return!1;if(null===Object.getPrototypeOf(t))return!0;let e=t;for(;null!==Object.getPrototypeOf(e);)e=Object.getPrototypeOf(e);return Object.getPrototypeOf(t)===e}(t)?Object.setPrototypeOf(Object.assign({},t),Object.getPrototypeOf(t)):Object.assign({},t)}function tn(){for(var t=arguments.length,e=Array(t),i=0;i<t;i++)e[i]=arguments[i];let n=null,r=[...e];for(;r.length>0;){let t=r.shift();n=n?function t(e,i){let n=ti(e);return Object.keys(i).forEach(e=>{n.hasOwnProperty(e)?Array.isArray(i[e])?n[e]=Array.isArray(n[e])?[...n[e],...i[e]]:[...i[e]]:"object"==typeof i[e]&&i[e]?n[e]="object"==typeof n[e]&&n[e]?t(n[e],i[e]):ti(i[e]):n[e]=i[e]:n[e]=i[e]}),n}(n,t):ti(t)}return n}function tr(){for(var t=arguments.length,e=Array(t),i=0;i<t;i++)e[i]=arguments[i];if(0===e.length)return{};let n={};return e.reduce((t,e)=>(Object.keys(e).forEach(i=>{let r=i.toLowerCase();n.hasOwnProperty(r)?t[n[r]]=e[i]:(n[r]=i,t[i]=e[i])}),t),{})}_(805);let to="function"==typeof ArrayBuffer,{toString:ts}=Object.prototype;function ta(t){return to&&(t instanceof ArrayBuffer||"[object ArrayBuffer]"===ts.call(t))}function tl(t){return null!=t&&null!=t.constructor&&"function"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}function tu(t){return function(){for(var e=[],i=0;i<arguments.length;i++)e[i]=arguments[i];try{return Promise.resolve(t.apply(this,e))}catch(t){return Promise.reject(t)}}}function th(t,e,i){return i?e?e(t):t:(t&&t.then||(t=Promise.resolve(t)),e?t.then(e):t)}let tc=tu(function(t){let e=t._digest;return delete t._digest,e.hasDigestAuth&&(t=tn(t,{headers:{Authorization:M(t,e)}})),th(tg(t),function(i){var n,r;let o=!1;return n=function(t){return o?t:i},(r=function(){if(401==i.status)return e.hasDigestAuth=function(t,e){if(!B(t))return!1;let i=/([a-z0-9_-]+)=(?:"([^"]+)"|([a-z0-9_-]+))/gi;for(;;){let n=t.headers&&t.headers.get("www-authenticate")||"",r=i.exec(n);if(!r)break;e[r[1]]=r[2]||r[3]}return e.nc+=1,e.cnonce=function(){let t="";for(let e=0;e<32;++e)t=`${t}${"abcdef0123456789"[Math.floor(16*Math.random())]}`;return t}(),!0}(i,e),function(){if(e.hasDigestAuth)return th(tg(t=tn(t,{headers:{Authorization:M(t,e)}})),function(t){return 401==t.status?e.hasDigestAuth=!1:e.nc++,o=!0,t})}();e.nc++}())&&r.then?r.then(n):n(r)})}),tp=tu(function(t,e){return th(tg(t),function(i){return i.ok?(e.authType=q.Password,i):401==i.status&&B(i)?(e.authType=q.Digest,K(e,e.username,e.password,void 0,void 0),t._digest=e.digest,tc(t)):i})}),td=tu(function(t,e){return e.authType===q.Auto?tp(t,e):t._digest?tc(t):tg(t)});function tf(t,e,i){let n=ti(t);return n.headers=tr(e.headers,n.headers||{},i.headers||{}),void 0!==i.data&&(n.data=i.data),i.signal&&(n.signal=i.signal),e.httpAgent&&(n.httpAgent=e.httpAgent),e.httpsAgent&&(n.httpsAgent=e.httpsAgent),e.digest&&(n._digest=e.digest),"boolean"==typeof e.withCredentials&&(n.withCredentials=e.withCredentials),n}function tg(t){let e=te();return e.patchInline("request",t=>e.patchInline("fetch",G,t.url,function(t){let e={},i={method:t.method};if(t.headers&&(e=tr(e,t.headers)),void 0!==t.data){let[n,r]=function(t){if("string"==typeof t||tl(t)||ta(t))return[t,{}];if(t&&"object"==typeof t)return[JSON.stringify(t),{"content-type":"application/json"}];throw Error("Unable to convert request body: Unexpected body type: "+typeof t)}(t.data);i.body=n,e=tr(e,r)}return t.signal&&(i.signal=t.signal),t.withCredentials&&(i.credentials="include"),i.headers=e,i}(t)),t)}var tm=_(285);let ty=t=>{if("string"!=typeof t)throw TypeError("invalid pattern");if(t.length>65536)throw TypeError("pattern is too long")},tb={"[:alnum:]":["\\p{L}\\p{Nl}\\p{Nd}",!0],"[:alpha:]":["\\p{L}\\p{Nl}",!0],"[:ascii:]":["\\x00-\\x7f",!1],"[:blank:]":["\\p{Zs}\\t",!0],"[:cntrl:]":["\\p{Cc}",!0],"[:digit:]":["\\p{Nd}",!0],"[:graph:]":["\\p{Z}\\p{C}",!0,!0],"[:lower:]":["\\p{Ll}",!0],"[:print:]":["\\p{C}",!0],"[:punct:]":["\\p{P}",!0],"[:space:]":["\\p{Z}\\t\\r\\n\\v\\f",!0],"[:upper:]":["\\p{Lu}",!0],"[:word:]":["\\p{L}\\p{Nl}\\p{Nd}\\p{Pc}",!0],"[:xdigit:]":["A-Fa-f0-9",!1]},tv=t=>t.replace(/[[\]\\-]/g,"\\$&"),tx=(t,e)=>{if("["!==t.charAt(e))throw Error("not in a brace expression");let i=[],n=[],r=e+1,o=!1,s=!1,a=!1,l=!1,u=e,h="";t:for(;r<t.length;){let c=t.charAt(r);if("!"!==c&&"^"!==c||r!==e+1){if("]"===c&&o&&!a){u=r+1;break}if(o=!0,"\\"!==c||a){if("["===c&&!a){for(let[o,[a,l,u]]of Object.entries(tb))if(t.startsWith(o,r)){if(h)return["$.",!1,t.length-e,!0];r+=o.length,u?n.push(a):i.push(a),s=s||l;continue t}}a=!1,h?(c>h?i.push(tv(h)+"-"+tv(c)):c===h&&i.push(tv(c)),h="",r++):t.startsWith("-]",r+1)?(i.push(tv(c+"-")),r+=2):t.startsWith("-",r+1)?(h=c,r+=2):(i.push(tv(c)),r++)}else a=!0,r++}else l=!0,r++}if(u<r)return["",!1,0,!1];if(!i.length&&!n.length)return["$.",!1,t.length-e,!0];if(0===n.length&&1===i.length&&/^\\?.$/.test(i[0])&&!l)return[(2===i[0].length?i[0].slice(-1):i[0]).replace(/[-[\]{}()*+?.,\\^$|#\s]/g,"\\$&"),!1,u-e,!1];let c="["+(l?"^":"")+i.join("")+"]",p="["+(l?"":"^")+n.join("")+"]";return[i.length&&n.length?"("+c+"|"+p+")":i.length?c:p,s,u-e,!0]},tw=function(t){let{windowsPathsNoEscape:e=!1}=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return e?t.replace(/\[([^\/\\])\]/g,"$1"):t.replace(/((?!\\).|^)\[([^\/\\])\]/g,"$1$2").replace(/\\([^\/])/g,"$1")},tN=new Set(["!","?","+","*","@"]),t_=t=>tN.has(t),tS=new Map([["!",["@"]],["?",["?","@"]],["@",["@"]],["*",["*","+","?","@"]],["+",["+","@"]]]),tE=new Map([["!",["?"]],["@",["?"]],["+",["?","*"]]]),tC=new Map([["!",["?","@"]],["?",["?","@"]],["@",["?","@"]],["*",["*","+","?","@"]],["+",["+","@","?","*"]]]),tP=new Map([["!",new Map([["!","@"]])],["?",new Map([["*","*"],["+","*"]])],["@",new Map([["!","!"],["?","?"],["@","@"],["*","*"],["+","+"]])],["+",new Map([["?","*"],["*","*"]])]]),tO="(?!\\.)",tA=new Set(["[","."]),tT=new Set(["..","."]),t$=new Set("().*{}+?[]^$\\!"),tk="[^/]",tL=tk+"*?",tj=tk+"+?";class tI{type;#t;#e;#i=!1;#n=[];#r;#o;#s;#a=!1;#l;#u;#h=!1;constructor(t,e){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};this.type=t,t&&(this.#e=!0),this.#r=e,this.#t=this.#r?this.#r.#t:this,this.#l=this.#t===this?i:this.#t.#l,this.#s=this.#t===this?[]:this.#t.#s,"!"!==t||this.#t.#a||this.#s.push(this),this.#o=this.#r?this.#r.#n.length:0}get hasMagic(){if(void 0!==this.#e)return this.#e;for(let t of this.#n)if("string"!=typeof t&&(t.type||t.hasMagic))return this.#e=!0;return this.#e}toString(){return void 0!==this.#u?this.#u:this.type?this.#u=this.type+"("+this.#n.map(t=>String(t)).join("|")+")":this.#u=this.#n.map(t=>String(t)).join("")}#c(){let t;if(this!==this.#t)throw Error("should only call on root");if(this.#a)return this;for(this.toString(),this.#a=!0;t=this.#s.pop();){if("!"!==t.type)continue;let e=t,i=e.#r;for(;i;){for(let n=e.#o+1;!i.type&&n<i.#n.length;n++)for(let e of t.#n){if("string"==typeof e)throw Error("string part in extglob AST??");e.copyIn(i.#n[n])}i=(e=i).#r}}return this}push(){for(var t=arguments.length,e=Array(t),i=0;i<t;i++)e[i]=arguments[i];for(let t of e)if(""!==t){if("string"!=typeof t&&!(t instanceof b&&t.#r===this))throw Error("invalid part: "+t);this.#n.push(t)}}toJSON(){let t=null===this.type?this.#n.slice().map(t=>"string"==typeof t?t:t.toJSON()):[this.type,...this.#n.map(t=>t.toJSON())];return this.isStart()&&!this.type&&t.unshift([]),this.isEnd()&&(this===this.#t||this.#t.#a&&"!"===this.#r?.type)&&t.push({}),t}isStart(){if(this.#t===this)return!0;if(!this.#r?.isStart())return!1;if(0===this.#o)return!0;let t=this.#r;for(let e=0;e<this.#o;e++){let i=t.#n[e];if(!(i instanceof b&&"!"===i.type))return!1}return!0}isEnd(){if(this.#t===this||"!"===this.#r?.type)return!0;if(!this.#r?.isEnd())return!1;if(!this.type)return this.#r?.isEnd();let t=this.#r?this.#r.#n.length:0;return this.#o===t-1}copyIn(t){"string"==typeof t?this.push(t):this.push(t.clone(this))}clone(t){let e=new b(this.type,t);for(let t of this.#n)e.copyIn(t);return e}static #p(t,e,i,n,r){let o=n.maxExtglobRecursion??2,s=!1,a=!1,l=-1,u=!1;if(null===e.type){let h=i,c="";for(;h<t.length;){let i=t.charAt(h++);if(s||"\\"===i)s=!s,c+=i;else if(a)h===l+1?"^"!==i&&"!"!==i||(u=!0):"]"!==i||h===l+2&&u||(a=!1),c+=i;else if("["!==i)if(!n.noext&&t_(i)&&"("===t.charAt(h)&&r<=o){e.push(c),c="";let o=new b(i,e);h=b.#p(t,o,h,n,r+1),e.push(o)}else c+=i;else a=!0,l=h,u=!1,c+=i}return e.push(c),h}let h=i+1,c=new b(null,e),p=[],d="";for(;h<t.length;){let i=t.charAt(h++);if(s||"\\"===i)s=!s,d+=i;else if(a)h===l+1?"^"!==i&&"!"!==i||(u=!0):"]"!==i||h===l+2&&u||(a=!1),d+=i;else if("["!==i)if(t_(i)&&"("===t.charAt(h)&&(r<=o||e&&e.#d(i))){let o=e&&e.#d(i)?0:1;c.push(d),d="";let s=new b(i,c);c.push(s),h=b.#p(t,s,h,n,r+o)}else if("|"!==i){if(")"===i)return""===d&&0===e.#n.length&&(e.#h=!0),c.push(d),d="",e.push(...p,c),h;d+=i}else c.push(d),d="",p.push(c),c=new b(null,e);else a=!0,l=h,u=!1,d+=i}return e.type=null,e.#e=void 0,e.#n=[t.substring(i-1)],h}#f(t){return this.#g(t,tE)}#g(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:tS;if(!t||"object"!=typeof t||null!==t.type||1!==t.#n.length||null===this.type)return!1;let i=t.#n[0];return!(!i||"object"!=typeof i||null===i.type)&&this.#d(i.type,e)}#d(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:tC;return!!e.get(this.type)?.includes(t)}#m(t,e){let i=t.#n[0],n=new b(null,i,this.options);n.#n.push(""),i.push(n),this.#y(t,e)}#y(t,e){let i=t.#n[0];for(let t of(this.#n.splice(e,1,...i.#n),i.#n))"object"==typeof t&&(t.#r=this);this.#u=void 0}#b(t){let e=tP.get(this.type);return!!e?.has(t)}#v(t){if(!t||"object"!=typeof t||null!==t.type||1!==t.#n.length||null===this.type||1!==this.#n.length)return!1;let e=t.#n[0];return!(!e||"object"!=typeof e||null===e.type)&&this.#b(e.type)}#x(t){let e=tP.get(this.type),i=t.#n[0],n=e?.get(i.type);if(!n)return!1;for(let t of(this.#n=i.#n,this.#n))"object"==typeof t&&(t.#r=this);this.type=n,this.#u=void 0,this.#h=!1}#w(){if(t_(this.type)){let t=0,e=!1;do{e=!0;for(let t=0;t<this.#n.length;t++){let i=this.#n[t];"object"==typeof i&&(i.#w(),this.#g(i)?(e=!1,this.#y(i,t)):this.#f(i)?(e=!1,this.#m(i,t)):this.#v(i)&&(e=!1,this.#x(i)))}}while(!e&&++t<10)}else for(let t of this.#n)"object"==typeof t&&t.#w();this.#u=void 0}static fromGlob(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},i=new b(null,void 0,e);return b.#p(t,i,0,e,0),i}toMMPattern(){if(this!==this.#t)return this.#t.toMMPattern();let t=this.toString(),[e,i,n,r]=this.toRegExpSource();return n||this.#e||this.#l.nocase&&!this.#l.nocaseMagicOnly&&t.toUpperCase()!==t.toLowerCase()?Object.assign(RegExp(`^${e}$`,(this.#l.nocase?"i":"")+(r?"u":"")),{_src:e,_glob:t}):i}get options(){return this.#l}toRegExpSource(t){let e=t??!!this.#l.dot;if(this.#t===this&&(this.#w(),this.#c()),!t_(this.type)){let i=this.isStart()&&this.isEnd(),n=this.#n.map(e=>{let[n,r,o,s]="string"==typeof e?b.#N(e,this.#e,i):e.toRegExpSource(t);return this.#e=this.#e||o,this.#i=this.#i||s,n}).join(""),r="";if(this.isStart()&&"string"==typeof this.#n[0]&&(1!==this.#n.length||!tT.has(this.#n[0]))){let i=e&&tA.has(n.charAt(0))||n.startsWith("\\.")&&tA.has(n.charAt(2))||n.startsWith("\\.\\.")&&tA.has(n.charAt(4)),o=!e&&!t&&tA.has(n.charAt(0));r=i?"(?!(?:^|/)\\.\\.?(?:$|/))":o?tO:""}let o="";return this.isEnd()&&this.#t.#a&&"!"===this.#r?.type&&(o="(?:$|\\/)"),[r+n+o,tw(n),this.#e=!!this.#e,this.#i]}let i="*"===this.type||"+"===this.type,n="!"===this.type?"(?:(?!(?:":"(?:",r=this.#_(e);if(this.isStart()&&this.isEnd()&&!r&&"!"!==this.type){let t=this.toString();return this.#n=[t],this.type=null,this.#e=void 0,[t,tw(this.toString()),!1,!1]}let o=!i||t||e?"":this.#_(!0);o===r&&(o=""),o&&(r=`(?:${r})(?:${o})*?`);return["!"===this.type&&this.#h?(this.isStart()&&!e?tO:"")+tj:n+r+("!"===this.type?"))"+(!this.isStart()||e||t?"":tO)+tL+")":"@"===this.type?")":"?"===this.type?")?":"+"===this.type&&o?")":"*"===this.type&&o?")?":`)${this.type}`),tw(r),this.#e=!!this.#e,this.#i]}#_(t){return this.#n.map(e=>{if("string"==typeof e)throw Error("string type in extglob ast??");let[i,n,r,o]=e.toRegExpSource(t);return this.#i=this.#i||o,i}).filter(t=>!(this.isStart()&&this.isEnd()&&!t)).join("|")}static #N(t,e){let i=arguments.length>2&&void 0!==arguments[2]&&arguments[2],n=!1,r="",o=!1,s=!1;for(let a=0;a<t.length;a++){let l=t.charAt(a);if(n)n=!1,r+=(t$.has(l)?"\\":"")+l,s=!1;else if("\\"!==l){if("["===l){let[i,n,l,u]=tx(t,a);if(l){r+=i,o=o||n,a+=l-1,e=e||u,s=!1;continue}}if("*"!==l)s=!1,"?"!==l?r+=l.replace(/[-[\]{}()*+?.,\\^$|#\s]/g,"\\$&"):(r+=tk,e=!0);else{if(s)continue;s=!0,r+=i&&/^[*]+$/.test(t)?tj:tL,e=!0}}else a===t.length-1?r+="\\\\":n=!0}return[r,tw(t),!!e,o]}}b=tI;let tR=function(t,e){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};return ty(e),!(!i.nocomment&&"#"===e.charAt(0))&&new t0(e,i).match(t)},tD=/^\*+([^+@!?\*\[\(]*)$/,tV=/^\*+\.\*+$/,tM=t=>!t.startsWith(".")&&t.includes("."),tB=t=>"."!==t&&".."!==t&&t.includes("."),tF=/^\.\*+$/,tU=t=>"."!==t&&".."!==t&&t.startsWith("."),tW=/^\*+$/,tz=t=>0!==t.length&&!t.startsWith("."),tX=t=>0!==t.length&&"."!==t&&".."!==t,tG=/^\?+([^+@!?\*\[\(]*)?$/,tq=t=>{let[e]=t,i=e.length;return t=>t.length===i&&!t.startsWith(".")},tH=t=>{let[e]=t,i=e.length;return t=>t.length===i&&"."!==t&&".."!==t},tK="object"==typeof x&&x?"object"==typeof x.env&&x.env&&x.env.__MINIMATCH_TESTING_PLATFORM__||x.platform:"posix";tR.sep="win32"===tK?"\\":"/";let tQ=Symbol("globstar **");tR.GLOBSTAR=tQ,tR.filter=function(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return i=>tR(i,t,e)};let tY=function(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return Object.assign({},t,e)};tR.defaults=t=>{if(!t||"object"!=typeof t||!Object.keys(t).length)return tR;let e=tR;return Object.assign(function(i,n){return e(i,n,tY(t,arguments.length>2&&void 0!==arguments[2]?arguments[2]:{}))},{Minimatch:class extends e.Minimatch{constructor(e){super(e,tY(t,arguments.length>1&&void 0!==arguments[1]?arguments[1]:{}))}static defaults(i){return e.defaults(tY(t,i)).Minimatch}},AST:class extends e.AST{constructor(e,i){super(e,i,tY(t,arguments.length>2&&void 0!==arguments[2]?arguments[2]:{}))}static fromGlob(i){let n=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return e.AST.fromGlob(i,tY(t,n))}},unescape:function(i){let n=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return e.unescape(i,tY(t,n))},escape:function(i){let n=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return e.escape(i,tY(t,n))},filter:function(i){let n=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return e.filter(i,tY(t,n))},defaults:i=>e.defaults(tY(t,i)),makeRe:function(i){let n=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return e.makeRe(i,tY(t,n))},braceExpand:function(i){let n=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return e.braceExpand(i,tY(t,n))},match:function(i,n){let r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};return e.match(i,n,tY(t,r))},sep:e.sep,GLOBSTAR:tQ})};let tJ=function(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return ty(t),e.nobrace||!/\{(?:(?!\{).)*\}/.test(t)?[t]:tm(t)};tR.braceExpand=tJ,tR.makeRe=function(t){return new t0(t,arguments.length>1&&void 0!==arguments[1]?arguments[1]:{}).makeRe()},tR.match=function(t,e){let i=new t0(e,arguments.length>2&&void 0!==arguments[2]?arguments[2]:{});return t=t.filter(t=>i.match(t)),i.options.nonull&&!t.length&&t.push(e),t};let tZ=/[?*]|[+@!]\(.*?\)|\[|\]/;class t0{options;set;pattern;windowsPathsNoEscape;nonegate;negate;comment;empty;preserveMultipleSlashes;partial;globSet;globParts;nocase;isWindows;platform;windowsNoMagicRoot;maxGlobstarRecursion;regexp;constructor(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};ty(t),e=e||{},this.options=e,this.maxGlobstarRecursion=e.maxGlobstarRecursion??200,this.pattern=t,this.platform=e.platform||tK,this.isWindows="win32"===this.platform,this.windowsPathsNoEscape=!!e.windowsPathsNoEscape||!1===e.allowWindowsEscape,this.windowsPathsNoEscape&&(this.pattern=this.pattern.replace(/\\/g,"/")),this.preserveMultipleSlashes=!!e.preserveMultipleSlashes,this.regexp=null,this.negate=!1,this.nonegate=!!e.nonegate,this.comment=!1,this.empty=!1,this.partial=!!e.partial,this.nocase=!!this.options.nocase,this.windowsNoMagicRoot=void 0!==e.windowsNoMagicRoot?e.windowsNoMagicRoot:!(!this.isWindows||!this.nocase),this.globSet=[],this.globParts=[],this.set=[],this.make()}hasMagic(){if(this.options.magicalBraces&&this.set.length>1)return!0;for(let t of this.set)for(let e of t)if("string"!=typeof e)return!0;return!1}debug(){}make(){let t=this.pattern,e=this.options;if(!e.nocomment&&"#"===t.charAt(0))return void(this.comment=!0);if(!t)return void(this.empty=!0);this.parseNegate(),this.globSet=[...new Set(this.braceExpand())],e.debug&&(this.debug=function(){return console.error(...arguments)}),this.debug(this.pattern,this.globSet);let i=this.globSet.map(t=>this.slashSplit(t));this.globParts=this.preprocess(i),this.debug(this.pattern,this.globParts);let n=this.globParts.map((t,e,i)=>{if(this.isWindows&&this.windowsNoMagicRoot){let e=!(""!==t[0]||""!==t[1]||"?"!==t[2]&&tZ.test(t[2])||tZ.test(t[3])),i=/^[a-z]:/i.test(t[0]);if(e)return[...t.slice(0,4),...t.slice(4).map(t=>this.parse(t))];if(i)return[t[0],...t.slice(1).map(t=>this.parse(t))]}return t.map(t=>this.parse(t))});if(this.debug(this.pattern,n),this.set=n.filter(t=>-1===t.indexOf(!1)),this.isWindows)for(let t=0;t<this.set.length;t++){let e=this.set[t];""===e[0]&&""===e[1]&&"?"===this.globParts[t][2]&&"string"==typeof e[3]&&/^[a-z]:$/i.test(e[3])&&(e[2]="?")}this.debug(this.pattern,this.set)}preprocess(t){if(this.options.noglobstar)for(let e=0;e<t.length;e++)for(let i=0;i<t[e].length;i++)"**"===t[e][i]&&(t[e][i]="*");let{optimizationLevel:e=1}=this.options;return e>=2?(t=this.firstPhasePreProcess(t),t=this.secondPhasePreProcess(t)):t=e>=1?this.levelOneOptimize(t):this.adjascentGlobstarOptimize(t),t}adjascentGlobstarOptimize(t){return t.map(t=>{let e=-1;for(;-1!==(e=t.indexOf("**",e+1));){let i=e;for(;"**"===t[i+1];)i++;i!==e&&t.splice(e,i-e)}return t})}levelOneOptimize(t){return t.map(t=>0===(t=t.reduce((t,e)=>{let i=t[t.length-1];return"**"===e&&"**"===i||(".."===e&&i&&".."!==i&&"."!==i&&"**"!==i?t.pop():t.push(e)),t},[])).length?[""]:t)}levelTwoFileOptimize(t){Array.isArray(t)||(t=this.slashSplit(t));let e=!1;do{if(e=!1,!this.preserveMultipleSlashes){for(let i=1;i<t.length-1;i++){let n=t[i];1===i&&""===n&&""===t[0]||"."!==n&&""!==n||(e=!0,t.splice(i,1),i--)}"."!==t[0]||2!==t.length||"."!==t[1]&&""!==t[1]||(e=!0,t.pop())}let i=0;for(;-1!==(i=t.indexOf("..",i+1));){let n=t[i-1];n&&"."!==n&&".."!==n&&"**"!==n&&(e=!0,t.splice(i-1,2),i-=2)}}while(e);return 0===t.length?[""]:t}firstPhasePreProcess(t){let e=!1;do for(let i of(e=!1,t)){let n=-1;for(;-1!==(n=i.indexOf("**",n+1));){let r=n;for(;"**"===i[r+1];)r++;r>n&&i.splice(n+1,r-n);let o=i[n+1],s=i[n+2],a=i[n+3];if(".."!==o||!s||"."===s||".."===s||!a||"."===a||".."===a)continue;e=!0,i.splice(n,1);let l=i.slice(0);l[n]="**",t.push(l),n--}if(!this.preserveMultipleSlashes){for(let t=1;t<i.length-1;t++){let n=i[t];1===t&&""===n&&""===i[0]||"."!==n&&""!==n||(e=!0,i.splice(t,1),t--)}"."!==i[0]||2!==i.length||"."!==i[1]&&""!==i[1]||(e=!0,i.pop())}let r=0;for(;-1!==(r=i.indexOf("..",r+1));){let t=i[r-1];if(t&&"."!==t&&".."!==t&&"**"!==t){e=!0;let t=1===r&&"**"===i[r+1]?["."]:[];i.splice(r-1,2,...t),0===i.length&&i.push(""),r-=2}}}while(e);return t}secondPhasePreProcess(t){for(let e=0;e<t.length-1;e++)for(let i=e+1;i<t.length;i++){let n=this.partsMatch(t[e],t[i],!this.preserveMultipleSlashes);if(n){t[e]=[],t[i]=n;break}}return t.filter(t=>t.length)}partsMatch(t,e){let i=arguments.length>2&&void 0!==arguments[2]&&arguments[2],n=0,r=0,o=[],s="";for(;n<t.length&&r<e.length;)if(t[n]===e[r])o.push("b"===s?e[r]:t[n]),n++,r++;else if(i&&"**"===t[n]&&e[r]===t[n+1])o.push(t[n]),n++;else if(i&&"**"===e[r]&&t[n]===e[r+1])o.push(e[r]),r++;else if("*"!==t[n]||!e[r]||!this.options.dot&&e[r].startsWith(".")||"**"===e[r]){if("*"!==e[r]||!t[n]||!this.options.dot&&t[n].startsWith(".")||"**"===t[n]||"a"===s)return!1;s="b",o.push(e[r]),n++,r++}else{if("b"===s)return!1;s="a",o.push(t[n]),n++,r++}return t.length===e.length&&o}parseNegate(){if(this.nonegate)return;let t=this.pattern,e=!1,i=0;for(let n=0;n<t.length&&"!"===t.charAt(n);n++)e=!e,i++;i&&(this.pattern=t.slice(i)),this.negate=e}matchOne(t,e){let i=arguments.length>2&&void 0!==arguments[2]&&arguments[2],n=0,r=0;if(this.isWindows){let i="string"==typeof t[0]&&/^[a-z]:$/i.test(t[0]),o=!i&&""===t[0]&&""===t[1]&&"?"===t[2]&&/^[a-z]:$/i.test(t[3]),s="string"==typeof e[0]&&/^[a-z]:$/i.test(e[0]),a=o?3:i?0:void 0,l=!s&&""===e[0]&&""===e[1]&&"?"===e[2]&&"string"==typeof e[3]&&/^[a-z]:$/i.test(e[3])?3:s?0:void 0;if("number"==typeof a&&"number"==typeof l){let[i,o]=[t[a],e[l]];i.toLowerCase()===o.toLowerCase()&&(e[l]=i,r=l,n=a)}}let{optimizationLevel:o=1}=this.options;return o>=2&&(t=this.levelTwoFileOptimize(t)),e.includes(tQ)?this.#S(t,e,i,n,r):this.#E(t,e,i,n,r)}#S(t,e,i,n,r){let o=e.indexOf(tQ,r),s=e.lastIndexOf(tQ),[a,l,u]=i?[e.slice(r,o),e.slice(o+1),[]]:[e.slice(r,o),e.slice(o+1,s),e.slice(s+1)];if(a.length){let e=t.slice(n,n+a.length);if(!this.#E(e,a,i,0,0))return!1;n+=a.length}let h=0;if(u.length){if(u.length+n>t.length)return!1;let e=t.length-u.length;if(this.#E(t,u,i,e,0))h=u.length;else{if(""!==t[t.length-1]||n+u.length===t.length||(e--,!this.#E(t,u,i,e,0)))return!1;h=u.length+1}}if(!l.length){let e=!!h;for(let i=n;i<t.length-h;i++){let n=String(t[i]);if(e=!0,"."===n||".."===n||!this.options.dot&&n.startsWith("."))return!1}return i||e}let c=[[[],0]],p=c[0],d=0,f=[0];for(let t of l)t===tQ?(f.push(d),p=[[],0],c.push(p)):(p[0].push(t),d++);let g=c.length-1,m=t.length-h;for(let t of c)t[1]=m-(f[g--]+t[0].length);return!!this.#C(t,c,n,0,i,0,!!h)}#C(t,e,i,n,r,o,s){let a=e[n];if(!a){for(let e=i;e<t.length;e++){s=!0;let i=t[e];if("."===i||".."===i||!this.options.dot&&i.startsWith("."))return!1}return s}let[l,u]=a;for(;i<=u;){if(this.#E(t.slice(0,i+l.length),l,r,i,0)&&o<this.maxGlobstarRecursion){let a=this.#C(t,e,i+l.length,n+1,r,o+1,s);if(!1!==a)return a}let a=t[i];if("."===a||".."===a||!this.options.dot&&a.startsWith("."))return!1;i++}return r||null}#E(t,e,i,n,r){let o,s,a,l;for(o=n,s=r,l=t.length,a=e.length;o<l&&s<a;o++,s++){this.debug("matchOne loop");let i,n=e[s],r=t[o];if(this.debug(e,n,r),!1===n||n===tQ||("string"==typeof n?(i=r===n,this.debug("string match",n,r,i)):(i=n.test(r),this.debug("pattern match",n,r,i)),!i))return!1}if(o===l&&s===a)return!0;if(o===l)return i;if(s===a)return o===l-1&&""===t[o];throw Error("wtf?")}braceExpand(){return tJ(this.pattern,this.options)}parse(t){ty(t);let e=this.options;if("**"===t)return tQ;if(""===t)return"";let i,n=null;(i=t.match(tW))?n=e.dot?tX:tz:(i=t.match(tD))?n=(e.nocase?e.dot?t=>(t=t.toLowerCase(),e=>e.toLowerCase().endsWith(t)):t=>(t=t.toLowerCase(),e=>!e.startsWith(".")&&e.toLowerCase().endsWith(t)):e.dot?t=>e=>e.endsWith(t):t=>e=>!e.startsWith(".")&&e.endsWith(t))(i[1]):(i=t.match(tG))?n=(e.nocase?e.dot?t=>{let[e,i=""]=t,n=tH([e]);return i?(i=i.toLowerCase(),t=>n(t)&&t.toLowerCase().endsWith(i)):n}:t=>{let[e,i=""]=t,n=tq([e]);return i?(i=i.toLowerCase(),t=>n(t)&&t.toLowerCase().endsWith(i)):n}:e.dot?t=>{let[e,i=""]=t,n=tH([e]);return i?t=>n(t)&&t.endsWith(i):n}:t=>{let[e,i=""]=t,n=tq([e]);return i?t=>n(t)&&t.endsWith(i):n})(i):(i=t.match(tV))?n=e.dot?tB:tM:(i=t.match(tF))&&(n=tU);let r=tI.fromGlob(t,this.options).toMMPattern();return n&&"object"==typeof r&&Reflect.defineProperty(r,"test",{value:n}),r}makeRe(){if(this.regexp||!1===this.regexp)return this.regexp;let t=this.set;if(!t.length)return this.regexp=!1,this.regexp;let e=this.options,i=e.noglobstar?"[^/]*?":e.dot?"(?:(?!(?:\\/|^)(?:\\.{1,2})($|\\/)).)*?":"(?:(?!(?:\\/|^)\\.).)*?",n=new Set(e.nocase?["i"]:[]),r=t.map(t=>{let e=t.map(t=>{if(t instanceof RegExp)for(let e of t.flags.split(""))n.add(e);return"string"==typeof t?t.replace(/[-[\]{}()*+?.,\\^$|#\s]/g,"\\$&"):t===tQ?tQ:t._src});return e.forEach((t,n)=>{let r=e[n+1],o=e[n-1];t===tQ&&o!==tQ&&(void 0===o?void 0!==r&&r!==tQ?e[n+1]="(?:\\/|"+i+"\\/)?"+r:e[n]=i:void 0===r?e[n-1]=o+"(?:\\/|"+i+")?":r!==tQ&&(e[n-1]=o+"(?:\\/|\\/"+i+"\\/)"+r,e[n+1]=tQ))}),e.filter(t=>t!==tQ).join("/")}).join("|"),[o,s]=t.length>1?["(?:",")"]:["",""];r="^"+o+r+s+"$",this.negate&&(r="^(?!"+r+").+$");try{this.regexp=new RegExp(r,[...n].join(""))}catch(t){this.regexp=!1}return this.regexp}slashSplit(t){return this.preserveMultipleSlashes?t.split("/"):this.isWindows&&/^\/\/[^\/]+/.test(t)?["",...t.split(/\/+/)]:t.split(/\/+/)}match(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:this.partial;if(this.debug("match",t,this.pattern),this.comment)return!1;if(this.empty)return""===t;if("/"===t&&e)return!0;let i=this.options;this.isWindows&&(t=t.split("\\").join("/"));let n=this.slashSplit(t);this.debug(this.pattern,"split",n);let r=this.set;this.debug(this.pattern,"set",r);let o=n[n.length-1];if(!o)for(let t=n.length-2;!o&&t>=0;t--)o=n[t];for(let t=0;t<r.length;t++){let s=r[t],a=n;if(i.matchBase&&1===s.length&&(a=[o]),this.matchOne(a,s,e))return!!i.flipNegate||!this.negate}return!i.flipNegate&&this.negate}static defaults(t){return tR.defaults(t).Minimatch}}function t1(t){let e=Error(`${arguments.length>1&&void 0!==arguments[1]?arguments[1]:""}Invalid response: ${t.status} ${t.statusText}`);return e.status=t.status,e.response=t,e}function t2(t,e){let{status:i}=e;if(401===i&&t.digest)return e;if(i>=400)throw t1(e);return e}function t3(t,e){return arguments.length>2&&void 0!==arguments[2]&&arguments[2]?{data:e,headers:t.headers?function(t){let e={};for(let i of t.keys())e[i]=t.get(i);return e}(t.headers):{},status:t.status,statusText:t.statusText}:e}tR.AST=tI,tR.Minimatch=t0,tR.escape=function(t){let{windowsPathsNoEscape:e=!1}=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return e?t.replace(/[?*()[\]]/g,"[$&]"):t.replace(/[?*()[\]\\]/g,"\\$&")},tR.unescape=tw;let t4=(v=function(t,e,i){var n,r;let o=arguments.length>3&&void 0!==arguments[3]?arguments[3]:{},s=tf({url:R(t.remoteURL,L(e)),method:"COPY",headers:{Destination:R(t.remoteURL,L(i)),Overwrite:!1===o.overwrite?"F":"T",Depth:o.shallow?"0":"infinity"}},t,o);return n=function(e){t2(t,e)},(r=td(s,t))&&r.then||(r=Promise.resolve(r)),n?r.then(n):r},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(v.apply(this,t))}catch(t){return Promise.reject(t)}}),t6=":A-Za-z_\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD",t8=RegExp("^["+t6+"]["+t6+"\\-.\\d\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$");function t5(t,e){let i=[],n=e.exec(t);for(;n;){let r=[];r.startIndex=e.lastIndex-n[0].length;let o=n.length;for(let t=0;t<o;t++)r.push(n[t]);i.push(r),n=e.exec(t)}return i}let t9=function(t){return null!=t8.exec(t)},t7=["hasOwnProperty","toString","valueOf","__defineGetter__","__defineSetter__","__lookupGetter__","__lookupSetter__"],et=["__proto__","constructor","prototype"],ee=t=>t7.includes(t)?"__"+t:t,ei={preserveOrder:!1,attributeNamePrefix:"@_",attributesGroupName:!1,textNodeName:"#text",ignoreAttributes:!0,removeNSPrefix:!1,allowBooleanAttributes:!1,parseTagValue:!0,parseAttributeValue:!1,trimValues:!0,cdataPropName:!1,numberParseOptions:{hex:!0,leadingZeros:!0,eNotation:!0},tagValueProcessor:function(t,e){return e},attributeValueProcessor:function(t,e){return e},stopNodes:[],alwaysCreateTextNode:!1,isArray:()=>!1,commentPropName:!1,unpairedTags:[],processEntities:!0,htmlEntities:!1,entityDecoder:null,ignoreDeclaration:!1,ignorePiTags:!1,transformTagName:!1,transformAttributeName:!1,updateTag:function(t,e,i){return t},captureMetaData:!1,maxNestedTags:100,strictReservedNames:!0,jPath:!0,onDangerousProperty:ee},en=function(t){let e=Object.assign({},ei,t);for(let{value:t,name:i}of[{value:e.attributeNamePrefix,name:"attributeNamePrefix"},{value:e.attributesGroupName,name:"attributesGroupName"},{value:e.textNodeName,name:"textNodeName"},{value:e.cdataPropName,name:"cdataPropName"},{value:e.commentPropName,name:"commentPropName"}])t&&function(t,e){if("string"!=typeof t)return;let i=t.toLowerCase();if(t7.some(t=>i===t.toLowerCase())||et.some(t=>i===t.toLowerCase()))throw Error(`[SECURITY] Invalid ${e}: "${t}" is a reserved JavaScript keyword that could cause prototype pollution`)}(t,i);return null===e.onDangerousProperty&&(e.onDangerousProperty=ee),e.processEntities=function t(e,i){return"boolean"==typeof e?{enabled:e,maxEntitySize:1e4,maxExpansionDepth:1e4,maxTotalExpansions:1/0,maxExpandedLength:1e5,maxEntityCount:1e3,allowedTags:null,tagFilter:null,appliesTo:"all"}:"object"==typeof e&&null!==e?{enabled:!1!==e.enabled,maxEntitySize:Math.max(1,e.maxEntitySize??1e4),maxExpansionDepth:Math.max(1,e.maxExpansionDepth??1e4),maxTotalExpansions:Math.max(1,e.maxTotalExpansions??1/0),maxExpandedLength:Math.max(1,e.maxExpandedLength??1e5),maxEntityCount:Math.max(1,e.maxEntityCount??1e3),allowedTags:e.allowedTags??null,tagFilter:e.tagFilter??null,appliesTo:e.appliesTo??"all"}:t(!0)}(e.processEntities,e.htmlEntities),e.unpairedTagsSet=new Set(e.unpairedTags),e.stopNodes&&Array.isArray(e.stopNodes)&&(e.stopNodes=e.stopNodes.map(t=>"string"==typeof t&&t.startsWith("*.")?".."+t.substring(2):t)),e};n="function"!=typeof Symbol?"@@xmlMetadata":Symbol("XML Node Metadata");class er{constructor(t){this.tagname=t,this.child=[],this[":@"]=Object.create(null)}add(t,e){"__proto__"===t&&(t="#__proto__"),this.child.push({[t]:e})}addChild(t,e){"__proto__"===t.tagname&&(t.tagname="#__proto__"),t[":@"]&&Object.keys(t[":@"]).length>0?this.child.push({[t.tagname]:t.child,":@":t[":@"]}):this.child.push({[t.tagname]:t.child}),void 0!==e&&(this.child[this.child.length-1][n]={startIndex:e})}static getMetaDataSymbol(){return n}}class eo{constructor(t){this.suppressValidationErr=!t,this.options=t}readDocType(t,e){let i=Object.create(null),n=0;if("O"!==t[e+3]||"C"!==t[e+4]||"T"!==t[e+5]||"Y"!==t[e+6]||"P"!==t[e+7]||"E"!==t[e+8])throw Error("Invalid Tag instead of DOCTYPE");{e+=9;let r=1,o=!1,s=!1;for(;e<t.length;e++)if("<"!==t[e]||s)if(">"===t[e]){if(s?"-"===t[e-1]&&"-"===t[e-2]&&(s=!1,r--):r--,0===r)break}else"["===t[e]?o=!0:t[e];else{if(o&&ea(t,"!ENTITY",e)){let r,o;if(e+=7,[r,o,e]=this.readEntityExp(t,e+1,this.suppressValidationErr),-1===o.indexOf("&")){if(!1!==this.options.enabled&&null!=this.options.maxEntityCount&&n>=this.options.maxEntityCount)throw Error(`Entity count (${n+1}) exceeds maximum allowed (${this.options.maxEntityCount})`);i[r]=o,n++}}else if(o&&ea(t,"!ELEMENT",e)){e+=8;let{index:i}=this.readElementExp(t,e+1);e=i}else if(o&&ea(t,"!ATTLIST",e))e+=8;else if(o&&ea(t,"!NOTATION",e)){e+=9;let{index:i}=this.readNotationExp(t,e+1,this.suppressValidationErr);e=i}else{if(!ea(t,"!--",e))throw Error("Invalid DOCTYPE");s=!0}r++}if(0!==r)throw Error("Unclosed DOCTYPE")}return{entities:i,i:e}}readEntityExp(t,e){let i=e=es(t,e);for(;e<t.length&&!/\s/.test(t[e])&&'"'!==t[e]&&"'"!==t[e];)e++;let n=t.substring(i,e);if(el(n),e=es(t,e),!this.suppressValidationErr){if("SYSTEM"===t.substring(e,e+6).toUpperCase())throw Error("External entities are not supported");if("%"===t[e])throw Error("Parameter entities are not supported")}let r="";if([e,r]=this.readIdentifierVal(t,e,"entity"),!1!==this.options.enabled&&null!=this.options.maxEntitySize&&r.length>this.options.maxEntitySize)throw Error(`Entity "${n}" size (${r.length}) exceeds maximum allowed size (${this.options.maxEntitySize})`);return[n,r,--e]}readNotationExp(t,e){let i=e=es(t,e);for(;e<t.length&&!/\s/.test(t[e]);)e++;let n=t.substring(i,e);this.suppressValidationErr||el(n),e=es(t,e);let r=t.substring(e,e+6).toUpperCase();if(!this.suppressValidationErr&&"SYSTEM"!==r&&"PUBLIC"!==r)throw Error(`Expected SYSTEM or PUBLIC, found "${r}"`);e+=r.length,e=es(t,e);let o=null,s=null;if("PUBLIC"===r)[e,o]=this.readIdentifierVal(t,e,"publicIdentifier"),'"'!==t[e=es(t,e)]&&"'"!==t[e]||([e,s]=this.readIdentifierVal(t,e,"systemIdentifier"));else if("SYSTEM"===r&&([e,s]=this.readIdentifierVal(t,e,"systemIdentifier"),!this.suppressValidationErr&&!s))throw Error("Missing mandatory system identifier for SYSTEM notation");return{notationName:n,publicIdentifier:o,systemIdentifier:s,index:--e}}readIdentifierVal(t,e,i){let n="",r=t[e];if('"'!==r&&"'"!==r)throw Error(`Expected quoted string, found "${r}"`);let o=++e;for(;e<t.length&&t[e]!==r;)e++;if(n=t.substring(o,e),t[e]!==r)throw Error(`Unterminated ${i} value`);return[++e,n]}readElementExp(t,e){let i=e=es(t,e);for(;e<t.length&&!/\s/.test(t[e]);)e++;let n=t.substring(i,e);if(!this.suppressValidationErr&&!t9(n))throw Error(`Invalid element name: "${n}"`);let r="";if("E"===t[e=es(t,e)]&&ea(t,"MPTY",e))e+=4;else if("A"===t[e]&&ea(t,"NY",e))e+=2;else if("("===t[e]){let i=++e;for(;e<t.length&&")"!==t[e];)e++;if(r=t.substring(i,e),")"!==t[e])throw Error("Unterminated content model")}else if(!this.suppressValidationErr)throw Error(`Invalid Element Expression, found "${t[e]}"`);return{elementName:n,contentModel:r.trim(),index:e}}readAttlistExp(t,e){let i=e=es(t,e);for(;e<t.length&&!/\s/.test(t[e]);)e++;let n=t.substring(i,e);for(el(n),i=e=es(t,e);e<t.length&&!/\s/.test(t[e]);)e++;let r=t.substring(i,e);if(!el(r))throw Error(`Invalid attribute name: "${r}"`);e=es(t,e);let o="";if("NOTATION"===t.substring(e,e+8).toUpperCase()){if(o="NOTATION","("!==t[e=es(t,e+=8)])throw Error(`Expected '(', found "${t[e]}"`);e++;let i=[];for(;e<t.length&&")"!==t[e];){let n=e;for(;e<t.length&&"|"!==t[e]&&")"!==t[e];)e++;let r=t.substring(n,e);if(!el(r=r.trim()))throw Error(`Invalid notation name: "${r}"`);i.push(r),"|"===t[e]&&(e=es(t,++e))}if(")"!==t[e])throw Error("Unterminated list of notations");e++,o+=" ("+i.join("|")+")"}else{let i=e;for(;e<t.length&&!/\s/.test(t[e]);)e++;if(o+=t.substring(i,e),!this.suppressValidationErr&&!["CDATA","ID","IDREF","IDREFS","ENTITY","ENTITIES","NMTOKEN","NMTOKENS"].includes(o.toUpperCase()))throw Error(`Invalid attribute type: "${o}"`)}e=es(t,e);let s="";return"#REQUIRED"===t.substring(e,e+8).toUpperCase()?(s="#REQUIRED",e+=8):"#IMPLIED"===t.substring(e,e+7).toUpperCase()?(s="#IMPLIED",e+=7):[e,s]=this.readIdentifierVal(t,e,"ATTLIST"),{elementName:n,attributeName:r,attributeType:o,defaultValue:s,index:e}}}let es=(t,e)=>{for(;e<t.length&&/\s/.test(t[e]);)e++;return e};function ea(t,e,i){for(let n=0;n<e.length;n++)if(e[n]!==t[i+n+1])return!1;return!0}function el(t){if(t9(t))return t;throw Error(`Invalid entity name ${t}`)}let eu=/^[-+]?0x[a-fA-F0-9]+$/,eh=/^([\-\+])?(0*)([0-9]*(\.[0-9]*)?)$/,ec={hex:!0,leadingZeros:!0,decimalPoint:".",eNotation:!0,infinity:"original"},ep=/^([-+])?(0*)(\d*(\.\d*)?[eE][-\+]?\d+)$/;class ed{constructor(t){this._matcher=t}get separator(){return this._matcher.separator}getCurrentTag(){let t=this._matcher.path;return t.length>0?t[t.length-1].tag:void 0}getCurrentNamespace(){let t=this._matcher.path;return t.length>0?t[t.length-1].namespace:void 0}getAttrValue(t){let e=this._matcher.path;if(0!==e.length)return e[e.length-1].values?.[t]}hasAttr(t){let e=this._matcher.path;if(0===e.length)return!1;let i=e[e.length-1];return void 0!==i.values&&t in i.values}getPosition(){let t=this._matcher.path;return 0===t.length?-1:t[t.length-1].position??0}getCounter(){let t=this._matcher.path;return 0===t.length?-1:t[t.length-1].counter??0}getIndex(){return this.getPosition()}getDepth(){return this._matcher.path.length}toString(t){let e=!(arguments.length>1&&void 0!==arguments[1])||arguments[1];return this._matcher.toString(t,e)}toArray(){return this._matcher.path.map(t=>t.tag)}matches(t){return this._matcher.matches(t)}matchesAny(t){return t.matchesAny(this._matcher)}}class ef{constructor(){let t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{};this.separator=t.separator||".",this.path=[],this.siblingStacks=[],this._pathStringCache=null,this._view=new ed(this)}push(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:null,i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:null;this._pathStringCache=null,this.path.length>0&&(this.path[this.path.length-1].values=void 0);let n=this.path.length;this.siblingStacks[n]||(this.siblingStacks[n]=new Map);let r=this.siblingStacks[n],o=i?`${i}:${t}`:t,s=r.get(o)||0,a=0;for(let t of r.values())a+=t;r.set(o,s+1);let l={tag:t,position:a,counter:s};null!=i&&(l.namespace=i),null!=e&&(l.values=e),this.path.push(l)}pop(){if(0===this.path.length)return;this._pathStringCache=null;let t=this.path.pop();return this.siblingStacks.length>this.path.length+1&&(this.siblingStacks.length=this.path.length+1),t}updateCurrent(t){if(this.path.length>0){let e=this.path[this.path.length-1];null!=t&&(e.values=t)}}getCurrentTag(){return this.path.length>0?this.path[this.path.length-1].tag:void 0}getCurrentNamespace(){return this.path.length>0?this.path[this.path.length-1].namespace:void 0}getAttrValue(t){if(0!==this.path.length)return this.path[this.path.length-1].values?.[t]}hasAttr(t){if(0===this.path.length)return!1;let e=this.path[this.path.length-1];return void 0!==e.values&&t in e.values}getPosition(){return 0===this.path.length?-1:this.path[this.path.length-1].position??0}getCounter(){return 0===this.path.length?-1:this.path[this.path.length-1].counter??0}getIndex(){return this.getPosition()}getDepth(){return this.path.length}toString(t){let e=!(arguments.length>1&&void 0!==arguments[1])||arguments[1],i=t||this.separator;if(i===this.separator&&!0===e){if(null!==this._pathStringCache)return this._pathStringCache;let t=this.path.map(t=>t.namespace?`${t.namespace}:${t.tag}`:t.tag).join(i);return this._pathStringCache=t,t}return this.path.map(t=>e&&t.namespace?`${t.namespace}:${t.tag}`:t.tag).join(i)}toArray(){return this.path.map(t=>t.tag)}reset(){this._pathStringCache=null,this.path=[],this.siblingStacks=[]}matches(t){let e=t.segments;return 0!==e.length&&(t.hasDeepWildcard()?this._matchWithDeepWildcard(e):this._matchSimple(e))}_matchSimple(t){if(this.path.length!==t.length)return!1;for(let e=0;e<t.length;e++)if(!this._matchSegment(t[e],this.path[e],e===this.path.length-1))return!1;return!0}_matchWithDeepWildcard(t){let e=this.path.length-1,i=t.length-1;for(;i>=0&&e>=0;){let n=t[i];if("deep-wildcard"===n.type){if(--i<0)return!0;let n=t[i],r=!1;for(let t=e;t>=0;t--)if(this._matchSegment(n,this.path[t],t===this.path.length-1)){e=t-1,i--,r=!0;break}if(!r)return!1}else{if(!this._matchSegment(n,this.path[e],e===this.path.length-1))return!1;e--,i--}}return i<0}_matchSegment(t,e,i){if("*"!==t.tag&&t.tag!==e.tag||void 0!==t.namespace&&"*"!==t.namespace&&t.namespace!==e.namespace||void 0!==t.attrName&&(!i||!e.values||!(t.attrName in e.values)||void 0!==t.attrValue&&String(e.values[t.attrName])!==String(t.attrValue)))return!1;if(void 0!==t.position){if(!i)return!1;let n=e.counter??0;if("first"===t.position&&0!==n||"odd"===t.position&&n%2!=1||"even"===t.position&&n%2!=0||"nth"===t.position&&n!==t.positionValue)return!1}return!0}matchesAny(t){return t.matchesAny(this)}snapshot(){return{path:this.path.map(t=>({...t})),siblingStacks:this.siblingStacks.map(t=>new Map(t))}}restore(t){this._pathStringCache=null,this.path=t.path.map(t=>({...t})),this.siblingStacks=t.siblingStacks.map(t=>new Map(t))}readOnly(){return this._view}}class eg{constructor(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},i=arguments.length>2?arguments[2]:void 0;this.pattern=t,this.separator=e.separator||".",this.segments=this._parse(t),this.data=i,this._hasDeepWildcard=this.segments.some(t=>"deep-wildcard"===t.type),this._hasAttributeCondition=this.segments.some(t=>void 0!==t.attrName),this._hasPositionSelector=this.segments.some(t=>void 0!==t.position)}_parse(t){let e=[],i=0,n="";for(;i<t.length;)t[i]===this.separator?i+1<t.length&&t[i+1]===this.separator?(n.trim()&&(e.push(this._parseSegment(n.trim())),n=""),e.push({type:"deep-wildcard"}),i+=2):(n.trim()&&e.push(this._parseSegment(n.trim())),n="",i++):(n+=t[i],i++);return n.trim()&&e.push(this._parseSegment(n.trim())),e}_parseSegment(t){let e={type:"tag"},i=null,n=t,r=t.match(/^([^\[]+)(\[[^\]]*\])(.*)$/);if(r&&(n=r[1]+r[3],r[2])){let t=r[2].slice(1,-1);t&&(i=t)}let o,s,a=n;if(n.includes("::")){let e=n.indexOf("::");if(o=n.substring(0,e).trim(),a=n.substring(e+2).trim(),!o)throw Error(`Invalid namespace in pattern: ${t}`)}let l=null;if(a.includes(":")){let t=a.lastIndexOf(":"),e=a.substring(0,t).trim(),i=a.substring(t+1).trim();["first","last","odd","even"].includes(i)||/^nth\(\d+\)$/.test(i)?(s=e,l=i):s=a}else s=a;if(!s)throw Error(`Invalid segment pattern: ${t}`);if(e.tag=s,o&&(e.namespace=o),i)if(i.includes("=")){let t=i.indexOf("=");e.attrName=i.substring(0,t).trim(),e.attrValue=i.substring(t+1).trim()}else e.attrName=i.trim();if(l){let t=l.match(/^nth\((\d+)\)$/);t?(e.position="nth",e.positionValue=parseInt(t[1],10)):e.position=l}return e}get length(){return this.segments.length}hasDeepWildcard(){return this._hasDeepWildcard}hasAttributeCondition(){return this._hasAttributeCondition}hasPositionSelector(){return this._hasPositionSelector}toString(){return this.pattern}}class em{constructor(){this._byDepthAndTag=new Map,this._wildcardByDepth=new Map,this._deepWildcards=[],this._patterns=new Set,this._sealed=!1}add(t){if(this._sealed)throw TypeError("ExpressionSet is sealed. Create a new ExpressionSet to add more expressions.");if(this._patterns.has(t.pattern))return this;if(this._patterns.add(t.pattern),t.hasDeepWildcard())return this._deepWildcards.push(t),this;let e=t.length,i=t.segments[t.segments.length-1],n=i?.tag;if(n&&"*"!==n){let i=`${e}:${n}`;this._byDepthAndTag.has(i)||this._byDepthAndTag.set(i,[]),this._byDepthAndTag.get(i).push(t)}else this._wildcardByDepth.has(e)||this._wildcardByDepth.set(e,[]),this._wildcardByDepth.get(e).push(t);return this}addAll(t){for(let e of t)this.add(e);return this}has(t){return this._patterns.has(t.pattern)}get size(){return this._patterns.size}seal(){return this._sealed=!0,this}get isSealed(){return this._sealed}matchesAny(t){return null!==this.findMatch(t)}findMatch(t){let e=t.getDepth(),i=`${e}:${t.getCurrentTag()}`,n=this._byDepthAndTag.get(i);if(n){for(let e=0;e<n.length;e++)if(t.matches(n[e]))return n[e]}let r=this._wildcardByDepth.get(e);if(r){for(let e=0;e<r.length;e++)if(t.matches(r[e]))return r[e]}for(let e=0;e<this._deepWildcards.length;e++)if(t.matches(this._deepWildcards[e]))return this._deepWildcards[e];return null}}let ey={cent:"\xa2",pound:"\xa3",curren:"\xa4",yen:"\xa5",euro:"€",dollar:"$",euro:"€",fnof:"ƒ",inr:"₹",af:"؋",birr:"ብር",peso:"₱",rub:"₽",won:"₩",yuan:"\xa5",cedil:"\xb8"},eb={amp:"&",apos:"'",gt:">",lt:"<",quot:'"'},ev={nbsp:"\xa0",copy:"\xa9",reg:"\xae",trade:"™",mdash:"—",ndash:"–",hellip:"…",laquo:"\xab",raquo:"\xbb",lsquo:"‘",rsquo:"’",ldquo:"“",rdquo:"”",bull:"•",para:"\xb6",sect:"\xa7",deg:"\xb0",frac12:"\xbd",frac14:"\xbc",frac34:"\xbe"},ex=new Set("!?\\\\/[]$%{}^&*()<>|+");function ew(t){if("#"===t[0])throw Error(`[EntityReplacer] Invalid character '#' in entity name: "${t}"`);for(let e of t)if(ex.has(e))throw Error(`[EntityReplacer] Invalid character '${e}' in entity name: "${t}"`);return t}function eN(){let t=Object.create(null);for(var e=arguments.length,i=Array(e),n=0;n<e;n++)i[n]=arguments[n];for(let e of i)if(e)for(let i of Object.keys(e)){let n=e[i];if("string"==typeof n)t[i]=n;else if(n&&"object"==typeof n&&void 0!==n.val){let e=n.val;"string"==typeof e&&(t[i]=e)}}return t}let e_="external",eS="base",eE=Object.freeze({allow:0,leave:1,remove:2,throw:3}),eC=new Set([9,10,13]);class eP{constructor(){var t;let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{};this._limit=e.limit||{},this._maxTotalExpansions=this._limit.maxTotalExpansions||0,this._maxExpandedLength=this._limit.maxExpandedLength||0,this._postCheck="function"==typeof e.postCheck?e.postCheck:t=>t,this._limitTiers=new Set((t=this._limit.applyLimitsTo??e_)&&t!==e_?"all"===t?["all"]:t===eS?[eS]:Array.isArray(t)?t:[e_]:[e_]),this._numericAllowed=e.numericAllowed??!0,this._baseMap=eN(eb,e.namedEntities||null),this._externalMap=Object.create(null),this._inputMap=Object.create(null),this._totalExpansions=0,this._expandedLength=0,this._removeSet=new Set(e.remove&&Array.isArray(e.remove)?e.remove:[]),this._leaveSet=new Set(e.leave&&Array.isArray(e.leave)?e.leave:[]);const i=function(t){return t?{xmlVersion:1.1===t.xmlVersion?1.1:1,onLevel:eE[t.onNCR]??eE.allow,nullLevel:Math.max(eE[t.nullNCR]??eE.remove,eE.remove)}:{xmlVersion:1,onLevel:eE.allow,nullLevel:eE.remove}}(e.ncr);this._ncrXmlVersion=i.xmlVersion,this._ncrOnLevel=i.onLevel,this._ncrNullLevel=i.nullLevel}setExternalEntities(t){if(t)for(let e of Object.keys(t))ew(e);this._externalMap=eN(t)}addExternalEntity(t,e){ew(t),"string"==typeof e&&-1===e.indexOf("&")&&(this._externalMap[t]=e)}addInputEntities(t){this._totalExpansions=0,this._expandedLength=0,this._inputMap=eN(t)}reset(){return this._inputMap=Object.create(null),this._totalExpansions=0,this._expandedLength=0,this}setXmlVersion(t){this._ncrXmlVersion=1.1===t?1.1:1}decode(t){if("string"!=typeof t||0===t.length)return t;let e=[],i=t.length,n=0,r=0,o=this._maxTotalExpansions>0,s=this._maxExpandedLength>0,a=o||s;for(;r<i;){let l,u;if(38!==t.charCodeAt(r)){r++;continue}let h=r+1;for(;h<i&&59!==t.charCodeAt(h)&&h-r<=32;)h++;if(h>=i||59!==t.charCodeAt(h)){r++;continue}let c=t.slice(r+1,h);if(0===c.length){r++;continue}if(this._removeSet.has(c))l="",void 0===u&&(u=e_);else{if(this._leaveSet.has(c)){r++;continue}if(35===c.charCodeAt(0)){let t=this._resolveNCR(c);if(void 0===t){r++;continue}l=t,u=eS}else{let t=this._resolveName(c);l=t?.value,u=t?.tier}}if(void 0!==l){if(r>n&&e.push(t.slice(n,r)),e.push(l),r=n=h+1,a&&this._tierCounts(u)){if(o&&(this._totalExpansions++,this._totalExpansions>this._maxTotalExpansions))throw Error(`[EntityReplacer] Entity expansion count limit exceeded: ${this._totalExpansions} > ${this._maxTotalExpansions}`);if(s){let t=l.length-(c.length+2);if(t>0&&(this._expandedLength+=t,this._expandedLength>this._maxExpandedLength))throw Error(`[EntityReplacer] Expanded content length limit exceeded: ${this._expandedLength} > ${this._maxExpandedLength}`)}}}else r++}n<i&&e.push(t.slice(n));let l=0===e.length?t:e.join("");return this._postCheck(l,t)}_tierCounts(t){return!!this._limitTiers.has("all")||this._limitTiers.has(t)}_resolveName(t){return t in this._inputMap?{value:this._inputMap[t],tier:e_}:t in this._externalMap?{value:this._externalMap[t],tier:e_}:t in this._baseMap?{value:this._baseMap[t],tier:eS}:void 0}_classifyNCR(t){return 0===t?this._ncrNullLevel:t>=55296&&t<=57343||1===this._ncrXmlVersion&&t>=1&&t<=31&&!eC.has(t)?eE.remove:-1}_applyNCRAction(t,e,i){switch(t){case eE.allow:return String.fromCodePoint(i);case eE.remove:return"";case eE.leave:return;case eE.throw:throw Error(`[EntityDecoder] Prohibited numeric character reference &${e}; (U+${i.toString(16).toUpperCase().padStart(4,"0")})`);default:return String.fromCodePoint(i)}}_resolveNCR(t){let e,i=t.charCodeAt(1);if(Number.isNaN(e=120===i||88===i?parseInt(t.slice(2),16):parseInt(t.slice(1),10))||e<0||e>1114111)return;let n=this._classifyNCR(e);if(!this._numericAllowed&&n<eE.remove)return;let r=-1===n?this._ncrOnLevel:Math.max(this._ncrOnLevel,n);return this._applyNCRAction(r,t,e)}}class eO{constructor(t,e){var i;this.options=t,this.currentNode=null,this.tagsNodeStack=[],this.parseXml=eL,this.parseTextData=eA,this.resolveNameSpace=eT,this.buildAttributesMap=ek,this.isItStopNode=eD,this.replaceEntitiesValue=eI,this.readStopNodeData=eB,this.saveTextToParentTag=eR,this.addChild=ej,this.ignoreAttributesFn="function"==typeof(i=this.options.ignoreAttributes)?i:Array.isArray(i)?t=>{for(let e of i)if("string"==typeof e&&t===e||e instanceof RegExp&&e.test(t))return!0}:()=>!1,this.entityExpansionCount=0,this.currentExpandedLength=0;let n={...eb};this.options.entityDecoder?this.entityDecoder=this.options.entityDecoder:("object"==typeof this.options.htmlEntities?n=this.options.htmlEntities:!0===this.options.htmlEntities&&(n={...ev,...ey}),this.entityDecoder=new eP({namedEntities:{...n,...e},numericAllowed:this.options.htmlEntities,limit:{maxTotalExpansions:this.options.processEntities.maxTotalExpansions,maxExpandedLength:this.options.processEntities.maxExpandedLength,applyLimitsTo:this.options.processEntities.appliesTo}})),this.matcher=new ef,this.readonlyMatcher=this.matcher.readOnly(),this.isCurrentNodeStopNode=!1,this.stopNodeExpressionsSet=new em;const r=this.options.stopNodes;if(r&&r.length>0){for(let t=0;t<r.length;t++){const e=r[t];"string"==typeof e?this.stopNodeExpressionsSet.add(new eg(e)):e instanceof eg&&this.stopNodeExpressionsSet.add(e)}this.stopNodeExpressionsSet.seal()}}}function eA(t,e,i,n,r,o,s){let a=this.options;if(void 0!==t&&(a.trimValues&&!n&&(t=t.trim()),t.length>0)){s||(t=this.replaceEntitiesValue(t,e,i));let n=a.jPath?i.toString():i,l=a.tagValueProcessor(e,t,n,r,o);return null==l?t:typeof l!=typeof t||l!==t?l:a.trimValues||t.trim()===t?eF(t,a.parseTagValue,a.numberParseOptions):t}}function eT(t){if(this.options.removeNSPrefix){let e=t.split(":"),i="/"===t.charAt(0)?"/":"";if("xmlns"===e[0])return"";2===e.length&&(t=i+e[1])}return t}let e$=RegExp("([^\\s=]+)\\s*(=\\s*(['\"])([\\s\\S]*?)\\3)?","gm");function ek(t,e,i){let n=arguments.length>3&&void 0!==arguments[3]&&arguments[3],r=this.options;if(!0===n||!0!==r.ignoreAttributes&&"string"==typeof t){let n=t5(t,e$),o=n.length,s={},a=Array(o),l=!1,u={};for(let t=0;t<o;t++){let e=this.resolveNameSpace(n[t][1]),o=n[t][4];if(e.length&&void 0!==o){let n=o;r.trimValues&&(n=n.trim()),n=this.replaceEntitiesValue(n,i,this.readonlyMatcher),a[t]=n,u[e]=n,l=!0}}l&&"object"==typeof e&&e.updateCurrent&&e.updateCurrent(u);let h=r.jPath?e.toString():this.readonlyMatcher,c=!1;for(let t=0;t<o;t++){let e=this.resolveNameSpace(n[t][1]);if(this.ignoreAttributesFn(e,h))continue;let i=r.attributeNamePrefix+e;if(e.length)if(r.transformAttributeName&&(i=r.transformAttributeName(i)),i=eW(i,r),void 0!==n[t][4]){let n=a[t],o=r.attributeValueProcessor(e,n,h);s[i]=null==o?n:typeof o!=typeof n||o!==n?o:eF(n,r.parseAttributeValue,r.numberParseOptions),c=!0}else r.allowBooleanAttributes&&(s[i]=!0,c=!0)}if(!c)return;if(r.attributesGroupName&&!r.preserveOrder){let t={};return t[r.attributesGroupName]=s,t}return s}}let eL=function(t){t=t.replace(/\r\n?/g,"\n");let e=new er("!xml"),i=e,n="";this.matcher.reset(),this.entityDecoder.reset(),this.entityExpansionCount=0,this.currentExpandedLength=0;let r=this.options,o=new eo(r.processEntities),s=t.length;for(let a=0;a<s;a++)if("<"===t[a]){let l=t.charCodeAt(a+1);if(47===l){let e=eV(t,">",a,"Closing Tag is not closed."),o=t.substring(a+2,e).trim();if(r.removeNSPrefix){let t=o.indexOf(":");-1!==t&&(o=o.substr(t+1))}o=eU(r.transformTagName,o,"",r).tagName,i&&(n=this.saveTextToParentTag(n,i,this.readonlyMatcher));let s=this.matcher.getCurrentTag();if(o&&r.unpairedTagsSet.has(o))throw Error(`Unpaired tag can not be used as closing tag: </${o}>`);s&&r.unpairedTagsSet.has(s)&&(this.matcher.pop(),this.tagsNodeStack.pop()),this.matcher.pop(),this.isCurrentNodeStopNode=!1,i=this.tagsNodeStack.pop(),n="",a=e}else if(63===l){let e=eM(t,a,!1,"?>");if(!e)throw Error("Pi Tag is not closed.");n=this.saveTextToParentTag(n,i,this.readonlyMatcher);let o=this.buildAttributesMap(e.tagExp,this.matcher,e.tagName,!0);if(o){let t=o[this.options.attributeNamePrefix+"version"];this.entityDecoder.setXmlVersion(Number(t)||1)}if(r.ignoreDeclaration&&"?xml"===e.tagName||r.ignorePiTags);else{let t=new er(e.tagName);t.add(r.textNodeName,""),e.tagName!==e.tagExp&&e.attrExpPresent&&!0!==r.ignoreAttributes&&(t[":@"]=o),this.addChild(i,t,this.readonlyMatcher,a)}a=e.closeIndex+1}else if(33===l&&45===t.charCodeAt(a+2)&&45===t.charCodeAt(a+3)){let e=eV(t,"--\x3e",a+4,"Comment is not closed.");if(r.commentPropName){let o=t.substring(a+4,e-2);n=this.saveTextToParentTag(n,i,this.readonlyMatcher),i.add(r.commentPropName,[{[r.textNodeName]:o}])}a=e}else if(33===l&&68===t.charCodeAt(a+2)){let e=o.readDocType(t,a);this.entityDecoder.addInputEntities(e.entities),a=e.i}else if(33===l&&91===t.charCodeAt(a+2)){let e=eV(t,"]]>",a,"CDATA is not closed.")-2,o=t.substring(a+9,e);n=this.saveTextToParentTag(n,i,this.readonlyMatcher);let s=this.parseTextData(o,i.tagname,this.readonlyMatcher,!0,!1,!0,!0);null==s&&(s=""),r.cdataPropName?i.add(r.cdataPropName,[{[r.textNodeName]:o}]):i.add(r.textNodeName,s),a=e+2}else{let o=eM(t,a,r.removeNSPrefix);if(!o){let e=t.substring(Math.max(0,a-50),Math.min(s,a+50));throw Error(`readTagExp returned undefined at position ${a}. Context: "${e}"`)}let l=o.tagName,u=o.rawTagName,h=o.tagExp,c=o.attrExpPresent,p=o.closeIndex;if({tagName:l,tagExp:h}=eU(r.transformTagName,l,h,r),r.strictReservedNames&&(l===r.commentPropName||l===r.cdataPropName||l===r.textNodeName||l===r.attributesGroupName))throw Error(`Invalid tag name: ${l}`);i&&n&&"!xml"!==i.tagname&&(n=this.saveTextToParentTag(n,i,this.readonlyMatcher,!1));let d=i;d&&r.unpairedTagsSet.has(d.tagname)&&(i=this.tagsNodeStack.pop(),this.matcher.pop());let f=!1;h.length>0&&h.lastIndexOf("/")===h.length-1&&(f=!0,h="/"===l[l.length-1]?l=l.substr(0,l.length-1):h.substr(0,h.length-1),c=l!==h);let g,m=null;g=function(t){if(!t||"string"!=typeof t)return;let e=t.indexOf(":");if(-1!==e&&e>0){let i=t.substring(0,e);if("xmlns"!==i)return i}}(u),l!==e.tagname&&this.matcher.push(l,{},g),l!==h&&c&&(m=this.buildAttributesMap(h,this.matcher,l))&&function(t,e){if(!t)return;let i=e.attributesGroupName?t[e.attributesGroupName]:t;if(!i)return;let n={};for(let t in i)t.startsWith(e.attributeNamePrefix)?n[t.substring(e.attributeNamePrefix.length)]=i[t]:n[t]=i[t]}(m,r),l!==e.tagname&&(this.isCurrentNodeStopNode=this.isItStopNode());let y=a;if(this.isCurrentNodeStopNode){let e="";if(f)a=o.closeIndex;else if(r.unpairedTagsSet.has(l))a=o.closeIndex;else{let i=this.readStopNodeData(t,u,p+1);if(!i)throw Error(`Unexpected end of ${u}`);a=i.i,e=i.tagContent}let n=new er(l);m&&(n[":@"]=m),n.add(r.textNodeName,e),this.matcher.pop(),this.isCurrentNodeStopNode=!1,this.addChild(i,n,this.readonlyMatcher,y)}else{if(f){({tagName:l,tagExp:h}=eU(r.transformTagName,l,h,r));let t=new er(l);m&&(t[":@"]=m),this.addChild(i,t,this.readonlyMatcher,y),this.matcher.pop(),this.isCurrentNodeStopNode=!1}else{if(r.unpairedTagsSet.has(l)){let t=new er(l);m&&(t[":@"]=m),this.addChild(i,t,this.readonlyMatcher,y),this.matcher.pop(),this.isCurrentNodeStopNode=!1,a=o.closeIndex;continue}{let t=new er(l);if(this.tagsNodeStack.length>r.maxNestedTags)throw Error("Maximum nested tags exceeded");this.tagsNodeStack.push(i),m&&(t[":@"]=m),this.addChild(i,t,this.readonlyMatcher,y),i=t}}n="",a=p}}}else n+=t[a];return e.child};function ej(t,e,i,n){this.options.captureMetaData||(n=void 0);let r=this.options.jPath?i.toString():i,o=this.options.updateTag(e.tagname,r,e[":@"]);!1===o||("string"==typeof o&&(e.tagname=o),t.addChild(e,n))}function eI(t,e,i){let n=this.options.processEntities;if(!n||!n.enabled)return t;if(n.allowedTags){let r=this.options.jPath?i.toString():i;if(!(Array.isArray(n.allowedTags)?n.allowedTags.includes(e):n.allowedTags(e,r)))return t}if(n.tagFilter){let r=this.options.jPath?i.toString():i;if(!n.tagFilter(e,r))return t}return this.entityDecoder.decode(t)}function eR(t,e,i,n){return t&&(void 0===n&&(n=0===e.child.length),void 0!==(t=this.parseTextData(t,e.tagname,i,!1,!!e[":@"]&&0!==Object.keys(e[":@"]).length,n))&&""!==t&&e.add(this.options.textNodeName,t),t=""),t}function eD(){return 0!==this.stopNodeExpressionsSet.size&&this.matcher.matchesAny(this.stopNodeExpressionsSet)}function eV(t,e,i,n){let r=t.indexOf(e,i);if(-1===r)throw Error(n);return r+e.length-1}function eM(t,e,i){let n=function(t,e){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:">",n=0,r=t.length,o=i.charCodeAt(0),s=i.length>1?i.charCodeAt(1):-1,a="",l=e;for(let i=e;i<r;i++){let e=t.charCodeAt(i);if(n)e===n&&(n=0);else if(34===e||39===e)n=e;else if(e===o){if(-1===s||t.charCodeAt(i+1)===s)return{data:a+=t.substring(l,i),index:i}}else 9!==e||n||(a+=t.substring(l,i)+" ",l=i+1)}}(t,e+1,arguments.length>3&&void 0!==arguments[3]?arguments[3]:">");if(!n)return;let r=n.data,o=n.index,s=r.search(/\s/),a=r,l=!0;-1!==s&&(a=r.substring(0,s),r=r.substring(s+1).trimStart());let u=a;if(i){let t=a.indexOf(":");-1!==t&&(l=(a=a.substr(t+1))!==n.data.substr(t+1))}return{tagName:a,tagExp:r,closeIndex:o,attrExpPresent:l,rawTagName:u}}function eB(t,e,i){let n=i,r=1,o=t.length;for(;i<o;i++)if("<"===t[i]){let o=t.charCodeAt(i+1);if(47===o){let o=function(t,e,i){let n=t.indexOf(">",e);if(-1===n)throw Error(i);return n}(t,i,`${e} is not closed`);if(t.substring(i+2,o).trim()===e&&0==--r)return{tagContent:t.substring(n,i),i:o};i=o}else if(63===o)i=eV(t,"?>",i+1,"StopNode is not closed.");else if(33===o&&45===t.charCodeAt(i+2)&&45===t.charCodeAt(i+3))i=eV(t,"--\x3e",i+3,"StopNode is not closed.");else if(33===o&&91===t.charCodeAt(i+2))i=eV(t,"]]>",i,"StopNode is not closed.")-2;else{let n=eM(t,i,">");n&&((n&&n.tagName)===e&&"/"!==n.tagExp[n.tagExp.length-1]&&r++,i=n.closeIndex)}}}function eF(t,e,i){if(e&&"string"==typeof t){let e=t.trim();return"true"===e||"false"!==e&&function(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};if(e=Object.assign({},ec,e),!t||"string"!=typeof t)return t;let i=t.trim();if(0===i.length||void 0!==e.skipLike&&e.skipLike.test(i))return t;if("0"===i)return 0;if(e.hex&&eu.test(i)){var n;if(parseInt)return parseInt(i,16);if(Number.parseInt)return Number.parseInt(i,16);if(window&&window.parseInt)return window.parseInt(i,16);throw Error("parseInt, Number.parseInt, window.parseInt are not supported")}if(isFinite(i)){if(i.includes("e")||i.includes("E"))return function(t,e,i){if(!i.eNotation)return t;let n=e.match(ep);if(n){let r=n[1]||"",o=-1===n[3].indexOf("e")?"E":"e",s=n[2],a=r?t[s.length+1]===o:t[s.length]===o;return s.length>1&&a?t:(1!==s.length||!n[3].startsWith(`.${o}`)&&n[3][0]!==o)&&s.length>0?i.leadingZeros&&!a?Number(e=(n[1]||"")+n[3]):t:Number(e)}return t}(t,i,e);{let r=eh.exec(i);if(r){let o=r[1]||"",s=r[2],a=((n=r[3])&&-1!==n.indexOf(".")&&("."===(n=n.replace(/0+$/,""))?n="0":"."===n[0]?n="0"+n:"."===n[n.length-1]&&(n=n.substring(0,n.length-1))),n),l=o?"."===t[s.length+1]:"."===t[s.length];if(!e.leadingZeros&&(s.length>1||1===s.length&&!l))return t;{let n=Number(i),r=String(n);if(0===n)return n;if(-1!==r.search(/[eE]/))return e.eNotation?n:t;if(-1!==i.indexOf("."))return"0"===r||r===a||r===`${o}${a}`?n:t;let l=s?a:i;return s?l===r||o+l===r?n:t:l===r||l===o+r?n:t}}return t}}var r=Number(i);switch(e.infinity.toLowerCase()){case"null":return null;case"infinity":return r;case"string":return r===1/0?"Infinity":"-Infinity";default:return t}}(t,i)}return void 0!==t?t:""}function eU(t,e,i,n){if(t){let n=t(e);i===e&&(i=n),e=n}return{tagName:e=eW(e,n),tagExp:i}}function eW(t,e){if(et.includes(t))throw Error(`[SECURITY] Invalid name: "${t}" is a reserved JavaScript keyword that could cause prototype pollution`);return t7.includes(t)?e.onDangerousProperty(t):t}let ez=er.getMetaDataSymbol(),eX={allowBooleanAttributes:!1,unpairedTags:[]};function eG(t){return" "===t||"	"===t||"\n"===t||"\r"===t}function eq(t,e){let i=e;for(;e<t.length;e++)if("?"!=t[e]&&" "!=t[e]);else{let n=t.substr(i,e-i);if(e>5&&"xml"===n)return eY("InvalidXml","XML declaration allowed only at the start of the document.",eJ(t,e));if("?"==t[e]&&">"==t[e+1]){e++;break}}return e}function eH(t,e){if(t.length>e+5&&"-"===t[e+1]&&"-"===t[e+2]){for(e+=3;e<t.length;e++)if("-"===t[e]&&"-"===t[e+1]&&">"===t[e+2]){e+=2;break}}else if(t.length>e+8&&"D"===t[e+1]&&"O"===t[e+2]&&"C"===t[e+3]&&"T"===t[e+4]&&"Y"===t[e+5]&&"P"===t[e+6]&&"E"===t[e+7]){let i=1;for(e+=8;e<t.length;e++)if("<"===t[e])i++;else if(">"===t[e]&&0==--i)break}else if(t.length>e+9&&"["===t[e+1]&&"C"===t[e+2]&&"D"===t[e+3]&&"A"===t[e+4]&&"T"===t[e+5]&&"A"===t[e+6]&&"["===t[e+7]){for(e+=8;e<t.length;e++)if("]"===t[e]&&"]"===t[e+1]&&">"===t[e+2]){e+=2;break}}return e}let eK=RegExp("(\\s*)([^\\s=]+)(\\s*=)?(\\s*(['\"])(([\\s\\S])*?)\\5)?","g");function eQ(t,e){let i=t5(t,eK),n={};for(let t=0;t<i.length;t++){if(0===i[t][1].length)return eY("InvalidAttr","Attribute '"+i[t][2]+"' has no space in starting.",eZ(i[t]));if(void 0!==i[t][3]&&void 0===i[t][4])return eY("InvalidAttr","Attribute '"+i[t][2]+"' is without value.",eZ(i[t]));if(void 0===i[t][3]&&!e.allowBooleanAttributes)return eY("InvalidAttr","boolean attribute '"+i[t][2]+"' is not allowed.",eZ(i[t]));let r=i[t][2];if(!t9(r))return eY("InvalidAttr","Attribute '"+r+"' is an invalid name.",eZ(i[t]));if(Object.prototype.hasOwnProperty.call(n,r))return eY("InvalidAttr","Attribute '"+r+"' is repeated.",eZ(i[t]));n[r]=1}return!0}function eY(t,e,i){return{err:{code:t,msg:e,line:i.line||i,col:i.col}}}function eJ(t,e){let i=t.substring(0,e).split(/\r?\n/);return{line:i.length,col:i[i.length-1].length+1}}function eZ(t){return t.startIndex+t[1].length}class e0{constructor(t){this.externalEntities={},this.options=en(t)}parse(t,e){var i;if("string"!=typeof t&&t.toString)t=t.toString();else if("string"!=typeof t)throw Error("XML data is accepted in String or Bytes[] form.");if(e){!0===e&&(e={});let i=function(t,e){e=Object.assign({},eX,e);let i=[],n=!1,r=!1;"\uFEFF"===t[0]&&(t=t.substr(1));for(let o=0;o<t.length;o++)if("<"===t[o]&&"?"===t[o+1]){if(o+=2,(o=eq(t,o)).err)return o}else{if("<"!==t[o]){if(eG(t[o]))continue;return eY("InvalidChar","char '"+t[o]+"' is not expected.",eJ(t,o))}{let s=o;if("!"===t[++o]){o=eH(t,o);continue}{let a=!1;"/"===t[o]&&(a=!0,o++);let l="";for(;o<t.length&&">"!==t[o]&&" "!==t[o]&&"	"!==t[o]&&"\n"!==t[o]&&"\r"!==t[o];o++)l+=t[o];if("/"===(l=l.trim())[l.length-1]&&(l=l.substring(0,l.length-1),o--),!t9(l))return eY("InvalidTag",0===l.trim().length?"Invalid space after '<'.":"Tag '"+l+"' is an invalid name.",eJ(t,o));let u=function(t,e){let i="",n="",r=!1;for(;e<t.length;e++){if('"'===t[e]||"'"===t[e])""===n?n=t[e]:n!==t[e]||(n="");else if(">"===t[e]&&""===n){r=!0;break}i+=t[e]}return""===n&&{value:i,index:e,tagClosed:r}}(t,o);if(!1===u)return eY("InvalidAttr","Attributes for '"+l+"' have open quote.",eJ(t,o));let h=u.value;if(o=u.index,"/"===h[h.length-1]){let i=o-h.length,r=eQ(h=h.substring(0,h.length-1),e);if(!0!==r)return eY(r.err.code,r.err.msg,eJ(t,i+r.err.line));n=!0}else if(a){if(!u.tagClosed)return eY("InvalidTag","Closing tag '"+l+"' doesn't have proper closing.",eJ(t,o));if(h.trim().length>0)return eY("InvalidTag","Closing tag '"+l+"' can't have attributes or invalid starting.",eJ(t,s));if(0===i.length)return eY("InvalidTag","Closing tag '"+l+"' has not been opened.",eJ(t,s));{let e=i.pop();if(l!==e.tagName){let i=eJ(t,e.tagStartPos);return eY("InvalidTag","Expected closing tag '"+e.tagName+"' (opened in line "+i.line+", col "+i.col+") instead of closing tag '"+l+"'.",eJ(t,s))}0==i.length&&(r=!0)}}else{let a=eQ(h,e);if(!0!==a)return eY(a.err.code,a.err.msg,eJ(t,o-h.length+a.err.line));if(!0===r)return eY("InvalidXml","Multiple possible root nodes found.",eJ(t,o));-1!==e.unpairedTags.indexOf(l)||i.push({tagName:l,tagStartPos:s}),n=!0}for(o++;o<t.length;o++)if("<"===t[o]){if("!"===t[o+1]){o=eH(t,++o);continue}if("?"!==t[o+1])break;if((o=eq(t,++o)).err)return o}else if("&"===t[o]){let e=function(t,e){if(";"===t[++e])return -1;if("#"===t[e]){var i=++e;let n=/\d/;for("x"===t[i]&&(i++,n=/[\da-fA-F]/);i<t.length;i++){if(";"===t[i])return i;if(!t[i].match(n))break}return -1}let n=0;for(;e<t.length;e++,n++)if(!(t[e].match(/\w/)&&n<20)){if(";"===t[e])break;return -1}return e}(t,o);if(-1==e)return eY("InvalidChar","char '&' is not expected.",eJ(t,o));o=e}else if(!0===r&&!eG(t[o]))return eY("InvalidXml","Extra text at the end",eJ(t,o));"<"===t[o]&&o--}}}return n?1==i.length?eY("InvalidTag","Unclosed tag '"+i[0].tagName+"'.",eJ(t,i[0].tagStartPos)):!(i.length>0)||eY("InvalidXml","Invalid '"+JSON.stringify(i.map(t=>t.tagName),null,4).replace(/\r?\n/g,"")+"' found.",{line:1,col:1}):eY("InvalidXml","Start tag expected.",1)}(t,e);if(!0!==i)throw Error(`${i.err.msg}:${i.err.line}:${i.err.col}`)}let n=new eO(this.options,this.externalEntities),r=n.parseXml(t);return this.options.preserveOrder||void 0===r?r:(i=this.options,function t(e,i,n,r){let o,s={};for(let a=0;a<e.length;a++){let l=e[a],u=function(t){let e=Object.keys(t);for(let t=0;t<e.length;t++){let i=e[t];if(":@"!==i)return i}}(l);if(void 0!==u&&u!==i.textNodeName){let t=function(t,e){if(!t||"object"!=typeof t)return{};if(!e)return t;let i={};for(let n in t)n.startsWith(e)?i[n.substring(e.length)]=t[n]:i[n]=t[n];return i}(l[":@"]||{},i.attributeNamePrefix);n.push(u,t)}if(u===i.textNodeName)void 0===o?o=l[u]:o+=""+l[u];else{if(void 0===u)continue;if(l[u]){let e=t(l[u],i,n,r),o=function(t,e){let{textNodeName:i}=e,n=Object.keys(t).length;return 0===n||!(1!==n||!t[i]&&"boolean"!=typeof t[i]&&0!==t[i])}(e,i);if(l[":@"]?function(t,e,i,n){if(e){let r=Object.keys(e),o=r.length;for(let s=0;s<o;s++){let o=r[s],a=o.startsWith(n.attributeNamePrefix)?o.substring(n.attributeNamePrefix.length):o,l=n.jPath?i.toString()+"."+a:i;n.isArray(o,l,!0,!0)?t[o]=[e[o]]:t[o]=e[o]}}}(e,l[":@"],r,i):1!==Object.keys(e).length||void 0===e[i.textNodeName]||i.alwaysCreateTextNode?0===Object.keys(e).length&&(i.alwaysCreateTextNode?e[i.textNodeName]="":e=""):e=e[i.textNodeName],void 0!==l[ez]&&"object"==typeof e&&null!==e&&(e[ez]=l[ez]),void 0!==s[u]&&Object.prototype.hasOwnProperty.call(s,u))Array.isArray(s[u])||(s[u]=[s[u]]),s[u].push(e);else{let t=i.jPath?r.toString():r;i.isArray(u,t,o)?s[u]=[e]:s[u]=e}void 0!==u&&u!==i.textNodeName&&n.pop()}}}return"string"==typeof o?o.length>0&&(s[i.textNodeName]=o):void 0!==o&&(s[i.textNodeName]=o),s}(r,i,n.matcher,n.readonlyMatcher))}addEntity(t,e){if(-1!==e.indexOf("&"))throw Error("Entity value can't have '&'");if(-1!==t.indexOf("&")||-1!==t.indexOf(";"))throw Error("An entity must be set without '&' and ';'. Eg. use '#xD' for '&#xD;'");if("&"===e)throw Error("An entity with value '&' is not permitted");this.externalEntities[t]=e}static getMetaDataSymbol(){return er.getMetaDataSymbol()}}var e1=_(829),e2=_.n(e1),e3=((s=e3||{}).Array="array",s.Object="object",s.Original="original",s);function e4(t){return"string"==typeof t?t:t.toString(".",!1)}function e6(t,e){if(!t.endsWith("propstat.prop.displayname"))return e}function e8(t,e){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:e3.Original,n=e2().get(t,e);return"array"===i&&!1===Array.isArray(n)?[n]:"object"===i&&Array.isArray(n)?n[0]:n}function e5(t,e){return e=e??{attributeNamePrefix:"@",attributeParsers:[],tagParsers:[e6]},new Promise(i=>{i(function(t){let{multistatus:e}=t;if(""===e)return{multistatus:{response:[]}};if(!e)throw Error("Invalid response: No root multistatus found");let i={multistatus:Array.isArray(e)?e[0]:e};return e2().set(i,"multistatus.response",e8(i,"multistatus.response",e3.Array)),e2().set(i,"multistatus.response",e2().get(i,"multistatus.response").map(t=>{let e;return(e=Object.assign({},t)).status?e2().set(e,"status",e8(e,"status",e3.Object)):(e2().set(e,"propstat",e8(e,"propstat",e3.Object)),e2().set(e,"propstat.prop",e8(e,"propstat.prop",e3.Object))),e})),i}((function(t){let{attributeNamePrefix:e,attributeParsers:i,entityDecoder:n,tagParsers:r}=t,o={allowBooleanAttributes:!0,attributeNamePrefix:e,textNodeName:"text",ignoreAttributes:!1,removeNSPrefix:!0,jPath:!1,numberParseOptions:{hex:!0,leadingZeros:!1},attributeValueProcessor(t,e,n){let r=e4(n);for(let t of i)try{let i=t(r,e);if(i!==e)return i}catch(t){}return e},tagValueProcessor(t,e,i){let n=e4(i);for(let t of r)try{let i=t(n,e);if(i!==e)return i}catch(t){}return e}};return n&&(o.entityDecoder=new eP({limit:{maxTotalExpansions:n.limit?.maxTotalExpansions??0,maxExpandedLength:n.limit?.maxExpandedLength??0}})),new e0(o)})(e).parse(t)))})}function e9(t,e){let i=arguments.length>2&&void 0!==arguments[2]&&arguments[2],{getlastmodified:n=null,getcontentlength:r="0",resourcetype:o=null,getcontenttype:s=null,getetag:a=null}=t,l=o&&"object"==typeof o&&void 0!==o.collection?"directory":"file",u={filename:e,basename:T().basename(e),lastmod:n,size:parseInt(r,10),type:l,etag:"string"==typeof a?a.replace(/"/g,""):null};return"file"===l&&(u.mime=s&&"string"==typeof s?s.split(";")[0]:""),i&&(void 0!==t.displayname&&(t.displayname=String(t.displayname)),u.props=t),u}function e7(t,e,i){return i?e?e(t):t:(t&&t.then||(t=Promise.resolve(t)),e?t.then(e):t)}let it=(a=function(t,e){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},{details:n=!1}=i;return e7(td(tf({url:R(t.remoteURL,L(e)),method:"PROPFIND",headers:{Accept:"text/plain,application/xml",Depth:"0"}},t,i),t),function(i){return t2(t,i),e7(i.text(),function(r){return e7(e5(r,t.parsing),function(t){return t3(i,function(t,e){let i=arguments.length>2&&void 0!==arguments[2]&&arguments[2],n=null;try{t.multistatus.response[0].propstat&&(n=t.multistatus.response[0])}catch(t){}if(!n)throw Error("Failed getting item stat: bad response");let{propstat:{prop:r,status:o}}=n,[s,a,l]=o.split(" ",3),u=parseInt(a,10);if(u>=400){let t=Error(`Invalid response: ${u} ${l}`);throw t.status=u,t}return e9(r,I(e),i)}(t,e,n),n)})})})},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(a.apply(this,t))}catch(t){return Promise.reject(t)}});function ie(t,e,i){return i?e?e(t):t:(t&&t.then||(t=Promise.resolve(t)),e?t.then(e):t)}let ii=ir(function(t,e){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},n=function(t){if(!t||"/"===t)return[];let e=t,i=[];do i.push(e),e=T().dirname(e);while(e&&"/"!==e);return i}(I(e));n.sort((t,e)=>t.length>e.length?1:e.length>t.length?-1:0);let r=!1;return function(t,e,i){if("function"==typeof t[ia]){var n,r,o,s,a,l,u,h=t[ia]();if(function t(i){try{for(;!(a=h.next()).done;)if((i=e(a.value))&&i.then){if(!ih(i))return void i.then(t,u||(u=il.bind(null,l=new iu,2)));i=i.v}l?il(l,1,i):l=i}catch(t){il(l||(l=new iu),2,t)}}(),h.return){var c=function(t){try{a.done||h.return()}catch(t){}return t};if(l&&l.then)return l.then(c,function(t){throw c(t)});c()}return l}if(!("length"in t))throw TypeError("Object is not iterable");for(var p=[],d=0;d<t.length;d++)p.push(t[d]);return n=function(t){return e(p[t])},s=-1,function t(e){try{for(;++s<p.length&&(!i||!i());)if((e=n(s))&&e.then){if(!ih(e))return void e.then(t,o||(o=il.bind(null,r=new iu,2)));e=e.v}r?il(r,1,e):r=e}catch(t){il(r||(r=new iu),2,t)}}(),r}(n,function(n){var o,s;return s=function(){var o=function(e){if(404===e.status)return r=!0,is(ic(t,n,{...i,recursive:!1}));throw e};try{var s=ie(it(t,n),function(t){if("directory"!==t.type)throw Error(`Path includes a file: ${e}`)})}catch(t){return o(t)}return s&&s.then?s.then(void 0,o):s},(o=function(){if(r)return is(ic(t,n,{...i,recursive:!1}))}())&&o.then?o.then(s):s()},function(){return!1})});function ir(t){return function(){for(var e=[],i=0;i<arguments.length;i++)e[i]=arguments[i];try{return Promise.resolve(t.apply(this,e))}catch(t){return Promise.reject(t)}}}function io(){}function is(t,e){if(!e)return t&&t.then?t.then(io):Promise.resolve()}let ia="u">typeof Symbol?Symbol.iterator||(Symbol.iterator=Symbol("Symbol.iterator")):"@@iterator";function il(t,e,i){if(!t.s){if(i instanceof iu){if(!i.s)return void(i.o=il.bind(null,t,e));1&e&&(e=i.s),i=i.v}if(i&&i.then)return void i.then(il.bind(null,t,e),il.bind(null,t,2));t.s=e,t.v=i;let n=t.o;n&&n(t)}}let iu=function(){function t(){}return t.prototype.then=function(e,i){let n=new t,r=this.s;if(r){let t=1&r?e:i;if(t){try{il(n,1,t(this.v))}catch(t){il(n,2,t)}return n}return this}return this.o=function(t){try{let r=t.v;1&t.s?il(n,1,e?e(r):r):i?il(n,1,i(r)):il(n,2,r)}catch(t){il(n,2,t)}},n},t}();function ih(t){return t instanceof iu&&1&t.s}let ic=ir(function(t,e){var i;let n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};return!0===n.recursive?ii(t,e,n):ie(td(tf({url:R(t.remoteURL,(i=L(e)).endsWith("/")?i:i+"/"),method:"MKCOL"},t,n),t),function(e){t2(t,e)})});var ip=_(388),id=_.n(ip);let ig=(l=function(t,e){var i,n;let r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},o={};if("object"==typeof r.range&&"number"==typeof r.range.start){let t=`bytes=${r.range.start}-`;"number"==typeof r.range.end&&(t=`${t}${r.range.end}`),o.Range=t}let s=tf({url:R(t.remoteURL,L(e)),method:"GET",headers:o},t,r);return i=function(e){if(t2(t,e),o.Range&&206!==e.status){let t=Error(`Invalid response code for partial request: ${e.status}`);throw t.status=e.status,t}return r.callback&&setTimeout(()=>{r.callback(e)},0),e.body},(n=td(s,t))&&n.then||(n=Promise.resolve(n)),i?n.then(i):n},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(l.apply(this,t))}catch(t){return Promise.reject(t)}}),im=()=>{},iy=(u=function(t,e,i){var n,r;i.url||(i.url=R(t.remoteURL,L(e)));let o=tf(i,t,{});return r=function(e){return t2(t,e),e},(n=td(o,t))&&n.then||(n=Promise.resolve(n)),r?n.then(r):n},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(u.apply(this,t))}catch(t){return Promise.reject(t)}}),ib=(h=function(t,e){var i,n;let r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},o=tf({url:R(t.remoteURL,L(e)),method:"DELETE"},t,r);return n=function(e){t2(t,e)},(i=td(o,t))&&i.then||(i=Promise.resolve(i)),n?i.then(n):i},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(h.apply(this,t))}catch(t){return Promise.reject(t)}}),iv=(c=function(t,e){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};return function(n){try{var r,o,s,a=(r=it(t,e,i),o=function(){return!0},s?o?o():r:(r&&r.then||(r=Promise.resolve(r)),o?r.then(o):r))}catch(t){return n(t)}return a&&a.then?a.then(void 0,n):a}(function(t){if(404===t.status)return!1;throw t})},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(c.apply(this,t))}catch(t){return Promise.reject(t)}});function ix(t,e,i){return i?e?e(t):t:(t&&t.then||(t=Promise.resolve(t)),e?t.then(e):t)}let iw=(p=function(t,e){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};return ix(td(tf({url:R(t.remoteURL,L(e),"/"),method:"PROPFIND",headers:{Accept:"text/plain,application/xml",Depth:i.deep?"infinity":"1"}},t,i),t),function(n){return t2(t,n),ix(n.text(),function(r){if(!r)throw Error("Failed parsing directory contents: Empty response");return ix(e5(r,t.parsing),function(r){var o,s;let a=j(e),l=function(t,e,i){let n=arguments.length>3&&void 0!==arguments[3]&&arguments[3],r=arguments.length>4&&void 0!==arguments[4]&&arguments[4],o=T().join(e,"/"),{multistatus:{response:s}}=t,a=s.map(t=>{let e=function(t){try{return t.replace(/^https?:\/\/[^\/]+/,"")}catch(t){throw new O(t,"Failed normalising HREF")}}(t.href),{propstat:{prop:i}}=t;return e9(i,"/"===o?decodeURIComponent(I(e)):I(T().relative(decodeURIComponent(o),decodeURIComponent(e))),n)});return r?a:a.filter(t=>t.basename&&("file"===t.type||t.filename!==i.replace(/\/$/,"")))}(r,j(t.remoteBasePath||t.remotePath),a,i.details,i.includeSelf);return i.glob&&(o=l,s=i.glob,l=o.filter(t=>tR(t.filename,s,{matchBase:!0}))),t3(n,l,i.details)})})})},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(p.apply(this,t))}catch(t){return Promise.reject(t)}});function iN(t){return function(){for(var e=[],i=0;i<arguments.length;i++)e[i]=arguments[i];try{return Promise.resolve(t.apply(this,e))}catch(t){return Promise.reject(t)}}}let i_=iN(function(t,e){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};return iS(td(tf({url:R(t.remoteURL,L(e)),method:"GET",headers:{Accept:"text/plain"},transformResponse:[iP]},t,i),t),function(e){return t2(t,e),iS(e.text(),function(t){return t3(e,t,i.details)})})});function iS(t,e,i){return i?e?e(t):t:(t&&t.then||(t=Promise.resolve(t)),e?t.then(e):t)}let iE=iN(function(t,e){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};return iS(td(tf({url:R(t.remoteURL,L(e)),method:"GET"},t,i),t),function(e){var n,r,o;let s;return t2(t,e),n=function(){return iS(e.arrayBuffer(),function(t){s=t})},r=function(){return t3(e,s,i.details)},(o=n())&&o.then?o.then(r):r()})}),iC=iN(function(t,e){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},{format:n="binary"}=i;if("binary"!==n&&"text"!==n)throw new O({info:{code:H.InvalidOutputFormat}},`Invalid output format: ${n}`);return"text"===n?i_(t,e,i):iE(t,e,i)}),iP=t=>t;function iO(t){let e=Object.keys(t);for(let i=0;i<e.length;i++){let n=e[i];if(Object.prototype.hasOwnProperty.call(t,n)&&":@"!==n)return n}}function iA(t,e,i){let n="";if(t&&!e.ignoreAttributes)for(let r in t){let o;Object.prototype.hasOwnProperty.call(t,r)&&(!0===(o=i?t[r]:iT(o=e.attributeValueProcessor(r,t[r]),e))&&e.suppressBooleanAttributes?n+=` ${r.substr(e.attributeNamePrefix.length)}`:n+=` ${r.substr(e.attributeNamePrefix.length)}="${o}"`)}return n}function iT(t,e){if(t&&t.length>0&&e.processEntities)for(let i=0;i<e.entities.length;i++){let n=e.entities[i];t=t.replace(n.regex,n.val)}return t}let i$={attributeNamePrefix:"@_",attributesGroupName:!1,textNodeName:"#text",ignoreAttributes:!0,cdataPropName:!1,format:!1,indentBy:"  ",suppressEmptyNode:!1,suppressUnpairedNode:!0,suppressBooleanAttributes:!0,tagValueProcessor:function(t,e){return e},attributeValueProcessor:function(t,e){return e},preserveOrder:!1,commentPropName:!1,unpairedTags:[],entities:[{regex:RegExp("&","g"),val:"&amp;"},{regex:RegExp(">","g"),val:"&gt;"},{regex:RegExp("<","g"),val:"&lt;"},{regex:RegExp("'","g"),val:"&apos;"},{regex:RegExp('"',"g"),val:"&quot;"}],processEntities:!0,stopNodes:[],oneListGroup:!1,maxNestedTags:100,jPath:!0};function ik(t){var e;if(this.options=Object.assign({},i$,t),this.options.stopNodes&&Array.isArray(this.options.stopNodes)&&(this.options.stopNodes=this.options.stopNodes.map(t=>"string"==typeof t&&t.startsWith("*.")?".."+t.substring(2):t)),this.stopNodeExpressions=[],this.options.stopNodes&&Array.isArray(this.options.stopNodes))for(let t=0;t<this.options.stopNodes.length;t++){let e=this.options.stopNodes[t];"string"==typeof e?this.stopNodeExpressions.push(new eg(e)):e instanceof eg&&this.stopNodeExpressions.push(e)}!0===this.options.ignoreAttributes||this.options.attributesGroupName?this.isAttribute=function(){return!1}:(this.ignoreAttributesFn="function"==typeof(e=this.options.ignoreAttributes)?e:Array.isArray(e)?t=>{for(let i of e)if("string"==typeof i&&t===i||i instanceof RegExp&&i.test(t))return!0}:()=>!1,this.attrPrefixLen=this.options.attributeNamePrefix.length,this.isAttribute=iI),this.processTextOrObjNode=iL,this.options.format?(this.indentate=ij,this.tagEndChar=">\n",this.newLine="\n"):(this.indentate=function(){return""},this.tagEndChar=">",this.newLine="")}function iL(t,e,i,n){let r=this.extractAttributes(t);if(n.push(e,r),this.checkStopNode(n)){let r=this.buildRawContent(t),o=this.buildAttributesForStopNode(t);return n.pop(),this.buildObjectNode(r,e,o,i)}let o=this.j2x(t,i+1,n);return n.pop(),void 0!==t[this.options.textNodeName]&&1===Object.keys(t).length?this.buildTextValNode(t[this.options.textNodeName],e,o.attrStr,i,n):this.buildObjectNode(o.val,e,o.attrStr,i)}function ij(t){return this.options.indentBy.repeat(t)}function iI(t){return!(!t.startsWith(this.options.attributeNamePrefix)||t===this.options.textNodeName)&&t.substr(this.attrPrefixLen)}function iR(t,e,i){return i?e?e(t):t:(t&&t.then||(t=Promise.resolve(t)),e?t.then(e):t)}function iD(t){return function(){for(var e=[],i=0;i<arguments.length;i++)e[i]=arguments[i];try{return Promise.resolve(t.apply(this,e))}catch(t){return Promise.reject(t)}}}ik.prototype.build=function(t){if(this.options.preserveOrder)return function(t,e){let i="";e.format&&e.indentBy.length>0&&(i="\n");let n=[];if(e.stopNodes&&Array.isArray(e.stopNodes))for(let t=0;t<e.stopNodes.length;t++){let i=e.stopNodes[t];"string"==typeof i?n.push(new eg(i)):i instanceof eg&&n.push(i)}return function t(e,i,n,r,o){let s="",a=!1;if(i.maxNestedTags&&r.getDepth()>i.maxNestedTags)throw Error("Maximum nested tags exceeded");if(!Array.isArray(e))return null!=e?iT(e.toString(),i):"";for(let l=0;l<e.length;l++){let u,h=e[l],c=iO(h);if(void 0===c)continue;let p=function(t,e){if(!t||e.ignoreAttributes)return null;let i={},n=!1;for(let r in t)Object.prototype.hasOwnProperty.call(t,r)&&(i[r.startsWith(e.attributeNamePrefix)?r.substr(e.attributeNamePrefix.length):r]=t[r],n=!0);return n?i:null}(h[":@"],i);r.push(c,p);let d=function(t,e){if(!e||0===e.length)return!1;for(let i=0;i<e.length;i++)if(t.matches(e[i]))return!0;return!1}(r,o);if(c===i.textNodeName){let t=h[c];d||(t=iT(t=i.tagValueProcessor(c,t),i)),a&&(s+=n),s+=t,a=!1,r.pop();continue}if(c===i.cdataPropName){a&&(s+=n);let t=h[c][0][i.textNodeName];s+=`<![CDATA[${String(t).replace(/\]\]>/g,"]]]]><![CDATA[>")}]]>`,a=!1,r.pop();continue}if(c===i.commentPropName){let t=h[c][0][i.textNodeName];s+=n+`<!--${String(t).replace(/--/g,"- -").replace(/-$/,"- ")}-->`,a=!0,r.pop();continue}if("?"===c[0]){let t=iA(h[":@"],i,d),e="?xml"===c?"":n,o=h[c][0][i.textNodeName];o=0!==o.length?" "+o:"",s+=e+`<${c}${o}${t}?>`,a=!0,r.pop();continue}let f=n;""!==f&&(f+=i.indentBy);let g=n+`<${c}${iA(h[":@"],i,d)}`;u=d?function t(e,i){if(!Array.isArray(e))return null!=e?e.toString():"";let n="";for(let r=0;r<e.length;r++){let o=e[r],s=iO(o);if(s===i.textNodeName)n+=o[s];else if(s===i.cdataPropName)n+=o[s][0][i.textNodeName];else if(s===i.commentPropName)n+=o[s][0][i.textNodeName];else{if(s&&"?"===s[0])continue;if(s){let e=function(t,e){let i="";if(t&&!e.ignoreAttributes)for(let n in t){if(!Object.prototype.hasOwnProperty.call(t,n))continue;let r=t[n];!0===r&&e.suppressBooleanAttributes?i+=` ${n.substr(e.attributeNamePrefix.length)}`:i+=` ${n.substr(e.attributeNamePrefix.length)}="${r}"`}return i}(o[":@"],i),r=t(o[s],i);r&&0!==r.length?n+=`<${s}${e}>${r}</${s}>`:n+=`<${s}${e}/>`}}}return n}(h[c],i):t(h[c],i,f,r,o),-1!==i.unpairedTags.indexOf(c)?i.suppressUnpairedNode?s+=g+">":s+=g+"/>":u&&0!==u.length||!i.suppressEmptyNode?u&&u.endsWith(">")?s+=g+`>${u}${n}</${c}>`:(s+=g+">",u&&""!==n&&(u.includes("/>")||u.includes("</"))?s+=n+i.indentBy+u+n:s+=u,s+=`</${c}>`):s+=g+"/>",a=!0,r.pop()}return s}(t,e,i,new ef,n)}(t,this.options);{Array.isArray(t)&&this.options.arrayNodeName&&this.options.arrayNodeName.length>1&&(t={[this.options.arrayNodeName]:t});let e=new ef;return this.j2x(t,0,e).val}},ik.prototype.j2x=function(t,e,i){let n="",r="";if(this.options.maxNestedTags&&i.getDepth()>=this.options.maxNestedTags)throw Error("Maximum nested tags exceeded");let o=this.options.jPath?i.toString():i,s=this.checkStopNode(i);for(let a in t)if(Object.prototype.hasOwnProperty.call(t,a))if(void 0===t[a])this.isAttribute(a)&&(r+="");else if(null===t[a])this.isAttribute(a)||a===this.options.cdataPropName?r+="":"?"===a[0]?r+=this.indentate(e)+"<"+a+"?"+this.tagEndChar:r+=this.indentate(e)+"<"+a+"/"+this.tagEndChar;else if(t[a]instanceof Date)r+=this.buildTextValNode(t[a],a,"",e,i);else if("object"!=typeof t[a]){let l=this.isAttribute(a);if(l&&!this.ignoreAttributesFn(l,o))n+=this.buildAttrPairStr(l,""+t[a],s);else if(!l)if(a===this.options.textNodeName){let e=this.options.tagValueProcessor(a,""+t[a]);r+=this.replaceEntitiesValue(e)}else{i.push(a);let n=this.checkStopNode(i);if(i.pop(),n){let i=""+t[a];r+=""===i?this.indentate(e)+"<"+a+this.closeTag(a)+this.tagEndChar:this.indentate(e)+"<"+a+">"+i+"</"+a+this.tagEndChar}else r+=this.buildTextValNode(t[a],a,"",e,i)}}else if(Array.isArray(t[a])){let n=t[a].length,o="",s="";for(let l=0;l<n;l++){let n=t[a][l];if(void 0===n);else if(null===n)"?"===a[0]?r+=this.indentate(e)+"<"+a+"?"+this.tagEndChar:r+=this.indentate(e)+"<"+a+"/"+this.tagEndChar;else if("object"==typeof n)if(this.options.oneListGroup){i.push(a);let t=this.j2x(n,e+1,i);i.pop(),o+=t.val,this.options.attributesGroupName&&n.hasOwnProperty(this.options.attributesGroupName)&&(s+=t.attrStr)}else o+=this.processTextOrObjNode(n,a,e,i);else if(this.options.oneListGroup){let t=this.options.tagValueProcessor(a,n);o+=t=this.replaceEntitiesValue(t)}else{i.push(a);let t=this.checkStopNode(i);if(i.pop(),t){let t=""+n;o+=""===t?this.indentate(e)+"<"+a+this.closeTag(a)+this.tagEndChar:this.indentate(e)+"<"+a+">"+t+"</"+a+this.tagEndChar}else o+=this.buildTextValNode(n,a,"",e,i)}}this.options.oneListGroup&&(o=this.buildObjectNode(o,a,s,e)),r+=o}else if(this.options.attributesGroupName&&a===this.options.attributesGroupName){let e=Object.keys(t[a]),i=e.length;for(let r=0;r<i;r++)n+=this.buildAttrPairStr(e[r],""+t[a][e[r]],s)}else r+=this.processTextOrObjNode(t[a],a,e,i);return{attrStr:n,val:r}},ik.prototype.buildAttrPairStr=function(t,e,i){return i||(e=this.options.attributeValueProcessor(t,""+e),e=this.replaceEntitiesValue(e)),this.options.suppressBooleanAttributes&&"true"===e?" "+t:" "+t+'="'+e+'"'},ik.prototype.extractAttributes=function(t){if(!t||"object"!=typeof t)return null;let e={},i=!1;if(this.options.attributesGroupName&&t[this.options.attributesGroupName]){let n=t[this.options.attributesGroupName];for(let t in n)Object.prototype.hasOwnProperty.call(n,t)&&(e[t.startsWith(this.options.attributeNamePrefix)?t.substring(this.options.attributeNamePrefix.length):t]=n[t],i=!0)}else for(let n in t){if(!Object.prototype.hasOwnProperty.call(t,n))continue;let r=this.isAttribute(n);r&&(e[r]=t[n],i=!0)}return i?e:null},ik.prototype.buildRawContent=function(t){if("string"==typeof t)return t;if("object"!=typeof t||null===t)return String(t);if(void 0!==t[this.options.textNodeName])return t[this.options.textNodeName];let e="";for(let i in t){if(!Object.prototype.hasOwnProperty.call(t,i)||this.isAttribute(i)||this.options.attributesGroupName&&i===this.options.attributesGroupName)continue;let n=t[i];if(i===this.options.textNodeName)e+=n;else if(Array.isArray(n)){for(let t of n)if("string"==typeof t||"number"==typeof t)e+=`<${i}>${t}</${i}>`;else if("object"==typeof t&&null!==t){let n=this.buildRawContent(t),r=this.buildAttributesForStopNode(t);e+=""===n?`<${i}${r}/>`:`<${i}${r}>${n}</${i}>`}}else if("object"==typeof n&&null!==n){let t=this.buildRawContent(n),r=this.buildAttributesForStopNode(n);e+=""===t?`<${i}${r}/>`:`<${i}${r}>${t}</${i}>`}else e+=`<${i}>${n}</${i}>`}return e},ik.prototype.buildAttributesForStopNode=function(t){if(!t||"object"!=typeof t)return"";let e="";if(this.options.attributesGroupName&&t[this.options.attributesGroupName]){let i=t[this.options.attributesGroupName];for(let t in i){if(!Object.prototype.hasOwnProperty.call(i,t))continue;let n=t.startsWith(this.options.attributeNamePrefix)?t.substring(this.options.attributeNamePrefix.length):t,r=i[t];!0===r&&this.options.suppressBooleanAttributes?e+=" "+n:e+=" "+n+'="'+r+'"'}}else for(let i in t){if(!Object.prototype.hasOwnProperty.call(t,i))continue;let n=this.isAttribute(i);if(n){let r=t[i];!0===r&&this.options.suppressBooleanAttributes?e+=" "+n:e+=" "+n+'="'+r+'"'}}return e},ik.prototype.buildObjectNode=function(t,e,i,n){if(""===t)return"?"===e[0]?this.indentate(n)+"<"+e+i+"?"+this.tagEndChar:this.indentate(n)+"<"+e+i+this.closeTag(e)+this.tagEndChar;{let r="</"+e+this.tagEndChar,o="";return"?"===e[0]&&(o="?",r=""),(i||""===i)&&-1===t.indexOf("<")?this.indentate(n)+"<"+e+i+o+">"+t+r:!1!==this.options.commentPropName&&e===this.options.commentPropName&&0===o.length?this.indentate(n)+`<!--${t}-->`+this.newLine:this.indentate(n)+"<"+e+i+o+this.tagEndChar+t+this.indentate(n)+r}},ik.prototype.closeTag=function(t){let e="";return -1!==this.options.unpairedTags.indexOf(t)?this.options.suppressUnpairedNode||(e="/"):e=this.options.suppressEmptyNode?"/":`></${t}`,e},ik.prototype.checkStopNode=function(t){if(!this.stopNodeExpressions||0===this.stopNodeExpressions.length)return!1;for(let e=0;e<this.stopNodeExpressions.length;e++)if(t.matches(this.stopNodeExpressions[e]))return!0;return!1},ik.prototype.buildTextValNode=function(t,e,i,n,r){if(!1!==this.options.cdataPropName&&e===this.options.cdataPropName){let e=String(t).replace(/\]\]>/g,"]]]]><![CDATA[>");return this.indentate(n)+`<![CDATA[${e}]]>`+this.newLine}if(!1!==this.options.commentPropName&&e===this.options.commentPropName){let e=String(t).replace(/--/g,"- -").replace(/-$/,"- ");return this.indentate(n)+`<!--${e}-->`+this.newLine}if("?"===e[0])return this.indentate(n)+"<"+e+i+"?"+this.tagEndChar;{let r=this.options.tagValueProcessor(e,t);return""===(r=this.replaceEntitiesValue(r))?this.indentate(n)+"<"+e+i+this.closeTag(e)+this.tagEndChar:this.indentate(n)+"<"+e+i+">"+r+"</"+e+this.tagEndChar}},ik.prototype.replaceEntitiesValue=function(t){if(t&&t.length>0&&this.options.processEntities)for(let e=0;e<this.options.entities.length;e++){let i=this.options.entities[e];t=t.replace(i.regex,i.val)}return t};let iV=iD(function(t,e,i){let n=arguments.length>3&&void 0!==arguments[3]?arguments[3]:{};return iR(td(tf({url:R(t.remoteURL,L(e)),method:"UNLOCK",headers:{"Lock-Token":i}},t,n),t),function(e){if(t2(t,e),204!==e.status&&200!==e.status)throw t1(e)})}),iM=iD(function(t,e){var i;let n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},{refreshToken:r,timeout:o=iB}=n,s={Accept:"text/plain,application/xml",Timeout:o};return r&&(s.If=r),iR(td(tf({url:R(t.remoteURL,L(e)),method:"LOCK",headers:s,data:(i=t.contactHref,new ik({attributeNamePrefix:"@_",format:!0,ignoreAttributes:!1,suppressEmptyNode:!0}).build(function t(e,i){let n={...e};for(let e in n)n.hasOwnProperty(e)&&(n[e]&&"object"==typeof n[e]&&-1===e.indexOf(":")?(n[`${i}:${e}`]=t(n[e],i),delete n[e]):!1===/^@_/.test(e)&&(n[`${i}:${e}`]=n[e],delete n[e]));return n}({lockinfo:{"@_xmlns:d":"DAV:",lockscope:{exclusive:{}},locktype:{write:{}},owner:{href:i}}},"d")))},t,n),t),function(e){return t2(t,e),iR(e.text(),function(t){let i=new e0({removeNSPrefix:!0,parseAttributeValue:!0,parseTagValue:!0}).parse(t),n=e2().get(i,"prop.lockdiscovery.activelock.locktoken.href"),r=e2().get(i,"prop.lockdiscovery.activelock.timeout");if(!n)throw t1(e,"No lock token received: ");return{token:n,serverTimeout:r}})})}),iB="Infinite, Second-4100000000";function iF(t,e,i){return i?e?e(t):t:(t&&t.then||(t=Promise.resolve(t)),e?t.then(e):t)}let iU=(d=function(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},i=e.path||"/";return iF(td(tf({url:R(t.remoteURL,i),method:"PROPFIND",headers:{Accept:"text/plain,application/xml",Depth:"0"}},t,e),t),function(i){return t2(t,i),iF(i.text(),function(n){return iF(e5(n,t.parsing),function(t){return t3(i,function(t){try{let[e]=t.multistatus.response,{propstat:{prop:{"quota-used-bytes":i,"quota-available-bytes":n}}}=e;return void 0!==i&&void 0!==n?{used:parseInt(String(i),10),available:function(t){switch(String(t)){case"-3":return"unlimited";case"-2":case"-1":return"unknown";default:return parseInt(String(t),10)}}(n)}:null}catch(t){}return null}(t),e.details)})})})},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(d.apply(this,t))}catch(t){return Promise.reject(t)}});function iW(t,e,i){return i?e?e(t):t:(t&&t.then||(t=Promise.resolve(t)),e?t.then(e):t)}let iz=(f=function(t,e){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},{details:n=!1}=i;return iW(td(tf({url:R(t.remoteURL,L(e)),method:"SEARCH",headers:{Accept:"text/plain,application/xml","Content-Type":t.headers["Content-Type"]||"application/xml; charset=utf-8"}},t,i),t),function(i){return t2(t,i),iW(i.text(),function(r){return iW(e5(r,t.parsing),function(t){let r;return t3(i,((r={truncated:!1,results:[]}).truncated=t.multistatus.response.some(t=>"507"===(t.status||t.propstat?.status).split(" ",3)?.[1]&&t.href.replace(/\/$/,"").endsWith(L(e).replace(/\/$/,""))),t.multistatus.response.forEach(t=>{if(void 0===t.propstat)return;let e=t.href.split("/").map(decodeURIComponent).join("/");r.results.push(e9(t.propstat.prop,e,n))}),r),n)})})})},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(f.apply(this,t))}catch(t){return Promise.reject(t)}}),iX=(g=function(t,e,i){var n,r;let o=arguments.length>3&&void 0!==arguments[3]?arguments[3]:{},s=tf({url:R(t.remoteURL,L(e)),method:"MOVE",headers:{Destination:R(t.remoteURL,L(i)),Overwrite:!1===o.overwrite?"F":"T"}},t,o);return n=function(e){t2(t,e)},(r=td(s,t))&&r.then||(r=Promise.resolve(r)),n?r.then(n):r},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(g.apply(this,t))}catch(t){return Promise.reject(t)}});var iG=_(172);let iq=(m=function(t,e,i){var n,r;let o=arguments.length>3&&void 0!==arguments[3]?arguments[3]:{},{contentLength:s=!0,overwrite:a=!0}=o,l={"Content-Type":"application/octet-stream"};!1===s||(l["Content-Length"]="number"==typeof s?`${s}`:`${function(t){if(ta(t))return t.byteLength;if(tl(t))return t.length;if("string"==typeof t)return(0,iG.d)(t);throw new O({info:{code:H.DataTypeNoLength}},"Cannot calculate data length: Invalid type")}(i)}`),a||(l["If-None-Match"]="*");let u=tf({url:R(t.remoteURL,L(e)),method:"PUT",headers:l,data:i},t,o);return r=function(e){try{t2(t,e)}catch(t){if(412!==t.status||a)throw t;return!1}return!0},(n=td(u,t))&&n.then||(n=Promise.resolve(n)),r?n.then(r):n},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(m.apply(this,t))}catch(t){return Promise.reject(t)}}),iH=(y=function(t,e){var i,n;let r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},o=tf({url:R(t.remoteURL,L(e)),method:"OPTIONS"},t,r);return n=function(e){try{t2(t,e)}catch(t){throw t}return{compliance:(e.headers.get("DAV")??"").split(",").map(t=>t.trim()),server:e.headers.get("Server")??""}},(i=td(o,t))&&i.then||(i=Promise.resolve(i)),n?i.then(n):i},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(y.apply(this,t))}catch(t){return Promise.reject(t)}});function iK(t,e,i){return i?e?e(t):t:(t&&t.then||(t=Promise.resolve(t)),e?t.then(e):t)}let iQ=iZ(function(t,e,i,n,r){let o=arguments.length>5&&void 0!==arguments[5]?arguments[5]:{};if(i>n||i<0)throw new O({info:{code:H.InvalidUpdateRange}},`Invalid update range ${i} for partial update`);let s={"Content-Type":"application/octet-stream","Content-Length":""+(n-i+1),"Content-Range":`bytes ${i}-${n}/*`};return iK(td(tf({url:R(t.remoteURL,L(e)),method:"PUT",headers:s,data:r},t,o),t),function(e){t2(t,e)})});function iY(t,e){var i=t();return i&&i.then?i.then(e):e(i)}let iJ=iZ(function(t,e,i,n,r){let o=arguments.length>5&&void 0!==arguments[5]?arguments[5]:{};if(i>n||i<0)throw new O({info:{code:H.InvalidUpdateRange}},`Invalid update range ${i} for partial update`);let s={"Content-Type":"application/x-sabredav-partialupdate","Content-Length":""+(n-i+1),"X-Update-Range":`bytes=${i}-${n}`};return iK(td(tf({url:R(t.remoteURL,L(e)),method:"PATCH",headers:s,data:r},t,o),t),function(e){t2(t,e)})});function iZ(t){return function(){for(var e=[],i=0;i<arguments.length;i++)e[i]=arguments[i];try{return Promise.resolve(t.apply(this,e))}catch(t){return Promise.reject(t)}}}let i0=iZ(function(t,e,i,n,r){let o=arguments.length>5&&void 0!==arguments[5]?arguments[5]:{};return iK(iH(t,e,o),function(s){let a=!1;return iY(function(){if(s.compliance.includes("sabredav-partialupdate"))return iK(iJ(t,e,i,n,r,o),function(t){return a=!0,t})},function(l){let u=!1;return a?l:iY(function(){if(s.server.includes("Apache")&&s.compliance.includes("<http://apache.org/dav/propset/fs/1>"))return iK(iQ(t,e,i,n,r,o),function(t){return u=!0,t})},function(t){if(u)return t;throw new O({info:{code:H.NotSupported}},"Not supported")})})})});function i1(t){let e,i=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},{authType:n=null,remoteBasePath:r,contactHref:o="https://github.com/perry-mitchell/webdav-client/blob/master/LOCK_CONTACT.md",entityDecoder:s,ha1:a,headers:l={},httpAgent:u,httpsAgent:h,password:c,token:p,username:d,withCredentials:f}=i,g=n;g||(g=d||c?q.Password:q.None);let m={authType:g,remoteBasePath:r,contactHref:o,ha1:a,headers:Object.assign({},l),httpAgent:u,httpsAgent:h,password:c,parsing:{attributeNamePrefix:i.attributeNamePrefix??"@",attributeParsers:[],entityDecoder:s,tagParsers:[e6]},remotePath:((e=new(E())(t).pathname).length<=0&&(e="/"),I(e)),remoteURL:t,token:p,username:d,withCredentials:f};return K(m,d,c,p,a),{copyFile:(t,e,i)=>t4(m,t,e,i),createDirectory:(t,e)=>ic(m,t,e),createReadStream:(t,e)=>(function(t,e){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},n=new(0,id().PassThrough);return ig(t,e,i).then(t=>{t.pipe(n)}).catch(t=>{n.emit("error",t)}),n})(m,t,e),createWriteStream:(t,e,i)=>(function(t,e){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},n=arguments.length>3&&void 0!==arguments[3]?arguments[3]:im,r=new(0,id().PassThrough),o={};return!1===i.overwrite&&(o["If-None-Match"]="*"),td(tf({url:R(t.remoteURL,L(e)),method:"PUT",headers:o,data:r,maxRedirects:0},t,i),t).then(e=>t2(t,e)).then(t=>{setTimeout(()=>{n(t)},0)}).catch(t=>{r.emit("error",t)}),r})(m,t,e,i),customRequest:(t,e)=>iy(m,t,e),deleteFile:(t,e)=>ib(m,t,e),exists:(t,e)=>iv(m,t,e),getDirectoryContents:(t,e)=>iw(m,t,e),getFileContents:(t,e)=>iC(m,t,e),getFileDownloadLink:t=>(function(t,e){let i=R(t.remoteURL,L(e)),n=/^https:/i.test(i)?"https":"http";switch(t.authType){case q.None:break;case q.Password:{let e=W(t.headers.Authorization.replace(/^Basic /i,"").trim());i=i.replace(/^https?:\/\//,`${n}://${e}@`);break}default:throw new O({info:{code:H.LinkUnsupportedAuthType}},`Unsupported auth type for file link: ${t.authType}`)}return i})(m,t),getFileUploadLink:t=>(function(t,e){let i=`${R(t.remoteURL,L(e))}?Content-Type=application/octet-stream`,n=/^https:/i.test(i)?"https":"http";switch(t.authType){case q.None:break;case q.Password:{let e=W(t.headers.Authorization.replace(/^Basic /i,"").trim());i=i.replace(/^https?:\/\//,`${n}://${e}@`);break}default:throw new O({info:{code:H.LinkUnsupportedAuthType}},`Unsupported auth type for file link: ${t.authType}`)}return i})(m,t),getHeaders:()=>Object.assign({},m.headers),getQuota:t=>iU(m,t),lock:(t,e)=>iM(m,t,e),moveFile:(t,e,i)=>iX(m,t,e,i),putFileContents:(t,e,i)=>iq(m,t,e,i),partialUpdateFileContents:(t,e,i,n,r)=>i0(m,t,e,i,n,r),getDAVCompliance:t=>iH(m,t),search:(t,e)=>iz(m,t,e),setHeaders:t=>{m.headers=Object.assign({},t)},stat:(t,e)=>it(m,t,e),unlock:(t,e,i)=>iV(m,t,e,i),registerAttributeParser:t=>{m.parsing.attributeParsers.push(t)},registerTagParser:t=>{m.parsing.tagParsers.push(t)}}}i.d(e,{Gu:()=>te,UU:()=>i1})}}]);
//# sourceMappingURL=talk-defaultVendors-node_modules_nextcloud_vue_dist_assets_NcCheckboxRadioSwitch-BlQSZVW0_css-node-e54a6e.js.map?v=d97325a23487cefe